@@ -57,7 +57,7 @@ __PACKAGE__->meta->make_immutable;
 
 package Paws;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use Carp;
 
@@ -319,6 +319,8 @@ kept stable, and changes to it should be notified via ChangeLog
 =head1 SUPPORTED SERVICES
 
 
+L<Paws::AccessAnalyzer>
+
 L<Paws::ACM>
 
 L<Paws::ACMPCA>
@@ -333,6 +335,8 @@ L<Paws::ApiGatewayManagement>
 
 L<Paws::ApiGatewayV2>
 
+L<Paws::AppConfig>
+
 L<Paws::ApplicationAutoScaling>
 
 L<Paws::ApplicationInsights>
@@ -389,10 +393,18 @@ L<Paws::CodeCommit>
 
 L<Paws::CodeDeploy>
 
+L<Paws::CodeGuruProfiler>
+
+L<Paws::CodeGuruReviewer>
+
 L<Paws::CodePipeline>
 
 L<Paws::CodeStar>
 
+L<Paws::CodeStarConnections>
+
+L<Paws::CodeStarNotifications>
+
 L<Paws::CognitoIdentity>
 
 L<Paws::CognitoIdp>
@@ -403,20 +415,28 @@ L<Paws::Comprehend>
 
 L<Paws::ComprehendMedical>
 
+L<Paws::ComputeOptimizer>
+
 L<Paws::Config>
 
 L<Paws::Connect>
 
+L<Paws::ConnectParticipant>
+
 L<Paws::CostExplorer>
 
 L<Paws::CUR>
 
+L<Paws::DataExchange>
+
 L<Paws::DataPipeline>
 
 L<Paws::Datasync>
 
 L<Paws::DAX>
 
+L<Paws::Detective>
+
 L<Paws::DeviceFarm>
 
 L<Paws::DirectConnect>
@@ -435,6 +455,8 @@ L<Paws::DynamoDB>
 
 L<Paws::DynamoDBStreams>
 
+L<Paws::EBS>
+
 L<Paws::EC2>
 
 L<Paws::EC2InstanceConnect>
@@ -453,6 +475,8 @@ L<Paws::ElastiCache>
 
 L<Paws::ElasticBeanstalk>
 
+L<Paws::ElasticInference>
+
 L<Paws::ElasticTranscoder>
 
 L<Paws::ELB>
@@ -471,6 +495,12 @@ L<Paws::Firehose>
 
 L<Paws::FMS>
 
+L<Paws::Forecast>
+
+L<Paws::ForecastQuery>
+
+L<Paws::FraudDetector>
+
 L<Paws::FSX>
 
 L<Paws::GameLift>
@@ -491,6 +521,8 @@ L<Paws::Health>
 
 L<Paws::IAM>
 
+L<Paws::ImageBuilder>
+
 L<Paws::ImportExport>
 
 L<Paws::Inspector>
@@ -511,10 +543,14 @@ L<Paws::IoTEventsData>
 
 L<Paws::IoTJobsData>
 
+L<Paws::IoTSecureTunneling>
+
 L<Paws::IoTThingsGraph>
 
 L<Paws::Kafka>
 
+L<Paws::Kendra>
+
 L<Paws::Kinesis>
 
 L<Paws::KinesisAnalytics>
@@ -527,8 +563,12 @@ L<Paws::KinesisVideoArchivedMedia>
 
 L<Paws::KinesisVideoMedia>
 
+L<Paws::KinesisVideoSignaling>
+
 L<Paws::KMS>
 
+L<Paws::LakeFormation>
+
 L<Paws::Lambda>
 
 L<Paws::LexModels>
@@ -545,6 +585,8 @@ L<Paws::Macie>
 
 L<Paws::ManagedBlockchain>
 
+L<Paws::MarketplaceCatalog>
+
 L<Paws::MarketplaceCommerceAnalytics>
 
 L<Paws::MarketplaceEntitlement>
@@ -569,6 +611,8 @@ L<Paws::MediaTailor>
 
 L<Paws::MigrationHub>
 
+L<Paws::MigrationHubConfig>
+
 L<Paws::MobileHub>
 
 L<Paws::MQ>
@@ -577,12 +621,16 @@ L<Paws::MTurk>
 
 L<Paws::Neptune>
 
+L<Paws::NetworkManager>
+
 L<Paws::OpsWorks>
 
 L<Paws::OpsWorksCM>
 
 L<Paws::Organizations>
 
+L<Paws::Outposts>
+
 L<Paws::PerformanceInsights>
 
 L<Paws::Personalize>
@@ -603,6 +651,10 @@ L<Paws::Polly>
 
 L<Paws::Pricing>
 
+L<Paws::QLDB>
+
+L<Paws::QLDBSession>
+
 L<Paws::Quicksight>
 
 L<Paws::RAM>
@@ -633,8 +685,14 @@ L<Paws::S3Control>
 
 L<Paws::SageMaker>
 
+L<Paws::SageMakerA2IRuntime>
+
 L<Paws::SageMakerRuntime>
 
+L<Paws::SavingsPlans>
+
+L<Paws::Schemas>
+
 L<Paws::SDB>
 
 L<Paws::SecretsManager>
@@ -653,6 +711,8 @@ L<Paws::SES>
 
 L<Paws::SES>
 
+L<Paws::SESv2>
+
 L<Paws::Shield>
 
 L<Paws::Signer>
@@ -673,6 +733,10 @@ L<Paws::SQS>
 
 L<Paws::SSM>
 
+L<Paws::SSO>
+
+L<Paws::SSOOidc>
+
 L<Paws::StepFunctions>
 
 L<Paws::StorageGateway>
@@ -693,12 +757,16 @@ L<Paws::WAF>
 
 L<Paws::WAFRegional>
 
+L<Paws::WAFv2>
+
 L<Paws::WorkDocs>
 
 L<Paws::WorkLink>
 
 L<Paws::WorkMail>
 
+L<Paws::WorkMailMessageFlow>
+
 L<Paws::WorkSpaces>
 
 L<Paws::XRay>
@@ -958,6 +1026,12 @@ and giving me time to build and maintain it regularly.
 ZipRecruiter (https://www.ziprecruiter.com/) for sponsoring development of Paws. Lots of work
 from ZipRecruiter has been done via Shadowcat Systems (https://shadow.cat/).
 
+castaway for contributing to fixing documentation problems
+ - taking the reigns of Paws, become part of the core team that pushes it forward
+ - properly providing backlinks between related pages
+ - making TOCs render correctly on search.cpan.org
+ - generating helpful copy-paste ready scenarios in the synopsis of each method call
+
 Luis Alberto Gimenez (@agimenez) for
  - The git-fu cleaning up the "pull other sdks" code
  - Credential Providers code
@@ -1046,11 +1120,6 @@ gadgetjunkie for contributing the ECS credential provider
 
 mla for contributing a fix to correct dependencies
 
-castaway for contributing to fixing documentation problems
- - properly providing backlinks between related pages
- - making TOCs render correctly on search.cpan.org
- - generating helpful copy-paste ready scenarios in the synopsis of each method call
-
 autarch for correcting signature generation for a bunch of services
 
 piratefinn for linking calls to documentation AWS URLs
@@ -1071,5 +1140,7 @@ campus-explorer for contributing to test suite
 
 byterock for testing and fixing PinPoint
 
+torrentale for fixing QueryCaller to correctly signal empty arrays
+
 
 =cut
