@@ -40,11 +40,12 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       LastName           => 'Myuser_LastName',         # OPTIONAL
       Tags               => [
         {
-          Key   => 'MyTagKey',      # min: 1, max: 128; OPTIONAL
-          Value => 'MyTagValue',    # max: 256; OPTIONAL
+          Key   => 'MyTagKey',                         # min: 1, max: 128
+          Value => 'MyTagValue',                       # max: 256
+
         },
         ...
-      ],                            # OPTIONAL
+      ],                                               # OPTIONAL
     );
 
     # Results:
@@ -53,7 +54,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     # Returns a L<Paws::AlexaForBusiness::CreateUserResponse> object.
 
 Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
-For the AWS API documentation, see L<https://aws.amazon.com/documentation/>
+For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/a4b/CreateUser>
 
 =head1 ATTRIBUTES
 
