@@ -4,7 +4,9 @@ package Paws::AlexaForBusiness::UpdateProfile;
   has Address => (is => 'ro', isa => 'Str');
   has DistanceUnit => (is => 'ro', isa => 'Str');
   has IsDefault => (is => 'ro', isa => 'Bool');
+  has Locale => (is => 'ro', isa => 'Str');
   has MaxVolumeLimit => (is => 'ro', isa => 'Int');
+  has MeetingRoomConfiguration => (is => 'ro', isa => 'Paws::AlexaForBusiness::UpdateMeetingRoomConfiguration');
   has ProfileArn => (is => 'ro', isa => 'Str');
   has ProfileName => (is => 'ro', isa => 'Str');
   has PSTNEnabled => (is => 'ro', isa => 'Bool');
@@ -38,10 +40,30 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $a4b = Paws->service('AlexaForBusiness');
     my $UpdateProfileResponse = $a4b->UpdateProfile(
-      Address           => 'MyAddress',        # OPTIONAL
-      DistanceUnit      => 'METRIC',           # OPTIONAL
-      IsDefault         => 1,                  # OPTIONAL
-      MaxVolumeLimit    => 1,                  # OPTIONAL
+      Address                  => 'MyAddress',         # OPTIONAL
+      DistanceUnit             => 'METRIC',            # OPTIONAL
+      IsDefault                => 1,                   # OPTIONAL
+      Locale                   => 'MyDeviceLocale',    # OPTIONAL
+      MaxVolumeLimit           => 1,                   # OPTIONAL
+      MeetingRoomConfiguration => {
+        EndOfMeetingReminder => {
+          Enabled           => 1,
+          ReminderAtMinutes => [
+            1, ...                                     # OPTIONAL
+          ],    # min: 1, max: 1; OPTIONAL
+          ReminderType => 'ANNOUNCEMENT_TIME_CHECK'
+          , # values: ANNOUNCEMENT_TIME_CHECK, ANNOUNCEMENT_VARIABLE_TIME_LEFT, CHIME, KNOCK; OPTIONAL
+        },    # OPTIONAL
+        InstantBooking => {
+          DurationInMinutes => 1,    # OPTIONAL
+          Enabled           => 1,
+        },    # OPTIONAL
+        RequireCheckIn => {
+          Enabled             => 1,
+          ReleaseAfterMinutes => 1,    # OPTIONAL
+        },    # OPTIONAL
+        RoomUtilizationMetricsEnabled => 1,
+      },    # OPTIONAL
       PSTNEnabled       => 1,                  # OPTIONAL
       ProfileArn        => 'MyArn',            # OPTIONAL
       ProfileName       => 'MyProfileName',    # OPTIONAL
@@ -76,12 +98,25 @@ is done to the default status.
 
 
 
+=head2 Locale => Str
+
+The updated locale for the room profile. (This is currently only
+available to a limited preview audience.)
+
+
+
 =head2 MaxVolumeLimit => Int
 
 The updated maximum volume limit for the room profile.
 
 
 
+=head2 MeetingRoomConfiguration => L<Paws::AlexaForBusiness::UpdateMeetingRoomConfiguration>
+
+The updated meeting room settings of a room profile.
+
+
+
 =head2 ProfileArn => Str
 
 The ARN of the room profile to update. Required.
