@@ -49,15 +49,18 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       AccessToken              => 'MyAccessToken',    # OPTIONAL
       AutoBranchCreationConfig => {
         BasicAuthCredentials => 'MyBasicAuthCredentials',  # max: 2000; OPTIONAL
-        BuildSpec            => 'MyBuildSpec',    # min: 1, max: 25000; OPTIONAL
-        EnableAutoBuild      => 1,                # OPTIONAL
-        EnableBasicAuth      => 1,                # OPTIONAL
-        EnvironmentVariables => {
-          'MyEnvKey' => 'MyEnvValue',    # key: max: 255, value: max: 1000
+        BuildSpec       => 'MyBuildSpec',    # min: 1, max: 25000; OPTIONAL
+        EnableAutoBuild => 1,                # OPTIONAL
+        EnableBasicAuth => 1,                # OPTIONAL
+        EnablePullRequestPreview => 1,       # OPTIONAL
+        EnvironmentVariables     => {
+          'MyEnvKey' => 'MyEnvValue',        # key: max: 255, value: max: 1000
         },    # OPTIONAL
         Framework => 'MyFramework',    # max: 255; OPTIONAL
-        Stage     => 'PRODUCTION'
-        ,    # values: PRODUCTION, BETA, DEVELOPMENT, EXPERIMENTAL; OPTIONAL
+        PullRequestEnvironmentName =>
+          'MyPullRequestEnvironmentName',    # max: 20; OPTIONAL
+        Stage => 'PRODUCTION'
+        , # values: PRODUCTION, BETA, DEVELOPMENT, EXPERIMENTAL, PULL_REQUEST; OPTIONAL
       },    # OPTIONAL
       AutoBranchCreationPatterns => [
         'MyAutoBranchCreationPattern', ...    # min: 1, max: 2048
@@ -69,7 +72,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           Source    => 'MySource',       # min: 1, max: 2048
           Target    => 'MyTarget',       # min: 1, max: 2048
           Condition => 'MyCondition',    # min: 1, max: 2048; OPTIONAL
-          Status    => 'MyStatus',       # min: 3, max: 3; OPTIONAL
+          Status    => 'MyStatus',       # min: 3, max: 7; OPTIONAL
         },
         ...
       ],                                 # OPTIONAL
