@@ -1,7 +1,7 @@
 
 package Paws::ApiGateway::SdkTypes;
   use Moose;
-  has Items => (is => 'ro', isa => 'ArrayRef[Paws::ApiGateway::SdkType]', traits => ['NameInRequest'], request_name => 'items');
+  has Items => (is => 'ro', isa => 'ArrayRef[Paws::ApiGateway::SdkType]', traits => ['NameInRequest'], request_name => 'item');
   has Position => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'position');
 
   has _request_id => (is => 'ro', isa => 'Str');
