@@ -35,11 +35,11 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       RestApiId       => 'MyString',
       PatchOperations => [
         {
-          from => 'MyString',
-          op =>
+          From => 'MyString',
+          Op =>
             'add',    # values: add, remove, replace, move, copy, test; OPTIONAL
-          path  => 'MyString',
-          value => 'MyString',
+          Path  => 'MyString',
+          Value => 'MyString',
         },
         ...
       ],              # OPTIONAL
@@ -55,7 +55,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     # Returns a L<Paws::ApiGateway::Resource> object.
 
 Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
-For the AWS API documentation, see L<https://aws.amazon.com/documentation/apigateway/>
+For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/apigateway/UpdateResource>
 
 =head1 ATTRIBUTES
 
