@@ -50,9 +50,7 @@ Represents the input parameters for a CreateDomainName request.
 
 =head2 Tags => L<Paws::ApiGatewayV2::Tags>
 
-  The key-value map of strings. The valid character set is
-[a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not
-start with aws:. The tag value can be up to 256 characters..
+  The collection of tags associated with a domain name.
 
 
 
