@@ -11,6 +11,7 @@ package Paws::ApiGatewayV2::CreateIntegration;
   has IntegrationType => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'integrationType', required => 1);
   has IntegrationUri => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'integrationUri');
   has PassthroughBehavior => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'passthroughBehavior');
+  has PayloadFormatVersion => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'payloadFormatVersion');
   has RequestParameters => (is => 'ro', isa => 'Paws::ApiGatewayV2::IntegrationParameters', traits => ['NameInRequest'], request_name => 'requestParameters');
   has RequestTemplates => (is => 'ro', isa => 'Paws::ApiGatewayV2::TemplateMap', traits => ['NameInRequest'], request_name => 'requestTemplates');
   has TemplateSelectionExpression => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'templateSelectionExpression');
@@ -21,7 +22,7 @@ package Paws::ApiGatewayV2::CreateIntegration;
   class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateIntegration');
   class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/v2/apis/{apiId}/integrations');
   class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
-  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ApiGatewayV2::CreateIntegrationResponse');
+  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ApiGatewayV2::CreateIntegrationResult');
 1;
 
 ### main pod documentation begin ###
@@ -41,7 +42,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 =head1 SYNOPSIS
 
     my $apigateway = Paws->service('ApiGatewayV2');
-    my $CreateIntegrationResponse = $apigateway->CreateIntegration(
+    my $CreateIntegrationResult = $apigateway->CreateIntegration(
       ApiId                   => 'My__string',
       IntegrationType         => 'AWS',
       ConnectionId            => 'MyStringWithLengthBetween1And1024', # OPTIONAL
@@ -52,6 +53,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       IntegrationMethod       => 'MyStringWithLengthBetween1And64',   # OPTIONAL
       IntegrationUri          => 'MyUriWithLengthBetween1And2048',    # OPTIONAL
       PassthroughBehavior     => 'WHEN_NO_MATCH',                     # OPTIONAL
+      PayloadFormatVersion    => 'MyStringWithLengthBetween1And64',   # OPTIONAL
       RequestParameters =>
         { 'My__string' => 'MyStringWithLengthBetween1And512', },      # OPTIONAL
       RequestTemplates =>
@@ -61,26 +63,28 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     );
 
     # Results:
-    my $ConnectionId   = $CreateIntegrationResponse->ConnectionId;
-    my $ConnectionType = $CreateIntegrationResponse->ConnectionType;
+    my $ApiGatewayManaged = $CreateIntegrationResult->ApiGatewayManaged;
+    my $ConnectionId      = $CreateIntegrationResult->ConnectionId;
+    my $ConnectionType    = $CreateIntegrationResult->ConnectionType;
     my $ContentHandlingStrategy =
-      $CreateIntegrationResponse->ContentHandlingStrategy;
-    my $CredentialsArn    = $CreateIntegrationResponse->CredentialsArn;
-    my $Description       = $CreateIntegrationResponse->Description;
-    my $IntegrationId     = $CreateIntegrationResponse->IntegrationId;
-    my $IntegrationMethod = $CreateIntegrationResponse->IntegrationMethod;
+      $CreateIntegrationResult->ContentHandlingStrategy;
+    my $CredentialsArn    = $CreateIntegrationResult->CredentialsArn;
+    my $Description       = $CreateIntegrationResult->Description;
+    my $IntegrationId     = $CreateIntegrationResult->IntegrationId;
+    my $IntegrationMethod = $CreateIntegrationResult->IntegrationMethod;
     my $IntegrationResponseSelectionExpression =
-      $CreateIntegrationResponse->IntegrationResponseSelectionExpression;
-    my $IntegrationType     = $CreateIntegrationResponse->IntegrationType;
-    my $IntegrationUri      = $CreateIntegrationResponse->IntegrationUri;
-    my $PassthroughBehavior = $CreateIntegrationResponse->PassthroughBehavior;
-    my $RequestParameters   = $CreateIntegrationResponse->RequestParameters;
-    my $RequestTemplates    = $CreateIntegrationResponse->RequestTemplates;
+      $CreateIntegrationResult->IntegrationResponseSelectionExpression;
+    my $IntegrationType      = $CreateIntegrationResult->IntegrationType;
+    my $IntegrationUri       = $CreateIntegrationResult->IntegrationUri;
+    my $PassthroughBehavior  = $CreateIntegrationResult->PassthroughBehavior;
+    my $PayloadFormatVersion = $CreateIntegrationResult->PayloadFormatVersion;
+    my $RequestParameters    = $CreateIntegrationResult->RequestParameters;
+    my $RequestTemplates     = $CreateIntegrationResult->RequestTemplates;
     my $TemplateSelectionExpression =
-      $CreateIntegrationResponse->TemplateSelectionExpression;
-    my $TimeoutInMillis = $CreateIntegrationResponse->TimeoutInMillis;
+      $CreateIntegrationResult->TemplateSelectionExpression;
+    my $TimeoutInMillis = $CreateIntegrationResult->TimeoutInMillis;
 
-    # Returns a L<Paws::ApiGatewayV2::CreateIntegrationResponse> object.
+    # Returns a L<Paws::ApiGatewayV2::CreateIntegrationResult> object.
 
 Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
 For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/apigateway/CreateIntegration>
@@ -110,9 +114,9 @@ Valid values are: C<"INTERNET">, C<"VPC_LINK">
 
 =head2 ContentHandlingStrategy => Str
 
-Specifies how to handle response payload content type conversions.
-Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the
-following behaviors:
+Supported only for WebSocket APIs. Specifies how to handle response
+payload content type conversions. Supported values are
+CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors:
 
 CONVERT_TO_BINARY: Converts a response payload from a Base64-encoded
 string to the corresponding binary blob.
@@ -157,22 +161,23 @@ AWS: for integrating the route or method request with an AWS service
 action, including the Lambda function-invoking action. With the Lambda
 function-invoking action, this is referred to as the Lambda custom
 integration. With any other AWS service action, this is known as AWS
-integration.
+integration. Supported only for WebSocket APIs.
 
 AWS_PROXY: for integrating the route or method request with the Lambda
 function-invoking action with the client request passed through as-is.
 This integration is also referred to as Lambda proxy integration.
 
 HTTP: for integrating the route or method request with an HTTP
-endpoint. This integration is also referred to as HTTP custom
-integration.
+endpoint. This integration is also referred to as the HTTP custom
+integration. Supported only for WebSocket APIs.
 
 HTTP_PROXY: for integrating route or method request with an HTTP
 endpoint, with the client request passed through as-is. This is also
 referred to as HTTP proxy integration.
 
 MOCK: for integrating the route or method request with API Gateway as a
-"loopback" endpoint without invoking any backend.
+"loopback" endpoint without invoking any backend. Supported only for
+WebSocket APIs.
 
 Valid values are: C<"AWS">, C<"HTTP">, C<"MOCK">, C<"HTTP_PROXY">, C<"AWS_PROXY">
 
@@ -188,7 +193,7 @@ Specifies the pass-through behavior for incoming requests based on the
 Content-Type header in the request, and the available mapping templates
 specified as the requestTemplates property on the Integration resource.
 There are three valid values: WHEN_NO_MATCH, WHEN_NO_TEMPLATES, and
-NEVER.
+NEVER. Supported only for WebSocket APIs.
 
 WHEN_NO_MATCH passes the request body for unmapped content types
 through to the integration backend without transformation.
@@ -203,6 +208,13 @@ same HTTP 415 Unsupported Media Type response.
 
 Valid values are: C<"WHEN_NO_MATCH">, C<"NEVER">, C<"WHEN_NO_TEMPLATES">
 
+=head2 PayloadFormatVersion => Str
+
+Specifies the format of the payload sent to an integration. Required
+for HTTP APIs. Currently, the only supported value is 1.0.
+
+
+
 =head2 RequestParameters => L<Paws::ApiGatewayV2::IntegrationParameters>
 
 A key-value map specifying request parameters that are passed from the
@@ -212,7 +224,8 @@ value or static value that must be enclosed within single quotes and
 pre-encoded as required by the backend. The method request parameter
 value must match the pattern of method.request.{location}.{name} ,
 where {location} is querystring, path, or header; and {name} must be a
-valid and unique method request parameter name.
+valid and unique method request parameter name. Supported only for
+WebSocket APIs.
 
 
 
@@ -221,7 +234,7 @@ valid and unique method request parameter name.
 Represents a map of Velocity templates that are applied on the request
 payload based on the value of the Content-Type header sent by the
 client. The content type value is the key in this map, and the template
-(as a String) is the value.
+(as a String) is the value. Supported only for WebSocket APIs.
 
 
 
@@ -234,7 +247,8 @@ The template selection expression for the integration.
 =head2 TimeoutInMillis => Int
 
 Custom timeout between 50 and 29,000 milliseconds. The default value is
-29,000 milliseconds or 29 seconds.
+29,000 milliseconds or 29 seconds for WebSocket APIs. The default value
+is 5,000 milliseconds, or 5 seconds for HTTP APIs.
 
 
 
