@@ -57,6 +57,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     );
 
     # Results:
+    my $ApiGatewayManaged   = $CreateRouteResponseShape->ApiGatewayManaged;
     my $ApiKeyRequired      = $CreateRouteResponseShape->ApiKeyRequired;
     my $AuthorizationScopes = $CreateRouteResponseShape->AuthorizationScopes;
     my $AuthorizationType   = $CreateRouteResponseShape->AuthorizationType;
@@ -88,7 +89,8 @@ The API identifier.
 
 =head2 ApiKeyRequired => Bool
 
-Specifies whether an API key is required for the route.
+Specifies whether an API key is required for the route. Supported only
+for WebSocket APIs.
 
 
 
@@ -100,23 +102,25 @@ The authorization scopes supported by this route.
 
 =head2 AuthorizationType => Str
 
-The authorization type for the route. Valid values are NONE for open
-access, AWS_IAM for using AWS IAM permissions, and CUSTOM for using a
-Lambda authorizer.
+The authorization type for the route. For WebSocket APIs, valid values
+are NONE for open access, AWS_IAM for using AWS IAM permissions, and
+CUSTOM for using a Lambda authorizer For HTTP APIs, valid values are
+NONE for open access, or JWT for using JSON Web Tokens.
 
-Valid values are: C<"NONE">, C<"AWS_IAM">, C<"CUSTOM">
+Valid values are: C<"NONE">, C<"AWS_IAM">, C<"CUSTOM">, C<"JWT">
 
 =head2 AuthorizerId => Str
 
 The identifier of the Authorizer resource to be associated with this
-route, if the authorizationType is CUSTOM . The authorizer identifier
-is generated by API Gateway when you created the authorizer.
+route. The authorizer identifier is generated by API Gateway when you
+created the authorizer.
 
 
 
 =head2 ModelSelectionExpression => Str
 
-The model selection expression for the route.
+The model selection expression for the route. Supported only for
+WebSocket APIs.
 
 
 
@@ -128,13 +132,14 @@ The operation name for the route.
 
 =head2 RequestModels => L<Paws::ApiGatewayV2::RouteModels>
 
-The request models for the route.
+The request models for the route. Supported only for WebSocket APIs.
 
 
 
 =head2 RequestParameters => L<Paws::ApiGatewayV2::RouteParameters>
 
-The request parameters for the route.
+The request parameters for the route. Supported only for WebSocket
+APIs.
 
 
 
@@ -146,7 +151,8 @@ The route key for the route.
 
 =head2 RouteResponseSelectionExpression => Str
 
-The route response selection expression for the route.
+The route response selection expression for the route. Supported only
+for WebSocket APIs.
 
 
 
