@@ -1,6 +1,7 @@
 package Paws::ApiGatewayV2::CreateStageInput;
   use Moose;
   has AccessLogSettings => (is => 'ro', isa => 'Paws::ApiGatewayV2::AccessLogSettings', request_name => 'accessLogSettings', traits => ['NameInRequest']);
+  has AutoDeploy => (is => 'ro', isa => 'Bool', request_name => 'autoDeploy', traits => ['NameInRequest']);
   has ClientCertificateId => (is => 'ro', isa => 'Str', request_name => 'clientCertificateId', traits => ['NameInRequest']);
   has DefaultRouteSettings => (is => 'ro', isa => 'Paws::ApiGatewayV2::RouteSettings', request_name => 'defaultRouteSettings', traits => ['NameInRequest']);
   has DeploymentId => (is => 'ro', isa => 'Str', request_name => 'deploymentId', traits => ['NameInRequest']);
@@ -49,9 +50,16 @@ Represents the input parameters for a CreateStage request.
   Settings for logging access in this stage.
 
 
+=head2 AutoDeploy => Bool
+
+  Specifies whether updates to an API automatically trigger a new
+deployment. The default value is false.
+
+
 =head2 ClientCertificateId => Str
 
-  The identifier of a client certificate for a Stage.
+  The identifier of a client certificate for a Stage. Supported only for
+WebSocket APIs.
 
 
 =head2 DefaultRouteSettings => L<Paws::ApiGatewayV2::RouteSettings>
@@ -71,7 +79,7 @@ Represents the input parameters for a CreateStage request.
 
 =head2 RouteSettings => L<Paws::ApiGatewayV2::RouteSettingsMap>
 
-  Route settings for the stage.
+  Route settings for the stage, by routeKey.
 
 
 =head2 B<REQUIRED> StageName => Str
@@ -83,14 +91,13 @@ Represents the input parameters for a CreateStage request.
 
   A map that defines the stage variables for a Stage. Variable names can
 have alphanumeric and underscore characters, and the values must match
-[A-Za-z0-9-._~:/?#&=,]+.
+[A-Za-z0-9-._~:/?#&=,]+. Supported only for WebSocket APIs.
 
 
 =head2 Tags => L<Paws::ApiGatewayV2::Tags>
 
-  The key-value map of strings. The valid character set is
-[a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not
-start with aws:. The tag value can be up to 256 characters..
+  The collection of tags. Each tag element is associated with a given
+resource.
 
 
 
