@@ -1,5 +1,6 @@
 package Paws::ApiGatewayV2::Integration;
   use Moose;
+  has ApiGatewayManaged => (is => 'ro', isa => 'Bool', request_name => 'apiGatewayManaged', traits => ['NameInRequest']);
   has ConnectionId => (is => 'ro', isa => 'Str', request_name => 'connectionId', traits => ['NameInRequest']);
   has ConnectionType => (is => 'ro', isa => 'Str', request_name => 'connectionType', traits => ['NameInRequest']);
   has ContentHandlingStrategy => (is => 'ro', isa => 'Str', request_name => 'contentHandlingStrategy', traits => ['NameInRequest']);
@@ -11,6 +12,7 @@ package Paws::ApiGatewayV2::Integration;
   has IntegrationType => (is => 'ro', isa => 'Str', request_name => 'integrationType', traits => ['NameInRequest']);
   has IntegrationUri => (is => 'ro', isa => 'Str', request_name => 'integrationUri', traits => ['NameInRequest']);
   has PassthroughBehavior => (is => 'ro', isa => 'Str', request_name => 'passthroughBehavior', traits => ['NameInRequest']);
+  has PayloadFormatVersion => (is => 'ro', isa => 'Str', request_name => 'payloadFormatVersion', traits => ['NameInRequest']);
   has RequestParameters => (is => 'ro', isa => 'Paws::ApiGatewayV2::IntegrationParameters', request_name => 'requestParameters', traits => ['NameInRequest']);
   has RequestTemplates => (is => 'ro', isa => 'Paws::ApiGatewayV2::TemplateMap', request_name => 'requestTemplates', traits => ['NameInRequest']);
   has TemplateSelectionExpression => (is => 'ro', isa => 'Str', request_name => 'templateSelectionExpression', traits => ['NameInRequest']);
@@ -34,14 +36,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::ApiGatewayV2::Integration object:
 
-  $service_obj->Method(Att1 => { ConnectionId => $value, ..., TimeoutInMillis => $value  });
+  $service_obj->Method(Att1 => { ApiGatewayManaged => $value, ..., TimeoutInMillis => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::ApiGatewayV2::Integration object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->ConnectionId
+  $result->Att1->ApiGatewayManaged
 
 =head1 DESCRIPTION
 
@@ -50,6 +52,14 @@ Represents an integration.
 =head1 ATTRIBUTES
 
 
+=head2 ApiGatewayManaged => Bool
+
+  Specifies whether an integration is managed by API Gateway. If you
+created an API using using quick create, the resulting integration is
+managed by API Gateway. You can update a managed integration, but you
+can't delete it.
+
+
 =head2 ConnectionId => Str
 
   The connection ID.
@@ -64,9 +74,9 @@ public routable internet.
 
 =head2 ContentHandlingStrategy => Str
 
-  Specifies how to handle response payload content type conversions.
-Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the
-following behaviors:
+  Supported only for WebSocket APIs. Specifies how to handle response
+payload content type conversions. Supported values are
+CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors:
 
 CONVERT_TO_BINARY: Converts a response payload from a Base64-encoded
 string to the corresponding binary blob.
@@ -106,8 +116,9 @@ permissions on supported AWS services, specify null.
 
 =head2 IntegrationResponseSelectionExpression => Str
 
-  The integration response selection expression for the integration. See
-Integration Response Selection Expressions
+  The integration response selection expression for the integration.
+Supported only for WebSocket APIs. See Integration Response Selection
+Expressions
 (https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-integration-response-selection-expressions).
 
 
@@ -119,7 +130,7 @@ AWS: for integrating the route or method request with an AWS service
 action, including the Lambda function-invoking action. With the Lambda
 function-invoking action, this is referred to as the Lambda custom
 integration. With any other AWS service action, this is known as AWS
-integration.
+integration. Supported only for WebSocket APIs.
 
 AWS_PROXY: for integrating the route or method request with the Lambda
 function-invoking action with the client request passed through as-is.
@@ -127,14 +138,15 @@ This integration is also referred to as Lambda proxy integration.
 
 HTTP: for integrating the route or method request with an HTTP
 endpoint. This integration is also referred to as the HTTP custom
-integration.
+integration. Supported only for WebSocket APIs.
 
 HTTP_PROXY: for integrating route or method request with an HTTP
 endpoint, with the client request passed through as-is. This is also
 referred to as HTTP proxy integration.
 
 MOCK: for integrating the route or method request with API Gateway as a
-"loopback" endpoint without invoking any backend.
+"loopback" endpoint without invoking any backend. Supported only for
+WebSocket APIs.
 
 
 =head2 IntegrationUri => Str
@@ -148,7 +160,7 @@ MOCK: for integrating the route or method request with API Gateway as a
 Content-Type header in the request, and the available mapping templates
 specified as the requestTemplates property on the Integration resource.
 There are three valid values: WHEN_NO_MATCH, WHEN_NO_TEMPLATES, and
-NEVER.
+NEVER. Supported only for WebSocket APIs.
 
 WHEN_NO_MATCH passes the request body for unmapped content types
 through to the integration backend without transformation.
@@ -162,6 +174,12 @@ content type defined, unmapped content types will be rejected with the
 same HTTP 415 Unsupported Media Type response.
 
 
+=head2 PayloadFormatVersion => Str
+
+  Specifies the format of the payload sent to an integration. Required
+for HTTP APIs. Currently, the only supported value is 1.0.
+
+
 =head2 RequestParameters => L<Paws::ApiGatewayV2::IntegrationParameters>
 
   A key-value map specifying request parameters that are passed from the
@@ -171,7 +189,8 @@ value or static value that must be enclosed within single quotes and
 pre-encoded as required by the backend. The method request parameter
 value must match the pattern of method.request.{location}.{name} ,
 where {location} is querystring, path, or header; and {name} must be a
-valid and unique method request parameter name.
+valid and unique method request parameter name. Supported only for
+WebSocket APIs.
 
 
 =head2 RequestTemplates => L<Paws::ApiGatewayV2::TemplateMap>
@@ -179,18 +198,20 @@ valid and unique method request parameter name.
   Represents a map of Velocity templates that are applied on the request
 payload based on the value of the Content-Type header sent by the
 client. The content type value is the key in this map, and the template
-(as a String) is the value.
+(as a String) is the value. Supported only for WebSocket APIs.
 
 
 =head2 TemplateSelectionExpression => Str
 
-  The template selection expression for the integration.
+  The template selection expression for the integration. Supported only
+for WebSocket APIs.
 
 
 =head2 TimeoutInMillis => Int
 
   Custom timeout between 50 and 29,000 milliseconds. The default value is
-29,000 milliseconds or 29 seconds.
+29,000 milliseconds or 29 seconds for WebSocket APIs. The default value
+is 5,000 milliseconds, or 5 seconds for HTTP APIs.
 
 
 
