@@ -1,5 +1,6 @@
 package Paws::ApiGatewayV2::Route;
   use Moose;
+  has ApiGatewayManaged => (is => 'ro', isa => 'Bool', request_name => 'apiGatewayManaged', traits => ['NameInRequest']);
   has ApiKeyRequired => (is => 'ro', isa => 'Bool', request_name => 'apiKeyRequired', traits => ['NameInRequest']);
   has AuthorizationScopes => (is => 'ro', isa => 'ArrayRef[Str|Undef]', request_name => 'authorizationScopes', traits => ['NameInRequest']);
   has AuthorizationType => (is => 'ro', isa => 'Str', request_name => 'authorizationType', traits => ['NameInRequest']);
@@ -31,14 +32,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::ApiGatewayV2::Route object:
 
-  $service_obj->Method(Att1 => { ApiKeyRequired => $value, ..., Target => $value  });
+  $service_obj->Method(Att1 => { ApiGatewayManaged => $value, ..., Target => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::ApiGatewayV2::Route object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->ApiKeyRequired
+  $result->Att1->ApiGatewayManaged
 
 =head1 DESCRIPTION
 
@@ -47,41 +48,50 @@ Represents a route.
 =head1 ATTRIBUTES
 
 
+=head2 ApiGatewayManaged => Bool
+
+  Specifies whether a route is managed by API Gateway. If you created an
+API using quick create, the $default route is managed by API Gateway.
+You can't modify the $default route key.
+
+
 =head2 ApiKeyRequired => Bool
 
-  Specifies whether an API key is required for this route.
+  Specifies whether an API key is required for this route. Supported only
+for WebSocket APIs.
 
 
 =head2 AuthorizationScopes => ArrayRef[Str|Undef]
 
   A list of authorization scopes configured on a route. The scopes are
-used with a COGNITO_USER_POOLS authorizer to authorize the method
-invocation. The authorization works by matching the route scopes
-against the scopes parsed from the access token in the incoming
-request. The method invocation is authorized if any route scope matches
-a claimed scope in the access token. Otherwise, the invocation is not
-authorized. When the route scope is configured, the client must provide
-an access token instead of an identity token for authorization
-purposes.
+used with a JWT authorizer to authorize the method invocation. The
+authorization works by matching the route scopes against the scopes
+parsed from the access token in the incoming request. The method
+invocation is authorized if any route scope matches a claimed scope in
+the access token. Otherwise, the invocation is not authorized. When the
+route scope is configured, the client must provide an access token
+instead of an identity token for authorization purposes.
 
 
 =head2 AuthorizationType => Str
 
-  The authorization type for the route. Valid values are NONE for open
-access, AWS_IAM for using AWS IAM permissions, and CUSTOM for using a
-Lambda authorizer
+  The authorization type for the route. For WebSocket APIs, valid values
+are NONE for open access, AWS_IAM for using AWS IAM permissions, and
+CUSTOM for using a Lambda authorizer For HTTP APIs, valid values are
+NONE for open access, or JWT for using JSON Web Tokens.
 
 
 =head2 AuthorizerId => Str
 
   The identifier of the Authorizer resource to be associated with this
-route, if the authorizationType is CUSTOM . The authorizer identifier
-is generated by API Gateway when you created the authorizer.
+route. The authorizer identifier is generated by API Gateway when you
+created the authorizer.
 
 
 =head2 ModelSelectionExpression => Str
 
-  The model selection expression for the route.
+  The model selection expression for the route. Supported only for
+WebSocket APIs.
 
 
 =head2 OperationName => Str
@@ -91,12 +101,13 @@ is generated by API Gateway when you created the authorizer.
 
 =head2 RequestModels => L<Paws::ApiGatewayV2::RouteModels>
 
-  The request models for the route.
+  The request models for the route. Supported only for WebSocket APIs.
 
 
 =head2 RequestParameters => L<Paws::ApiGatewayV2::RouteParameters>
 
-  The request parameters for the route.
+  The request parameters for the route. Supported only for WebSocket
+APIs.
 
 
 =head2 RouteId => Str
@@ -111,7 +122,8 @@ is generated by API Gateway when you created the authorizer.
 
 =head2 RouteResponseSelectionExpression => Str
 
-  The route response selection expression for the route.
+  The route response selection expression for the route. Supported only
+for WebSocket APIs.
 
 
 =head2 Target => Str
