@@ -1,11 +1,14 @@
 package Paws::ApiGatewayV2::Stage;
   use Moose;
   has AccessLogSettings => (is => 'ro', isa => 'Paws::ApiGatewayV2::AccessLogSettings', request_name => 'accessLogSettings', traits => ['NameInRequest']);
+  has ApiGatewayManaged => (is => 'ro', isa => 'Bool', request_name => 'apiGatewayManaged', traits => ['NameInRequest']);
+  has AutoDeploy => (is => 'ro', isa => 'Bool', request_name => 'autoDeploy', traits => ['NameInRequest']);
   has ClientCertificateId => (is => 'ro', isa => 'Str', request_name => 'clientCertificateId', traits => ['NameInRequest']);
   has CreatedDate => (is => 'ro', isa => 'Str', request_name => 'createdDate', traits => ['NameInRequest']);
   has DefaultRouteSettings => (is => 'ro', isa => 'Paws::ApiGatewayV2::RouteSettings', request_name => 'defaultRouteSettings', traits => ['NameInRequest']);
   has DeploymentId => (is => 'ro', isa => 'Str', request_name => 'deploymentId', traits => ['NameInRequest']);
   has Description => (is => 'ro', isa => 'Str', request_name => 'description', traits => ['NameInRequest']);
+  has LastDeploymentStatusMessage => (is => 'ro', isa => 'Str', request_name => 'lastDeploymentStatusMessage', traits => ['NameInRequest']);
   has LastUpdatedDate => (is => 'ro', isa => 'Str', request_name => 'lastUpdatedDate', traits => ['NameInRequest']);
   has RouteSettings => (is => 'ro', isa => 'Paws::ApiGatewayV2::RouteSettingsMap', request_name => 'routeSettings', traits => ['NameInRequest']);
   has StageName => (is => 'ro', isa => 'Str', request_name => 'stageName', traits => ['NameInRequest'], required => 1);
@@ -51,9 +54,23 @@ Represents an API stage.
   Settings for logging access in this stage.
 
 
+=head2 ApiGatewayManaged => Bool
+
+  Specifies whether a stage is managed by API Gateway. If you created an
+API using quick create, the $default stage is managed by API Gateway.
+You can't modify the $default stage.
+
+
+=head2 AutoDeploy => Bool
+
+  Specifies whether updates to an API automatically trigger a new
+deployment. The default value is false.
+
+
 =head2 ClientCertificateId => Str
 
-  The identifier of a client certificate for a Stage.
+  The identifier of a client certificate for a Stage. Supported only for
+WebSocket APIs.
 
 
 =head2 CreatedDate => Str
@@ -69,6 +86,7 @@ Represents an API stage.
 =head2 DeploymentId => Str
 
   The identifier of the Deployment that the Stage is associated with.
+Can't be updated if autoDeploy is enabled.
 
 
 =head2 Description => Str
@@ -76,6 +94,12 @@ Represents an API stage.
   The description of the stage.
 
 
+=head2 LastDeploymentStatusMessage => Str
+
+  Describes the status of the last deployment of a stage. Supported only
+for stages with autoDeploy enabled.
+
+
 =head2 LastUpdatedDate => Str
 
   The timestamp when the stage was last updated.
@@ -83,7 +107,7 @@ Represents an API stage.
 
 =head2 RouteSettings => L<Paws::ApiGatewayV2::RouteSettingsMap>
 
-  Route settings for the stage.
+  Route settings for the stage, by routeKey.
 
 
 =head2 B<REQUIRED> StageName => Str
@@ -95,14 +119,13 @@ Represents an API stage.
 
   A map that defines the stage variables for a stage resource. Variable
 names can have alphanumeric and underscore characters, and the values
-must match [A-Za-z0-9-._~:/?#&=,]+.
+must match [A-Za-z0-9-._~:/?#&=,]+. Supported only for WebSocket APIs.
 
 
 =head2 Tags => L<Paws::ApiGatewayV2::Tags>
 
-  The key-value map of strings. The valid character set is
-[a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not
-start with aws:. The tag value can be up to 256 characters..
+  The collection of tags. Each tag element is associated with a given
+resource.
 
 
 
