@@ -9,6 +9,7 @@ package Paws::ApiGatewayV2::UpdateIntegrationInput;
   has IntegrationType => (is => 'ro', isa => 'Str', request_name => 'integrationType', traits => ['NameInRequest']);
   has IntegrationUri => (is => 'ro', isa => 'Str', request_name => 'integrationUri', traits => ['NameInRequest']);
   has PassthroughBehavior => (is => 'ro', isa => 'Str', request_name => 'passthroughBehavior', traits => ['NameInRequest']);
+  has PayloadFormatVersion => (is => 'ro', isa => 'Str', request_name => 'payloadFormatVersion', traits => ['NameInRequest']);
   has RequestParameters => (is => 'ro', isa => 'Paws::ApiGatewayV2::IntegrationParameters', request_name => 'requestParameters', traits => ['NameInRequest']);
   has RequestTemplates => (is => 'ro', isa => 'Paws::ApiGatewayV2::TemplateMap', request_name => 'requestTemplates', traits => ['NameInRequest']);
   has TemplateSelectionExpression => (is => 'ro', isa => 'Str', request_name => 'templateSelectionExpression', traits => ['NameInRequest']);
@@ -62,9 +63,9 @@ public routable internet.
 
 =head2 ContentHandlingStrategy => Str
 
-  Specifies how to handle response payload content type conversions.
-Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the
-following behaviors:
+  Supported only for WebSocket APIs. Specifies how to handle response
+payload content type conversions. Supported values are
+CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors:
 
 CONVERT_TO_BINARY: Converts a response payload from a Base64-encoded
 string to the corresponding binary blob.
@@ -105,7 +106,7 @@ AWS: for integrating the route or method request with an AWS service
 action, including the Lambda function-invoking action. With the Lambda
 function-invoking action, this is referred to as the Lambda custom
 integration. With any other AWS service action, this is known as AWS
-integration.
+integration. Supported only for WebSocket APIs.
 
 AWS_PROXY: for integrating the route or method request with the Lambda
 function-invoking action with the client request passed through as-is.
@@ -113,14 +114,15 @@ This integration is also referred to as Lambda proxy integration.
 
 HTTP: for integrating the route or method request with an HTTP
 endpoint. This integration is also referred to as the HTTP custom
-integration.
+integration. Supported only for WebSocket APIs.
 
 HTTP_PROXY: for integrating route or method request with an HTTP
 endpoint, with the client request passed through as-is. This is also
 referred to as HTTP proxy integration.
 
 MOCK: for integrating the route or method request with API Gateway as a
-"loopback" endpoint without invoking any backend.
+"loopback" endpoint without invoking any backend. Supported only for
+WebSocket APIs.
 
 
 =head2 IntegrationUri => Str
@@ -134,7 +136,7 @@ MOCK: for integrating the route or method request with API Gateway as a
 Content-Type header in the request, and the available mapping templates
 specified as the requestTemplates property on the Integration resource.
 There are three valid values: WHEN_NO_MATCH, WHEN_NO_TEMPLATES, and
-NEVER.
+NEVER. Supported only for WebSocket APIs.
 
 WHEN_NO_MATCH passes the request body for unmapped content types
 through to the integration backend without transformation.
@@ -148,6 +150,12 @@ content type defined, unmapped content types will be rejected with the
 same HTTP 415 Unsupported Media Type response.
 
 
+=head2 PayloadFormatVersion => Str
+
+  Specifies the format of the payload sent to an integration. Required
+for HTTP APIs. Currently, the only supported value is 1.0.
+
+
 =head2 RequestParameters => L<Paws::ApiGatewayV2::IntegrationParameters>
 
   A key-value map specifying request parameters that are passed from the
@@ -157,7 +165,8 @@ value or static value that must be enclosed within single quotes and
 pre-encoded as required by the backend. The method request parameter
 value must match the pattern of method.request.{location}.{name} ,
 where {location} is querystring, path, or header; and {name} must be a
-valid and unique method request parameter name.
+valid and unique method request parameter name. Supported only for
+WebSocket APIs.
 
 
 =head2 RequestTemplates => L<Paws::ApiGatewayV2::TemplateMap>
@@ -165,7 +174,7 @@ valid and unique method request parameter name.
   Represents a map of Velocity templates that are applied on the request
 payload based on the value of the Content-Type header sent by the
 client. The content type value is the key in this map, and the template
-(as a String) is the value.
+(as a String) is the value. Supported only for WebSocket APIs.
 
 
 =head2 TemplateSelectionExpression => Str
@@ -176,7 +185,8 @@ client. The content type value is the key in this map, and the template
 =head2 TimeoutInMillis => Int
 
   Custom timeout between 50 and 29,000 milliseconds. The default value is
-29,000 milliseconds or 29 seconds.
+29,000 milliseconds or 29 seconds for WebSocket APIs. The default value
+is 5,000 milliseconds, or 5 seconds for HTTP APIs.
 
 
 
