@@ -2,6 +2,7 @@ package Paws::AppMesh::HttpRoute;
   use Moose;
   has Action => (is => 'ro', isa => 'Paws::AppMesh::HttpRouteAction', request_name => 'action', traits => ['NameInRequest'], required => 1);
   has Match => (is => 'ro', isa => 'Paws::AppMesh::HttpRouteMatch', request_name => 'match', traits => ['NameInRequest'], required => 1);
+  has RetryPolicy => (is => 'ro', isa => 'Paws::AppMesh::HttpRetryPolicy', request_name => 'retryPolicy', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -21,7 +22,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::AppMesh::HttpRoute object:
 
-  $service_obj->Method(Att1 => { Action => $value, ..., Match => $value  });
+  $service_obj->Method(Att1 => { Action => $value, ..., RetryPolicy => $value  });
 
 =head3 Results returned from an API call
 
@@ -32,19 +33,24 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::AppMesh::Ht
 
 =head1 DESCRIPTION
 
-An object representing the HTTP routing specification for a route.
+An object that represents an HTTP or HTTP2 route type.
 
 =head1 ATTRIBUTES
 
 
 =head2 B<REQUIRED> Action => L<Paws::AppMesh::HttpRouteAction>
 
-  The action to take if a match is determined.
+  An object that represents the action to take if a match is determined.
 
 
 =head2 B<REQUIRED> Match => L<Paws::AppMesh::HttpRouteMatch>
 
-  The criteria for determining an HTTP request match.
+  An object that represents the criteria for determining a request match.
+
+
+=head2 RetryPolicy => L<Paws::AppMesh::HttpRetryPolicy>
+
+  An object that represents a retry policy.
 
 
 
