@@ -1,11 +1,13 @@
 
 package Paws::AppStream::UpdateStack;
   use Moose;
+  has AccessEndpoints => (is => 'ro', isa => 'ArrayRef[Paws::AppStream::AccessEndpoint]');
   has ApplicationSettings => (is => 'ro', isa => 'Paws::AppStream::ApplicationSettings');
   has AttributesToDelete => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
   has DeleteStorageConnectors => (is => 'ro', isa => 'Bool');
   has Description => (is => 'ro', isa => 'Str');
   has DisplayName => (is => 'ro', isa => 'Str');
+  has EmbedHostDomains => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
   has FeedbackURL => (is => 'ro', isa => 'Str');
   has Name => (is => 'ro', isa => 'Str', required => 1);
   has RedirectURL => (is => 'ro', isa => 'Str');
@@ -37,26 +39,36 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $appstream2 = Paws->service('AppStream');
     my $UpdateStackResult = $appstream2->UpdateStack(
-      Name                => 'MyString',
+      Name            => 'MyString',
+      AccessEndpoints => [
+        {
+          EndpointType => 'STREAMING',    # values: STREAMING
+          VpceId       => 'MyString',     # min: 1
+        },
+        ...
+      ],                                  # OPTIONAL
       ApplicationSettings => {
         Enabled       => 1,
         SettingsGroup => 'MySettingsGroup',    # max: 100; OPTIONAL
       },    # OPTIONAL
       AttributesToDelete => [
         'STORAGE_CONNECTORS',
-        ... # values: STORAGE_CONNECTORS, STORAGE_CONNECTOR_HOMEFOLDERS, STORAGE_CONNECTOR_GOOGLE_DRIVE, STORAGE_CONNECTOR_ONE_DRIVE, REDIRECT_URL, FEEDBACK_URL, THEME_NAME, USER_SETTINGS
+        ... # values: STORAGE_CONNECTORS, STORAGE_CONNECTOR_HOMEFOLDERS, STORAGE_CONNECTOR_GOOGLE_DRIVE, STORAGE_CONNECTOR_ONE_DRIVE, REDIRECT_URL, FEEDBACK_URL, THEME_NAME, USER_SETTINGS, EMBED_HOST_DOMAINS, IAM_ROLE_ARN, ACCESS_ENDPOINTS
       ],    # OPTIONAL
       DeleteStorageConnectors => 1,                  # OPTIONAL
       Description             => 'MyDescription',    # OPTIONAL
       DisplayName             => 'MyDisplayName',    # OPTIONAL
-      FeedbackURL             => 'MyFeedbackURL',    # OPTIONAL
-      RedirectURL             => 'MyRedirectURL',    # OPTIONAL
-      StorageConnectors       => [
+      EmbedHostDomains        => [
+        'MyEmbedHostDomain', ...                     # max: 128
+      ],                                             # OPTIONAL
+      FeedbackURL       => 'MyFeedbackURL',          # OPTIONAL
+      RedirectURL       => 'MyRedirectURL',          # OPTIONAL
+      StorageConnectors => [
         {
           ConnectorType =>
             'HOMEFOLDERS',    # values: HOMEFOLDERS, GOOGLE_DRIVE, ONE_DRIVE
           Domains => [
-            'MyDomain', ...    # max: 64
+            'MyDomain', ...    # min: 1, max: 64
           ],                   # max: 10; OPTIONAL
           ResourceIdentifier => 'MyResourceIdentifier',    # min: 1; OPTIONAL
         },
@@ -84,6 +96,14 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/app
 =head1 ATTRIBUTES
 
 
+=head2 AccessEndpoints => ArrayRef[L<Paws::AppStream::AccessEndpoint>]
+
+The list of interface VPC endpoint (interface endpoint) objects. Users
+of the stack can connect to AppStream 2.0 only through the specified
+endpoints.
+
+
+
 =head2 ApplicationSettings => L<Paws::AppStream::ApplicationSettings>
 
 The persistent application settings for users of a stack. When these
@@ -117,6 +137,14 @@ The stack name to display.
 
 
 
+=head2 EmbedHostDomains => ArrayRef[Str|Undef]
+
+The domains where AppStream 2.0 streaming sessions can be embedded in
+an iframe. You must approve the domains that you want to host embedded
+AppStream 2.0 streaming sessions.
+
+
+
 =head2 FeedbackURL => Str
 
 The URL that users are redirected to after they choose the Send
