@@ -2,12 +2,14 @@
 package Paws::AppSync::CreateResolver;
   use Moose;
   has ApiId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'apiId', required => 1);
+  has CachingConfig => (is => 'ro', isa => 'Paws::AppSync::CachingConfig', traits => ['NameInRequest'], request_name => 'cachingConfig');
   has DataSourceName => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'dataSourceName');
   has FieldName => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'fieldName', required => 1);
   has Kind => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'kind');
   has PipelineConfig => (is => 'ro', isa => 'Paws::AppSync::PipelineConfig', traits => ['NameInRequest'], request_name => 'pipelineConfig');
   has RequestMappingTemplate => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'requestMappingTemplate', required => 1);
   has ResponseMappingTemplate => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'responseMappingTemplate');
+  has SyncConfig => (is => 'ro', isa => 'Paws::AppSync::SyncConfig', traits => ['NameInRequest'], request_name => 'syncConfig');
   has TypeName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'typeName', required => 1);
 
   use MooseX::ClassAttribute;
@@ -40,12 +42,23 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       FieldName              => 'MyResourceName',
       RequestMappingTemplate => 'MyMappingTemplate',
       TypeName               => 'MyResourceName',
-      DataSourceName         => 'MyResourceName',      # OPTIONAL
-      Kind                   => 'UNIT',                # OPTIONAL
-      PipelineConfig         => {
-        Functions => [ 'MyString', ... ],              # OPTIONAL
+      CachingConfig          => {
+        CachingKeys => [ 'MyString', ... ],    # OPTIONAL
+        Ttl         => 1,                      # OPTIONAL
+      },    # OPTIONAL
+      DataSourceName => 'MyResourceName',    # OPTIONAL
+      Kind           => 'UNIT',              # OPTIONAL
+      PipelineConfig => {
+        Functions => [ 'MyString', ... ],    # OPTIONAL
       },    # OPTIONAL
       ResponseMappingTemplate => 'MyMappingTemplate',    # OPTIONAL
+      SyncConfig              => {
+        ConflictDetection => 'VERSION',    # values: VERSION, NONE; OPTIONAL
+        ConflictHandler => 'OPTIMISTIC_CONCURRENCY'
+        ,    # values: OPTIMISTIC_CONCURRENCY, LAMBDA, AUTOMERGE, NONE; OPTIONAL
+        LambdaConflictHandlerConfig =>
+          { LambdaConflictHandlerArn => 'MyString', },    # OPTIONAL
+      },    # OPTIONAL
     );
 
     # Results:
@@ -65,6 +78,12 @@ The ID for the GraphQL API for which the resolver is being created.
 
 
 
+=head2 CachingConfig => L<Paws::AppSync::CachingConfig>
+
+The caching configuration for the resolver.
+
+
+
 =head2 DataSourceName => Str
 
 The name of the data source for which the resolver is being created.
@@ -123,6 +142,12 @@ The mapping template to be used for responses from the data source.
 
 
 
+=head2 SyncConfig => L<Paws::AppSync::SyncConfig>
+
+The C<SyncConfig> for a resolver attached to a versioned datasource.
+
+
+
 =head2 B<REQUIRED> TypeName => Str
 
 The name of the C<Type>.
