@@ -1,8 +1,10 @@
 package Paws::AppSync::DynamodbDataSourceConfig;
   use Moose;
   has AwsRegion => (is => 'ro', isa => 'Str', request_name => 'awsRegion', traits => ['NameInRequest'], required => 1);
+  has DeltaSyncConfig => (is => 'ro', isa => 'Paws::AppSync::DeltaSyncConfig', request_name => 'deltaSyncConfig', traits => ['NameInRequest']);
   has TableName => (is => 'ro', isa => 'Str', request_name => 'tableName', traits => ['NameInRequest'], required => 1);
   has UseCallerCredentials => (is => 'ro', isa => 'Bool', request_name => 'useCallerCredentials', traits => ['NameInRequest']);
+  has Versioned => (is => 'ro', isa => 'Bool', request_name => 'versioned', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -22,7 +24,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::AppSync::DynamodbDataSourceConfig object:
 
-  $service_obj->Method(Att1 => { AwsRegion => $value, ..., UseCallerCredentials => $value  });
+  $service_obj->Method(Att1 => { AwsRegion => $value, ..., Versioned => $value  });
 
 =head3 Results returned from an API call
 
@@ -43,6 +45,11 @@ Describes an Amazon DynamoDB data source configuration.
   The AWS Region.
 
 
+=head2 DeltaSyncConfig => L<Paws::AppSync::DeltaSyncConfig>
+
+  The C<DeltaSyncConfig> for a versioned datasource.
+
+
 =head2 B<REQUIRED> TableName => Str
 
   The table name.
@@ -53,6 +60,12 @@ Describes an Amazon DynamoDB data source configuration.
   Set to TRUE to use Amazon Cognito credentials with this data source.
 
 
+=head2 Versioned => Bool
+
+  Set to TRUE to use Conflict Detection and Resolution with this data
+source.
+
+
 
 =head1 SEE ALSO
 
