@@ -1,5 +1,6 @@
 package Paws::AppSync::Resolver;
   use Moose;
+  has CachingConfig => (is => 'ro', isa => 'Paws::AppSync::CachingConfig', request_name => 'cachingConfig', traits => ['NameInRequest']);
   has DataSourceName => (is => 'ro', isa => 'Str', request_name => 'dataSourceName', traits => ['NameInRequest']);
   has FieldName => (is => 'ro', isa => 'Str', request_name => 'fieldName', traits => ['NameInRequest']);
   has Kind => (is => 'ro', isa => 'Str', request_name => 'kind', traits => ['NameInRequest']);
@@ -7,6 +8,7 @@ package Paws::AppSync::Resolver;
   has RequestMappingTemplate => (is => 'ro', isa => 'Str', request_name => 'requestMappingTemplate', traits => ['NameInRequest']);
   has ResolverArn => (is => 'ro', isa => 'Str', request_name => 'resolverArn', traits => ['NameInRequest']);
   has ResponseMappingTemplate => (is => 'ro', isa => 'Str', request_name => 'responseMappingTemplate', traits => ['NameInRequest']);
+  has SyncConfig => (is => 'ro', isa => 'Paws::AppSync::SyncConfig', request_name => 'syncConfig', traits => ['NameInRequest']);
   has TypeName => (is => 'ro', isa => 'Str', request_name => 'typeName', traits => ['NameInRequest']);
 1;
 
@@ -27,14 +29,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::AppSync::Resolver object:
 
-  $service_obj->Method(Att1 => { DataSourceName => $value, ..., TypeName => $value  });
+  $service_obj->Method(Att1 => { CachingConfig => $value, ..., TypeName => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::AppSync::Resolver object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->DataSourceName
+  $result->Att1->CachingConfig
 
 =head1 DESCRIPTION
 
@@ -43,6 +45,11 @@ Describes a resolver.
 =head1 ATTRIBUTES
 
 
+=head2 CachingConfig => L<Paws::AppSync::CachingConfig>
+
+  The caching configuration for the resolver.
+
+
 =head2 DataSourceName => Str
 
   The resolver data source name.
@@ -96,6 +103,11 @@ sources.
   The response mapping template.
 
 
+=head2 SyncConfig => L<Paws::AppSync::SyncConfig>
+
+  The C<SyncConfig> for a resolver attached to a versioned datasource.
+
+
 =head2 TypeName => Str
 
   The resolver type name.
