@@ -7,6 +7,7 @@ package Paws::ApplicationAutoScaling::ScalableTarget;
   has RoleARN => (is => 'ro', isa => 'Str', required => 1);
   has ScalableDimension => (is => 'ro', isa => 'Str', required => 1);
   has ServiceNamespace => (is => 'ro', isa => 'Str', required => 1);
+  has SuspendedState => (is => 'ro', isa => 'Paws::ApplicationAutoScaling::SuspendedState');
 1;
 
 ### main pod documentation begin ###
@@ -26,7 +27,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::ApplicationAutoScaling::ScalableTarget object:
 
-  $service_obj->Method(Att1 => { CreationTime => $value, ..., ServiceNamespace => $value  });
+  $service_obj->Method(Att1 => { CreationTime => $value, ..., SuspendedState => $value  });
 
 =head3 Results returned from an API call
 
@@ -72,8 +73,8 @@ C<service/default/sample-webapp>.
 
 =item *
 
-Spot fleet request - The resource type is C<spot-fleet-request> and the
-unique identifier is the Spot fleet request ID. Example:
+Spot Fleet request - The resource type is C<spot-fleet-request> and the
+unique identifier is the Spot Fleet request ID. Example:
 C<spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE>.
 
 =item *
@@ -90,12 +91,12 @@ identifier is the fleet name. Example: C<fleet/sample-fleet>.
 =item *
 
 DynamoDB table - The resource type is C<table> and the unique
-identifier is the resource ID. Example: C<table/my-table>.
+identifier is the table name. Example: C<table/my-table>.
 
 =item *
 
 DynamoDB global secondary index - The resource type is C<index> and the
-unique identifier is the resource ID. Example:
+unique identifier is the index name. Example:
 C<table/my-table/index/my-table-index>.
 
 =item *
@@ -105,8 +106,8 @@ identifier is the cluster name. Example: C<cluster:my-db-cluster>.
 
 =item *
 
-Amazon SageMaker endpoint variants - The resource type is C<variant>
-and the unique identifier is the resource ID. Example:
+Amazon SageMaker endpoint variant - The resource type is C<variant> and
+the unique identifier is the resource ID. Example:
 C<endpoint/my-end-point/variant/KMeansClustering>.
 
 =item *
@@ -117,6 +118,19 @@ used to access the resources. The unique identifier is defined by the
 service provider. More information is available in our GitHub
 repository (https://github.com/aws/aws-auto-scaling-custom-resource).
 
+=item *
+
+Amazon Comprehend document classification endpoint - The resource type
+and unique identifier are specified using the endpoint ARN. Example:
+C<arn:aws:comprehend:us-west-2:123456789012:document-classifier-endpoint/EXAMPLE>.
+
+=item *
+
+Lambda provisioned concurrency - The resource type is C<function> and
+the unique identifier is the function name with a function version or
+alias name suffix that is not C<$LATEST>. Example:
+C<function:my-function:prod> or C<function:my-function:1>.
+
 =back
 
 
@@ -141,7 +155,7 @@ C<ecs:service:DesiredCount> - The desired task count of an ECS service.
 =item *
 
 C<ec2:spot-fleet-request:TargetCapacity> - The target capacity of a
-Spot fleet request.
+Spot Fleet request.
 
 =item *
 
@@ -189,6 +203,17 @@ for an Amazon SageMaker model endpoint variant.
 C<custom-resource:ResourceType:Property> - The scalable dimension for a
 custom resource provided by your own application or service.
 
+=item *
+
+C<comprehend:document-classifier-endpoint:DesiredInferenceUnits> - The
+number of inference units for an Amazon Comprehend document
+classification endpoint.
+
+=item *
+
+C<lambda:function:ProvisionedConcurrency> - The provisioned concurrency
+for a Lambda function.
+
 =back
 
 
@@ -198,10 +223,15 @@ custom resource provided by your own application or service.
   The namespace of the AWS service that provides the resource or
 C<custom-resource> for a resource provided by your own application or
 service. For more information, see AWS Service Namespaces
-(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#genref-aws-service-namespaces)
+(http://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#genref-aws-service-namespaces)
 in the I<Amazon Web Services General Reference>.
 
 
+=head2 SuspendedState => L<Paws::ApplicationAutoScaling::SuspendedState>
+
+  
+
+
 
 =head1 SEE ALSO
 
