@@ -4,10 +4,12 @@ package Paws::AutoScaling::AutoScalingInstanceDetails;
   has AvailabilityZone => (is => 'ro', isa => 'Str', required => 1);
   has HealthStatus => (is => 'ro', isa => 'Str', required => 1);
   has InstanceId => (is => 'ro', isa => 'Str', required => 1);
+  has InstanceType => (is => 'ro', isa => 'Str');
   has LaunchConfigurationName => (is => 'ro', isa => 'Str');
   has LaunchTemplate => (is => 'ro', isa => 'Paws::AutoScaling::LaunchTemplateSpecification');
   has LifecycleState => (is => 'ro', isa => 'Str', required => 1);
   has ProtectedFromScaleIn => (is => 'ro', isa => 'Bool', required => 1);
+  has WeightedCapacity => (is => 'ro', isa => 'Str');
 1;
 
 ### main pod documentation begin ###
@@ -27,7 +29,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::AutoScaling::AutoScalingInstanceDetails object:
 
-  $service_obj->Method(Att1 => { AutoScalingGroupName => $value, ..., ProtectedFromScaleIn => $value  });
+  $service_obj->Method(Att1 => { AutoScalingGroupName => $value, ..., WeightedCapacity => $value  });
 
 =head3 Results returned from an API call
 
@@ -66,6 +68,11 @@ terminate and replace it.
   The ID of the instance.
 
 
+=head2 InstanceType => Str
+
+  The instance type of the EC2 instance.
+
+
 =head2 LaunchConfigurationName => Str
 
   The launch configuration used to launch the instance. This value is not
@@ -88,6 +95,14 @@ available if you attached the instance to the Auto Scaling group.
 EC2 Auto Scaling when scaling in.
 
 
+=head2 WeightedCapacity => Str
+
+  The number of capacity units contributed by the instance based on its
+instance type.
+
+Valid Range: Minimum value of 1. Maximum value of 999.
+
+
 
 =head1 SEE ALSO
 
