@@ -35,16 +35,16 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::AutoScaling
 Describes a mixed instances policy for an Auto Scaling group. With
 mixed instances, your Auto Scaling group can provision a combination of
 On-Demand Instances and Spot Instances across multiple instance types.
-Used in combination with CreateAutoScalingGroup. For more information,
-see Auto Scaling Groups with Multiple Instance Types and Purchase
-Options
+For more information, see Auto Scaling Groups with Multiple Instance
+Types and Purchase Options
 (https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-purchase-options.html)
 in the I<Amazon EC2 Auto Scaling User Guide>.
 
-When you create your Auto Scaling group, you can specify a launch
-configuration or template as a parameter for the top-level object, or
-you can specify a mixed instances policy, but not both at the same
-time.
+You can create a mixed instances policy for a new Auto Scaling group,
+or you can create it for an existing group by updating the group to
+specify C<MixedInstancesPolicy> as the top-level parameter instead of a
+launch configuration or template. For more information, see
+CreateAutoScalingGroup and UpdateAutoScalingGroup.
 
 =head1 ATTRIBUTES
 
@@ -53,16 +53,16 @@ time.
 
   The instances distribution to use.
 
-If you leave this parameter unspecified when creating the group, the
-default values are used.
+If you leave this parameter unspecified, the value for each parameter
+in C<InstancesDistribution> uses a default value.
 
 
 =head2 LaunchTemplate => L<Paws::AutoScaling::LaunchTemplate>
 
-  The launch template and overrides.
+  The launch template and instance types (overrides).
 
-This parameter is required when creating an Auto Scaling group with a
-mixed instances policy, but is not required when updating the group.
+This parameter must be specified when creating a mixed instances
+policy.
 
 
 
