@@ -5,6 +5,7 @@ package Paws::Batch::ContainerProperties;
   has Image => (is => 'ro', isa => 'Str', request_name => 'image', traits => ['NameInRequest']);
   has InstanceType => (is => 'ro', isa => 'Str', request_name => 'instanceType', traits => ['NameInRequest']);
   has JobRoleArn => (is => 'ro', isa => 'Str', request_name => 'jobRoleArn', traits => ['NameInRequest']);
+  has LinuxParameters => (is => 'ro', isa => 'Paws::Batch::LinuxParameters', request_name => 'linuxParameters', traits => ['NameInRequest']);
   has Memory => (is => 'ro', isa => 'Int', request_name => 'memory', traits => ['NameInRequest']);
   has MountPoints => (is => 'ro', isa => 'ArrayRef[Paws::Batch::MountPoint]', request_name => 'mountPoints', traits => ['NameInRequest']);
   has Privileged => (is => 'ro', isa => 'Bool', request_name => 'privileged', traits => ['NameInRequest']);
@@ -133,6 +134,12 @@ type. This parameter is not valid for single-node container jobs.
 assume for AWS permissions.
 
 
+=head2 LinuxParameters => L<Paws::Batch::LinuxParameters>
+
+  Linux-specific modifications that are applied to the container, such as
+details for device mappings.
+
+
 =head2 Memory => Int
 
   The hard limit (in MiB) of memory to present to the container. If your
