@@ -1,7 +1,9 @@
 package Paws::Chime::UpdateUserRequestItem;
   use Moose;
+  has AlexaForBusinessMetadata => (is => 'ro', isa => 'Paws::Chime::AlexaForBusinessMetadata');
   has LicenseType => (is => 'ro', isa => 'Str');
   has UserId => (is => 'ro', isa => 'Str', required => 1);
+  has UserType => (is => 'ro', isa => 'Str');
 1;
 
 ### main pod documentation begin ###
@@ -21,14 +23,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::Chime::UpdateUserRequestItem object:
 
-  $service_obj->Method(Att1 => { LicenseType => $value, ..., UserId => $value  });
+  $service_obj->Method(Att1 => { AlexaForBusinessMetadata => $value, ..., UserType => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::Chime::UpdateUserRequestItem object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->LicenseType
+  $result->Att1->AlexaForBusinessMetadata
 
 =head1 DESCRIPTION
 
@@ -38,6 +40,11 @@ action.
 =head1 ATTRIBUTES
 
 
+=head2 AlexaForBusinessMetadata => L<Paws::Chime::AlexaForBusinessMetadata>
+
+  The Alexa for Business metadata.
+
+
 =head2 LicenseType => Str
 
   The user license type.
@@ -48,6 +55,11 @@ action.
   The user ID.
 
 
+=head2 UserType => Str
+
+  The user type.
+
+
 
 =head1 SEE ALSO
 
