@@ -49,7 +49,7 @@ How long CloudFront caches HTTP status codes in the 4xx and 5xx range.
 
 For more information about custom error pages, see Customizing Error
 Responses
-(http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/custom-error-pages.html)
+(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/custom-error-pages.html)
 in the I<Amazon CloudFront Developer Guide>.
 
 =head1 ATTRIBUTES
