@@ -41,8 +41,8 @@ target origin that match the C<PathPattern> for this cache behavior,
 specify C<true> for C<Enabled>, and specify the applicable values for
 C<Quantity> and C<Items>. For more information, see Serving Private
 Content through CloudFront
-(http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html)
-in the I<Amazon Amazon CloudFront Developer Guide>.
+(https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html)
+in the I< Amazon CloudFront Developer Guide>.
 
 If you don't want to require signed URLs in requests for objects that
 match C<PathPattern>, specify C<false> for C<Enabled> and C<0> for
@@ -54,7 +54,9 @@ as applicable, and specify all of the trusted signers that you want to
 include in the updated distribution.
 
 For more information about updating the distribution configuration, see
-DistributionConfig .
+DistributionConfig
+(https://docs.aws.amazon.com/cloudfront/latest/APIReference/DistributionConfig.html)
+in the I<Amazon CloudFront API Reference>.
 
 =head1 ATTRIBUTES
 
