@@ -52,11 +52,12 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               MetricName => 'MyMetricName',       # min: 1, max: 255; OPTIONAL
               Namespace  => 'MyNamespace',        # min: 1, max: 255; OPTIONAL
             },
-            Period => 1,                          # min: 1
+            Period => 1,                          # min: 1; OPTIONAL
             Stat   => 'MyStat',
             Unit   => 'Seconds'
             , # values: Seconds, Microseconds, Milliseconds, Bytes, Kilobytes, Megabytes, Gigabytes, Terabytes, Bits, Kilobits, Megabits, Gigabits, Terabits, Percent, Count, Bytes/Second, Kilobytes/Second, Megabytes/Second, Gigabytes/Second, Terabytes/Second, Bits/Second, Kilobits/Second, Megabits/Second, Gigabits/Second, Terabits/Second, Count/Second, None; OPTIONAL
           },    # OPTIONAL
+          Period     => 1,    # min: 1; OPTIONAL
           ReturnData => 1,    # OPTIONAL
         },
         ...
@@ -84,6 +85,9 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/mon
 
 The time stamp indicating the latest data to be returned.
 
+The value specified is exclusive; results include data points up to the
+specified time stamp.
+
 For better performance, specify C<StartTime> and C<EndTime> values that
 align with the value of the metric's C<Period> and sync up with the
 beginning and end of an hour. For example, if the C<Period> of a metric
@@ -129,6 +133,40 @@ Valid values are: C<"TimestampDescending">, C<"TimestampAscending">
 
 The time stamp indicating the earliest data to be returned.
 
+The value specified is inclusive; results include data points with the
+specified time stamp.
+
+CloudWatch rounds the specified time stamp as follows:
+
+=over
+
+=item *
+
+Start time less than 15 days ago - Round down to the nearest whole
+minute. For example, 12:32:34 is rounded down to 12:32:00.
+
+=item *
+
+Start time between 15 and 63 days ago - Round down to the nearest
+5-minute clock interval. For example, 12:32:34 is rounded down to
+12:30:00.
+
+=item *
+
+Start time greater than 63 days ago - Round down to the nearest 1-hour
+clock interval. For example, 12:32:34 is rounded down to 12:00:00.
+
+=back
+
+If you set C<Period> to 5, 10, or 30, the start time of your request is
+rounded down to the nearest time that corresponds to even 5-, 10-, or
+30-second divisions of a minute. For example, if you make a query at
+(HH:mm:ss) 01:05:23 for the previous 10-second period, the start time
+of your request is rounded down and you receive data from 01:05:10 to
+01:05:20. If you make a query at 15:07:17 for the previous 5 minutes of
+data, using a period of 5 seconds, you receive data timestamped between
+15:02:15 and 15:07:15.
+
 For better performance, specify C<StartTime> and C<EndTime> values that
 align with the value of the metric's C<Period> and sync up with the
 beginning and end of an hour. For example, if the C<Period> of a metric
