@@ -1,6 +1,7 @@
 
 package Paws::CloudWatchEvents::PutTargets;
   use Moose;
+  has EventBusName => (is => 'ro', isa => 'Str');
   has Rule => (is => 'ro', isa => 'Str', required => 1);
   has Targets => (is => 'ro', isa => 'ArrayRef[Paws::CloudWatchEvents::Target]', required => 1);
 
@@ -20,7 +21,7 @@ Paws::CloudWatchEvents::PutTargets - Arguments for method PutTargets on L<Paws::
 =head1 DESCRIPTION
 
 This class represents the parameters used for calling the method PutTargets on the
-L<Amazon CloudWatch Events|Paws::CloudWatchEvents> service. Use the attributes of this class
+L<Amazon EventBridge|Paws::CloudWatchEvents> service. Use the attributes of this class
 as arguments to method PutTargets.
 
 You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to PutTargets.
@@ -92,7 +93,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],
-
+      EventBusName => 'MyEventBusName',    # OPTIONAL
     );
 
     # Results:
@@ -107,6 +108,13 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/eve
 =head1 ATTRIBUTES
 
 
+=head2 EventBusName => Str
+
+The name of the event bus associated with the rule. If you omit this,
+the default event bus is used.
+
+
+
 =head2 B<REQUIRED> Rule => Str
 
 The name of the rule.
