@@ -65,10 +65,41 @@ C<BUILD_GENERAL1_MEDIUM>: Use up to 7 GB memory and 4 vCPUs for builds.
 
 =item *
 
-C<BUILD_GENERAL1_LARGE>: Use up to 15 GB memory and 8 vCPUs for builds.
+C<BUILD_GENERAL1_LARGE>: Use up to 16 GB memory and 8 vCPUs for builds,
+depending on your environment type.
+
+=item *
+
+C<BUILD_GENERAL1_2XLARGE>: Use up to 145 GB memory, 72 vCPUs, and 824
+GB of SSD storage for builds. This compute type supports Docker images
+up to 100 GB uncompressed.
 
 =back
 
+If you use C<BUILD_GENERAL1_LARGE>:
+
+=over
+
+=item *
+
+For environment type C<LINUX_CONTAINER>, you can use up to 15 GB memory
+and 8 vCPUs for builds.
+
+=item *
+
+For environment type C<LINUX_GPU_CONTAINER>, you can use up to 255 GB
+memory, 32 vCPUs, and 4 NVIDIA Tesla V100 GPUs for builds.
+
+=item *
+
+For environment type C<ARM_CONTAINER>, you can use up to 16 GB memory
+and 8 vCPUs on ARM-based processors for builds.
+
+=back
+
+For more information, see Build Environment Compute Types
+(https://docs.aws.amazon.com/codebuild/latest/userguide/build-env-ref-compute-types.html)
+in the I<AWS CodeBuild User Guide.>
 
 
 =head2 EnvironmentVariables => ArrayRef[L<Paws::CodeBuild::EnvironmentVariable>]
@@ -129,15 +160,13 @@ you must use CODEBUILD credentials.
 =head2 PrivilegedMode => Bool
 
   Enables running the Docker daemon inside a Docker container. Set to
-true only if the build project is be used to build Docker images, and
-the specified build environment image is not provided by AWS CodeBuild
-with Docker support. Otherwise, all associated builds that attempt to
-interact with the Docker daemon fail. You must also start the Docker
-daemon so that builds can interact with it. One way to do this is to
-initialize the Docker daemon during the install phase of your build
-spec by running the following build commands. (Do not run these
-commands if the specified build environment image is provided by AWS
-CodeBuild with Docker support.)
+true only if the build project is used to build Docker images.
+Otherwise, a build that attempts to interact with the Docker daemon
+fails. The default setting is C<false>.
+
+You can initialize the Docker daemon during the install phase of your
+build by adding one of the following sets of commands to the install
+phase of your buildspec file:
 
 If the operating system's base image is Ubuntu Linux:
 
@@ -164,6 +193,35 @@ C<- timeout -t 15 sh -c "until docker info; do echo .; sleep 1; done">
 
   The type of build environment to use for related builds.
 
+=over
+
+=item *
+
+The environment type C<ARM_CONTAINER> is available only in regions US
+East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland),
+Asia Pacific (Mumbai), Asia Pacific (Tokyo), Asia Pacific (Sydney), and
+EU (Frankfurt).
+
+=item *
+
+The environment type C<LINUX_CONTAINER> with compute type
+C<build.general1.2xlarge> is available only in regions US East (N.
+Virginia), US East (N. Virginia), US West (Oregon), Canada (Central),
+EU (Ireland), EU (London), EU (Frankfurt), Asia Pacific (Tokyo), Asia
+Pacific (Seoul), Asia Pacific (Singapore), Asia Pacific (Sydney), China
+(Beijing), and China (Ningxia).
+
+=item *
+
+The environment type C<LINUX_GPU_CONTAINER> is available only in
+regions US East (N. Virginia), US East (N. Virginia), US West (Oregon),
+Canada (Central), EU (Ireland), EU (London), EU (Frankfurt), Asia
+Pacific (Tokyo), Asia Pacific (Seoul), Asia Pacific (Singapore), Asia
+Pacific (Sydney) , China (Beijing), and China (Ningxia).
+
+=back
+
+
 
 
 =head1 SEE ALSO
