@@ -55,10 +55,19 @@ should not get or set this information directly.
 
 =head2 Buildspec => Str
 
-  The build spec declaration to use for the builds in this build project.
+  The buildspec file declaration to use for the builds in this build
+project.
 
-If this value is not specified, a build spec must be included along
-with the source code to be built.
+If this value is set, it can be either an inline buildspec definition,
+the path to an alternate buildspec file relative to the value of the
+built-in C<CODEBUILD_SRC_DIR> environment variable, or the path to an
+S3 bucket. The bucket must be in the same AWS Region as the build
+project. Specify the buildspec file using its ARN (for example,
+C<arn:aws:s3:::my-codebuild-sample2/buildspec.yml>). If this value is
+not provided or is set to an empty string, the source code must contain
+a buildspec file in its root directory. For more information, see
+Buildspec File Name and Storage Location
+(https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage).
 
 
 =head2 GitCloneDepth => Int
@@ -96,8 +105,8 @@ this value.
 =item *
 
 For source code in an AWS CodeCommit repository, the HTTPS clone URL to
-the repository that contains the source code and the build spec (for
-example,
+the repository that contains the source code and the buildspec file
+(for example,
 C<https://git-codecommit.I<region-ID>.amazonaws.com/v1/repos/I<repo-name>
 >).
 
@@ -123,7 +132,7 @@ I<bucket-name>/I<path>/I<to>/I<source-code>/I<folder>/>).
 =item *
 
 For source code in a GitHub repository, the HTTPS clone URL to the
-repository that contains the source and the build spec. You must
+repository that contains the source and the buildspec file. You must
 connect your AWS account to your GitHub account. Use the AWS CodeBuild
 console to start creating a build project. When you use the console to
 connect (or reconnect) with GitHub, on the GitHub B<Authorize
@@ -138,7 +147,7 @@ C<auth> object's C<type> value to C<OAUTH>.
 =item *
 
 For source code in a Bitbucket repository, the HTTPS clone URL to the
-repository that contains the source and the build spec. You must
+repository that contains the source and the buildspec file. You must
 connect your AWS account to your Bitbucket account. Use the AWS
 CodeBuild console to start creating a build project. When you use the
 console to connect (or reconnect) with Bitbucket, on the Bitbucket
@@ -159,6 +168,9 @@ source provider. This option is valid only when your source provider is
 GitHub, GitHub Enterprise, or Bitbucket. If this is set and you use a
 different source provider, an invalidInputException is thrown.
 
+The status of a build triggered by a webhook is always reported to your
+source provider.
+
 
 =head2 SourceIdentifier => Str
 
@@ -191,6 +203,11 @@ C<GITHUB>: The source code is in a GitHub repository.
 
 =item *
 
+C<GITHUB_ENTERPRISE>: The source code is in a GitHub Enterprise
+repository.
+
+=item *
+
 C<NO_SOURCE>: The project does not have input source code.
 
 =item *
