@@ -43,7 +43,7 @@ Represents information about an action type.
 
   A category defines what kind of action can be taken in the stage, and
 constrains the provider type for the action. Valid categories are
-limited to one of the values below.
+limited to one of the following values.
 
 
 =head2 B<REQUIRED> Owner => Str
@@ -56,9 +56,8 @@ limited to one of the values below.
   The provider of the service being called by the action. Valid providers
 are determined by the action category. For example, an action in the
 Deploy category type might have a provider of AWS CodeDeploy, which
-would be specified as CodeDeploy. To reference a list of action
-providers by action type, see Valid Action Types and Providers in
-CodePipeline
+would be specified as CodeDeploy. For more information, see Valid
+Action Types and Providers in CodePipeline
 (https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html#actions-valid-providers).
 
 
