@@ -5,6 +5,8 @@ package Paws::CodePipeline::PipelineExecutionSummary;
   has SourceRevisions => (is => 'ro', isa => 'ArrayRef[Paws::CodePipeline::SourceRevision]', request_name => 'sourceRevisions', traits => ['NameInRequest']);
   has StartTime => (is => 'ro', isa => 'Str', request_name => 'startTime', traits => ['NameInRequest']);
   has Status => (is => 'ro', isa => 'Str', request_name => 'status', traits => ['NameInRequest']);
+  has StopTrigger => (is => 'ro', isa => 'Paws::CodePipeline::StopExecutionTrigger', request_name => 'stopTrigger', traits => ['NameInRequest']);
+  has Trigger => (is => 'ro', isa => 'Paws::CodePipeline::ExecutionTrigger', request_name => 'trigger', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -24,7 +26,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::CodePipeline::PipelineExecutionSummary object:
 
-  $service_obj->Method(Att1 => { LastUpdateTime => $value, ..., Status => $value  });
+  $service_obj->Method(Att1 => { LastUpdateTime => $value, ..., Trigger => $value  });
 
 =head3 Results returned from an API call
 
@@ -75,13 +77,29 @@ InProgress: The pipeline execution is currently running.
 
 =item *
 
+Stopped: The pipeline execution was manually stopped. For more
+information, see Stopped Executions
+(https://docs.aws.amazon.com/codepipeline/latest/userguide/concepts.html#concepts-executions-stopped).
+
+=item *
+
+Stopping: The pipeline execution received a request to be manually
+stopped. Depending on the selected stop mode, the execution is either
+completing or abandoning in-progress actions. For more information, see
+Stopped Executions
+(https://docs.aws.amazon.com/codepipeline/latest/userguide/concepts.html#concepts-executions-stopped).
+
+=item *
+
 Succeeded: The pipeline execution was completed successfully.
 
 =item *
 
 Superseded: While this pipeline execution was waiting for the next
 stage to be completed, a newer pipeline execution advanced and
-continued through the pipeline instead.
+continued through the pipeline instead. For more information, see
+Superseded Executions
+(https://docs.aws.amazon.com/codepipeline/latest/userguide/concepts.html#concepts-superseded).
 
 =item *
 
@@ -91,6 +109,17 @@ Failed: The pipeline execution was not completed successfully.
 
 
 
+=head2 StopTrigger => L<Paws::CodePipeline::StopExecutionTrigger>
+
+  The interaction that stopped a pipeline execution.
+
+
+=head2 Trigger => L<Paws::CodePipeline::ExecutionTrigger>
+
+  The interaction or event that started a pipeline execution, such as
+automated change detection or a C<StartPipelineExecution> API call.
+
+
 
 =head1 SEE ALSO
 
