@@ -57,15 +57,14 @@ Represents information about the job data for a partner action.
 
   Represents an AWS session credentials object. These credentials are
 temporary credentials that are issued by AWS Secure Token Service
-(STS). They can be used to access input and output artifacts in the
-Amazon S3 bucket used to store artifact for the pipeline in AWS
-CodePipeline.
+(STS). They can be used to access input and output artifacts in the S3
+bucket used to store artifact for the pipeline in AWS CodePipeline.
 
 
 =head2 ContinuationToken => Str
 
   A system-generated token, such as a AWS CodeDeploy deployment ID, that
-a job requires in order to continue the job asynchronously.
+a job requires to continue the job asynchronously.
 
 
 =head2 EncryptionKey => L<Paws::CodePipeline::EncryptionKey>
@@ -77,17 +76,17 @@ key. This is optional and might not be present.
 
 =head2 InputArtifacts => ArrayRef[L<Paws::CodePipeline::Artifact>]
 
-  The name of the artifact that will be worked upon by the action, if
-any. This name might be system-generated, such as "MyApp", or might be
-defined by the user when the action is created. The input artifact name
-must match the name of an output artifact generated by an action in an
+  The name of the artifact that is worked on by the action, if any. This
+name might be system-generated, such as "MyApp", or it might be defined
+by the user when the action is created. The input artifact name must
+match the name of an output artifact generated by an action in an
 earlier action or stage of the pipeline.
 
 
 =head2 OutputArtifacts => ArrayRef[L<Paws::CodePipeline::Artifact>]
 
-  The name of the artifact that will be the result of the action, if any.
-This name might be system-generated, such as "MyBuiltApp", or might be
+  The name of the artifact that is the result of the action, if any. This
+name might be system-generated, such as "MyBuiltApp", or it might be
 defined by the user when the action is created.
 
 
