@@ -1,6 +1,7 @@
 
 package Paws::CognitoIdp::AdminCreateUser;
   use Moose;
+  has ClientMetadata => (is => 'ro', isa => 'Paws::CognitoIdp::ClientMetadataType');
   has DesiredDeliveryMediums => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
   has ForceAliasCreation => (is => 'ro', isa => 'Bool');
   has MessageAction => (is => 'ro', isa => 'Str');
@@ -35,8 +36,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $cognito-idp = Paws->service('CognitoIdp');
     my $AdminCreateUserResponse = $cognito -idp->AdminCreateUser(
-      UserPoolId             => 'MyUserPoolIdType',
-      Username               => 'MyUsernameType',
+      UserPoolId     => 'MyUserPoolIdType',
+      Username       => 'MyUsernameType',
+      ClientMetadata => { 'MyStringType' => 'MyStringType', },    # OPTIONAL
       DesiredDeliveryMediums => [
         'SMS', ...    # values: SMS, EMAIL
       ],              # OPTIONAL
@@ -70,6 +72,52 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/cog
 =head1 ATTRIBUTES
 
 
+=head2 ClientMetadata => L<Paws::CognitoIdp::ClientMetadataType>
+
+A map of custom key-value pairs that you can provide as input for any
+custom workflows that this action triggers.
+
+You create custom workflows by assigning AWS Lambda functions to user
+pool triggers. When you use the AdminCreateUser API action, Amazon
+Cognito invokes the function that is assigned to the I<pre sign-up>
+trigger. When Amazon Cognito invokes this function, it passes a JSON
+payload, which the function receives as input. This payload contains a
+C<clientMetadata> attribute, which provides the data that you assigned
+to the ClientMetadata parameter in your AdminCreateUser request. In
+your function code in AWS Lambda, you can process the C<clientMetadata>
+value to enhance your workflow for your specific needs.
+
+For more information, see Customizing User Pool Workflows with Lambda
+Triggers
+(https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html)
+in the I<Amazon Cognito Developer Guide>.
+
+Take the following limitations into consideration when you use the
+ClientMetadata parameter:
+
+=over
+
+=item *
+
+Amazon Cognito does not store the ClientMetadata value. This data is
+available only to AWS Lambda triggers that are assigned to a user pool
+to support custom workflows. If your user pool configuration does not
+include triggers, the ClientMetadata parameter serves no purpose.
+
+=item *
+
+Amazon Cognito does not validate the ClientMetadata value.
+
+=item *
+
+Amazon Cognito does not encrypt the the ClientMetadata value, so don't
+use it to provide sensitive information.
+
+=back
+
+
+
+
 =head2 DesiredDeliveryMediums => ArrayRef[Str|Undef]
 
 Specify C<"EMAIL"> if email will be used to send the welcome message.
