@@ -5,6 +5,7 @@ package Paws::CognitoIdp::AdminRespondToAuthChallenge;
   has ChallengeName => (is => 'ro', isa => 'Str', required => 1);
   has ChallengeResponses => (is => 'ro', isa => 'Paws::CognitoIdp::ChallengeResponsesType');
   has ClientId => (is => 'ro', isa => 'Str', required => 1);
+  has ClientMetadata => (is => 'ro', isa => 'Paws::CognitoIdp::ClientMetadataType');
   has ContextData => (is => 'ro', isa => 'Paws::CognitoIdp::ContextDataType');
   has Session => (is => 'ro', isa => 'Str');
   has UserPoolId => (is => 'ro', isa => 'Str', required => 1);
@@ -44,6 +45,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       ChallengeResponses => {
         'MyStringType' => 'MyStringType',    # key: OPTIONAL, value: OPTIONAL
       },    # OPTIONAL
+      ClientMetadata => {
+        'MyStringType' => 'MyStringType',    # key: OPTIONAL, value: OPTIONAL
+      },    # OPTIONAL
       ContextData => {
         HttpHeaders => [
           {
@@ -134,6 +138,56 @@ The app client ID.
 
 
 
+=head2 ClientMetadata => L<Paws::CognitoIdp::ClientMetadataType>
+
+A map of custom key-value pairs that you can provide as input for any
+custom workflows that this action triggers.
+
+You create custom workflows by assigning AWS Lambda functions to user
+pool triggers. When you use the AdminRespondToAuthChallenge API action,
+Amazon Cognito invokes any functions that are assigned to the following
+triggers: I<pre sign-up>, I<custom message>, I<post authentication>,
+I<user migration>, I<pre token generation>, I<define auth challenge>,
+I<create auth challenge>, and I<verify auth challenge response>. When
+Amazon Cognito invokes any of these functions, it passes a JSON
+payload, which the function receives as input. This payload contains a
+C<clientMetadata> attribute, which provides the data that you assigned
+to the ClientMetadata parameter in your AdminRespondToAuthChallenge
+request. In your function code in AWS Lambda, you can process the
+C<clientMetadata> value to enhance your workflow for your specific
+needs.
+
+For more information, see Customizing User Pool Workflows with Lambda
+Triggers
+(https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools-working-with-aws-lambda-triggers.html)
+in the I<Amazon Cognito Developer Guide>.
+
+Take the following limitations into consideration when you use the
+ClientMetadata parameter:
+
+=over
+
+=item *
+
+Amazon Cognito does not store the ClientMetadata value. This data is
+available only to AWS Lambda triggers that are assigned to a user pool
+to support custom workflows. If your user pool configuration does not
+include triggers, the ClientMetadata parameter serves no purpose.
+
+=item *
+
+Amazon Cognito does not validate the ClientMetadata value.
+
+=item *
+
+Amazon Cognito does not encrypt the the ClientMetadata value, so don't
+use it to provide sensitive information.
+
+=back
+
+
+
+
 =head2 ContextData => L<Paws::CognitoIdp::ContextDataType>
 
 Contextual data such as the user's device fingerprint, IP address, or
