@@ -32,20 +32,32 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::CognitoIdp:
 
 =head1 DESCRIPTION
 
-The SMS configuration type.
+The SMS configuration type that includes the settings the Cognito User
+Pool needs to call for the Amazon SNS service to send an SMS message
+from your AWS account. The Cognito User Pool makes the request to the
+Amazon SNS Service by using an AWS IAM role that you provide for your
+AWS account.
 
 =head1 ATTRIBUTES
 
 
 =head2 ExternalId => Str
 
-  The external ID.
+  The external ID is a value that we recommend you use to add security to
+your IAM role which is used to call Amazon SNS to send SMS messages for
+your user pool. If you provide an C<ExternalId>, the Cognito User Pool
+will include it when attempting to assume your IAM role, so that you
+can set your roles trust policy to require the C<ExternalID>. If you
+use the Cognito Management Console to create a role for SMS MFA,
+Cognito will create a role with the required permissions and a trust
+policy that demonstrates use of the C<ExternalId>.
 
 
 =head2 B<REQUIRED> SnsCallerArn => Str
 
   The Amazon Resource Name (ARN) of the Amazon Simple Notification
-Service (SNS) caller.
+Service (SNS) caller. This is the ARN of the IAM role in your AWS
+account which Cognito will use to send SMS messages.
 
 
 
