@@ -116,12 +116,10 @@ The identifier of the job.
 
 The language of the input documents. All documents must be in the same
 language. You can specify any of the languages supported by Amazon
-Comprehend: English ("en"), Spanish ("es"), French ("fr"), German
-("de"), Italian ("it"), or Portuguese ("pt"). If custom entities
-recognition is used, this parameter is ignored and the language used
-for training the model is used instead.
+Comprehend. If custom entities recognition is used, this parameter is
+ignored and the language used for training the model is used instead.
 
-Valid values are: C<"en">, C<"es">, C<"fr">, C<"de">, C<"it">, C<"pt">
+Valid values are: C<"en">, C<"es">, C<"fr">, C<"de">, C<"it">, C<"pt">, C<"ar">, C<"hi">, C<"ja">, C<"ko">, C<"zh">, C<"zh-TW">
 
 =head2 B<REQUIRED> OutputDataConfig => L<Paws::Comprehend::OutputDataConfig>
 
