@@ -36,9 +36,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         ... # values: COMPLIANT, NON_COMPLIANT, NOT_APPLICABLE, INSUFFICIENT_DATA
       ],    # OPTIONAL
       ConfigRuleNames => [
-        'MyStringWithCharLimit64', ...    # min: 1, max: 64
-      ],                                  # OPTIONAL
-      NextToken => 'MyString',            # OPTIONAL
+        'MyConfigRuleName', ...    # min: 1, max: 128
+      ],                           # OPTIONAL
+      NextToken => 'MyString',     # OPTIONAL
       );
 
     # Results:
