@@ -1,6 +1,8 @@
 package Paws::CostExplorer::Coverage;
   use Moose;
+  has CoverageCost => (is => 'ro', isa => 'Paws::CostExplorer::CoverageCost');
   has CoverageHours => (is => 'ro', isa => 'Paws::CostExplorer::CoverageHours');
+  has CoverageNormalizedUnits => (is => 'ro', isa => 'Paws::CostExplorer::CoverageNormalizedUnits');
 1;
 
 ### main pod documentation begin ###
@@ -20,14 +22,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::CostExplorer::Coverage object:
 
-  $service_obj->Method(Att1 => { CoverageHours => $value, ..., CoverageHours => $value  });
+  $service_obj->Method(Att1 => { CoverageCost => $value, ..., CoverageNormalizedUnits => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::CostExplorer::Coverage object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->CoverageHours
+  $result->Att1->CoverageCost
 
 =head1 DESCRIPTION
 
@@ -36,9 +38,20 @@ The amount of instance usage that a reservation covered.
 =head1 ATTRIBUTES
 
 
+=head2 CoverageCost => L<Paws::CostExplorer::CoverageCost>
+
+  The amount of cost that the reservation covered.
+
+
 =head2 CoverageHours => L<Paws::CostExplorer::CoverageHours>
 
-  The amount of instance usage that a reservation covered, in hours.
+  The amount of instance usage that the reservation covered, in hours.
+
+
+=head2 CoverageNormalizedUnits => L<Paws::CostExplorer::CoverageNormalizedUnits>
+
+  The amount of instance usage that the reservation covered, in
+normalized units.
 
 
 
