@@ -35,39 +35,39 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       PipelineId      => 'Myid',
       PipelineObjects => [
         {
-          fields => [
+          Fields => [
             {
-              key         => 'MyfieldNameString',     # min: 1, max: 256
-              refValue    => 'MyfieldNameString',     # min: 1, max: 256
-              stringValue => 'MyfieldStringValue',    # max: 10240; OPTIONAL
+              Key         => 'MyfieldNameString',     # min: 1, max: 256
+              RefValue    => 'MyfieldNameString',     # min: 1, max: 256
+              StringValue => 'MyfieldStringValue',    # max: 10240; OPTIONAL
             },
             ...
           ],
-          id   => 'Myid',                             # min: 1, max: 1024
-          name => 'Myid',                             # min: 1, max: 1024
+          Id   => 'Myid',                             # min: 1, max: 1024
+          Name => 'Myid',                             # min: 1, max: 1024
 
         },
         ...
       ],
       ParameterObjects => [
         {
-          attributes => [
+          Attributes => [
             {
-              key         => 'MyattributeNameString',     # min: 1, max: 256
-              stringValue => 'MyattributeValueString',    # max: 10240
+              Key         => 'MyattributeNameString',     # min: 1, max: 256
+              StringValue => 'MyattributeValueString',    # max: 10240
 
             },
             ...
           ],
-          id => 'MyfieldNameString',                      # min: 1, max: 256
+          Id => 'MyfieldNameString',                      # min: 1, max: 256
 
         },
         ...
       ],                                                  # OPTIONAL
       ParameterValues => [
         {
-          id          => 'MyfieldNameString',             # min: 1, max: 256
-          stringValue => 'MyfieldStringValue',            # max: 10240; OPTIONAL
+          Id          => 'MyfieldNameString',             # min: 1, max: 256
+          StringValue => 'MyfieldStringValue',            # max: 10240; OPTIONAL
 
         },
         ...
