@@ -52,85 +52,89 @@ following list.
 
 The Appium version for the test.
 
-I<Supported operators>: C<CONTAINS>
+Supported operators: C<CONTAINS>
 
 =item ARN
 
-The Amazon Resource Name (ARN) of the device. For example,
-"arn:aws:devicefarm:us-west-2::device:12345Example".
+The Amazon Resource Name (ARN) of the device (for example,
+C<arn:aws:devicefarm:us-west-2::device:12345Example>.
 
-I<Supported operators>: C<EQUALS>, C<IN>, C<NOT_IN>
+Supported operators: C<EQUALS>, C<IN>, C<NOT_IN>
 
 =item AVAILABILITY
 
-The current availability of the device. Valid values are "AVAILABLE",
-"HIGHLY_AVAILABLE", "BUSY", or "TEMPORARY_NOT_AVAILABLE".
+The current availability of the device. Valid values are AVAILABLE,
+HIGHLY_AVAILABLE, BUSY, or TEMPORARY_NOT_AVAILABLE.
 
-I<Supported operators>: C<EQUALS>
+Supported operators: C<EQUALS>
 
 =item FLEET_TYPE
 
-The fleet type. Valid values are "PUBLIC" or "PRIVATE".
+The fleet type. Valid values are PUBLIC or PRIVATE.
 
-I<Supported operators>: C<EQUALS>
+Supported operators: C<EQUALS>
 
 =item FORM_FACTOR
 
-The device form factor. Valid values are "PHONE" or "TABLET".
+The device form factor. Valid values are PHONE or TABLET.
 
-I<Supported operators>: C<EQUALS>, C<IN>, C<NOT_IN>
+Supported operators: C<EQUALS>, C<IN>, C<NOT_IN>
 
 =item INSTANCE_ARN
 
 The Amazon Resource Name (ARN) of the device instance.
 
-I<Supported operators>: C<IN>, C<NOT_IN>
+Supported operators: C<IN>, C<NOT_IN>
 
 =item INSTANCE_LABELS
 
 The label of the device instance.
 
-I<Supported operators>: C<CONTAINS>
+Supported operators: C<CONTAINS>
 
 =item MANUFACTURER
 
-The device manufacturer. For example, "Apple".
+The device manufacturer (for example, Apple).
 
-I<Supported operators>: C<EQUALS>, C<IN>, C<NOT_IN>
+Supported operators: C<EQUALS>, C<IN>, C<NOT_IN>
 
 =item MODEL
 
-The device model, such as "Apple iPad Air 2" or "Google Pixel".
+The device model, such as Apple iPad Air 2 or Google Pixel.
 
-I<Supported operators>: C<CONTAINS>, C<EQUALS>, C<IN>, C<NOT_IN>
+Supported operators: C<CONTAINS>, C<EQUALS>, C<IN>, C<NOT_IN>
 
 =item OS_VERSION
 
-The operating system version. For example, "10.3.2".
+The operating system version (for example, 10.3.2).
 
-I<Supported operators>: C<EQUALS>, C<GREATER_THAN>,
+Supported operators: C<EQUALS>, C<GREATER_THAN>,
 C<GREATER_THAN_OR_EQUALS>, C<IN>, C<LESS_THAN>, C<LESS_THAN_OR_EQUALS>,
 C<NOT_IN>
 
 =item PLATFORM
 
-The device platform. Valid values are "ANDROID" or "IOS".
+The device platform. Valid values are ANDROID or IOS.
 
-I<Supported operators>: C<EQUALS>, C<IN>, C<NOT_IN>
+Supported operators: C<EQUALS>, C<IN>, C<NOT_IN>
 
 =item REMOTE_ACCESS_ENABLED
 
-Whether the device is enabled for remote access. Valid values are
-"TRUE" or "FALSE".
+Whether the device is enabled for remote access. Valid values are TRUE
+or FALSE.
 
-I<Supported operators>: C<EQUALS>
+Supported operators: C<EQUALS>
 
 =item REMOTE_DEBUG_ENABLED
 
 Whether the device is enabled for remote debugging. Valid values are
-"TRUE" or "FALSE".
+TRUE or FALSE.
 
-I<Supported operators>: C<EQUALS>
+Supported operators: C<EQUALS>
+
+Because remote debugging is no longer supported
+(https://docs.aws.amazon.com/devicefarm/latest/developerguide/history.html),
+this filter is ignored.
 
 =back
 
