@@ -131,8 +131,8 @@ received, by app process.
 
 =head2 Url => Str
 
-  The pre-signed Amazon S3 URL that can be used with a corresponding GET
-request to download the sample's file.
+  The presigned Amazon S3 URL that can be used with a GET request to
+download the sample's file.
 
 
 
