@@ -35,9 +35,9 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::DeviceFarm:
 
 =head1 DESCRIPTION
 
-Represents test settings. This data structure is passed in as the
-"test" parameter to ScheduleRun. For an example of the JSON request
-syntax, see ScheduleRun.
+Represents test settings. This data structure is passed in as the test
+parameter to ScheduleRun. For an example of the JSON request syntax,
+see ScheduleRun.
 
 =head1 ATTRIBUTES
 
@@ -58,8 +58,8 @@ For all tests:
 
 =item *
 
-app_performance_monitoring: Performance monitoring is enabled by
-default. Set this parameter to "false" to disable it.
+C<app_performance_monitoring>: Performance monitoring is enabled by
+default. Set this parameter to false to disable it.
 
 =back
 
@@ -69,12 +69,12 @@ For Calabash tests:
 
 =item *
 
-profile: A cucumber profile, for example, "my_profile_name".
+profile: A cucumber profile (for example, C<my_profile_name>).
 
 =item *
 
 tags: You can limit execution to features or scenarios that have (or
-don't have) certain tags, for example, "@smoke" or "@smoke,~@wip".
+don't have) certain tags (for example, @smoke or @smoke,~@wip).
 
 =back
 
@@ -85,20 +85,19 @@ For Appium tests (all types):
 =item *
 
 appium_version: The Appium version. Currently supported values are
-"1.6.5" (and higher), "latest", and "default".
+1.6.5 (and later), latest, and default.
 
 =over
 
 =item *
 
-E<ldquo>latestE<rdquo> will run the latest Appium version supported by
-Device Farm (1.9.1).
+latest runs the latest Appium version supported by Device Farm (1.9.1).
 
 =item *
 
-For E<ldquo>defaultE<rdquo>, Device Farm will choose a compatible
-version of Appium for the device. The current behavior is to run 1.7.2
-on Android devices and iOS 9 and earlier, 1.7.2 for iOS 10 and later.
+For default, Device Farm selects a compatible version of Appium for the
+device. The current behavior is to run 1.7.2 on Android devices and iOS
+9 and earlier and 1.7.2 for iOS 10 and later.
 
 =item *
 
@@ -108,7 +107,7 @@ This behavior is subject to change.
 
 =back
 
-For Fuzz tests (Android only):
+For fuzz tests (Android only):
 
 =over
 
@@ -135,13 +134,13 @@ For Explorer tests:
 
 =item *
 
-username: A username to use if the Explorer encounters a login form. If
-not supplied, no username will be inserted.
+username: A user name to use if the Explorer encounters a login form.
+If not supplied, no user name is inserted.
 
 =item *
 
 password: A password to use if the Explorer encounters a login form. If
-not supplied, no password will be inserted.
+not supplied, no password is inserted.
 
 =back
 
@@ -157,15 +156,15 @@ filter: A test filter string. Examples:
 
 =item *
 
-Running a single test case: "com.android.abc.Test1"
+Running a single test case: C<com.android.abc.Test1>
 
 =item *
 
-Running a single test: "com.android.abc.Test1#smoke"
+Running a single test: C<com.android.abc.Test1#smoke>
 
 =item *
 
-Running multiple tests: "com.android.abc.Test1,com.android.abc.Test2"
+Running multiple tests: C<com.android.abc.Test1,com.android.abc.Test2>
 
 =back
 
@@ -183,19 +182,19 @@ filter: A test filter string. Examples:
 
 =item *
 
-Running a single test class: "LoginTests"
+Running a single test class: C<LoginTests>
 
 =item *
 
-Running a multiple test classes: "LoginTests,SmokeTests"
+Running a multiple test classes: C<LoginTests,SmokeTests>
 
 =item *
 
-Running a single test: "LoginTests/testValid"
+Running a single test: C<LoginTests/testValid>
 
 =item *
 
-Running multiple tests: "LoginTests/testValid,LoginTests/testInvalid"
+Running multiple tests: C<LoginTests/testValid,LoginTests/testInvalid>
 
 =back
 
@@ -213,15 +212,15 @@ filter: A test filter string. Examples:
 
 =item *
 
-Running a single test case: "com.android.abc.Test1"
+Running a single test case: C<com.android.abc.Test1>
 
 =item *
 
-Running a single test: "com.android.abc.Test1#smoke"
+Running a single test: C<com.android.abc.Test1#smoke>
 
 =item *
 
-Running multiple tests: "com.android.abc.Test1,com.android.abc.Test2"
+Running multiple tests: C<com.android.abc.Test1,com.android.abc.Test2>
 
 =back
 
@@ -231,7 +230,7 @@ Running multiple tests: "com.android.abc.Test1,com.android.abc.Test2"
 
 =head2 TestPackageArn => Str
 
-  The ARN of the uploaded test that will be run.
+  The ARN of the uploaded test to be run.
 
 
 =head2 TestSpecArn => Str
@@ -249,77 +248,77 @@ Must be one of the following values:
 
 =item *
 
-BUILTIN_FUZZ: The built-in fuzz type.
+BUILTIN_FUZZ
 
 =item *
 
-BUILTIN_EXPLORER: For Android, an app explorer that will traverse an
+BUILTIN_EXPLORER. For Android, an app explorer that traverses an
 Android app, interacting with it and capturing screenshots at the same
 time.
 
 =item *
 
-APPIUM_JAVA_JUNIT: The Appium Java JUnit type.
+APPIUM_JAVA_JUNIT
 
 =item *
 
-APPIUM_JAVA_TESTNG: The Appium Java TestNG type.
+APPIUM_JAVA_TESTNG
 
 =item *
 
-APPIUM_PYTHON: The Appium Python type.
+APPIUM_PYTHON
 
 =item *
 
-APPIUM_NODE: The Appium Node.js type.
+APPIUM_NODE
 
 =item *
 
-APPIUM_RUBY: The Appium Ruby type.
+APPIUM_RUBY
 
 =item *
 
-APPIUM_WEB_JAVA_JUNIT: The Appium Java JUnit type for web apps.
+APPIUM_WEB_JAVA_JUNIT
 
 =item *
 
-APPIUM_WEB_JAVA_TESTNG: The Appium Java TestNG type for web apps.
+APPIUM_WEB_JAVA_TESTNG
 
 =item *
 
-APPIUM_WEB_PYTHON: The Appium Python type for web apps.
+APPIUM_WEB_PYTHON
 
 =item *
 
-APPIUM_WEB_NODE: The Appium Node.js type for web apps.
+APPIUM_WEB_NODE
 
 =item *
 
-APPIUM_WEB_RUBY: The Appium Ruby type for web apps.
+APPIUM_WEB_RUBY
 
 =item *
 
-CALABASH: The Calabash type.
+CALABASH
 
 =item *
 
-INSTRUMENTATION: The Instrumentation type.
+INSTRUMENTATION
 
 =item *
 
-UIAUTOMATION: The uiautomation type.
+UIAUTOMATION
 
 =item *
 
-UIAUTOMATOR: The uiautomator type.
+UIAUTOMATOR
 
 =item *
 
-XCTEST: The Xcode test type.
+XCTEST
 
 =item *
 
-XCTEST_UI: The Xcode UI test type.
+XCTEST_UI
 
 =back
 
