@@ -61,6 +61,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     my $Location             = $Connection->Location;
     my $OwnerAccount         = $Connection->OwnerAccount;
     my $PartnerName          = $Connection->PartnerName;
+    my $ProviderName         = $Connection->ProviderName;
     my $Region               = $Connection->Region;
     my $Tags                 = $Connection->Tags;
     my $Vlan                 = $Connection->Vlan;
@@ -103,7 +104,7 @@ The ID of the AWS account ID of the customer for the connection.
 
 =head2 Tags => ArrayRef[L<Paws::DirectConnect::Tag>]
 
-The tags to assign to the hosted connection.
+The tags associated with the connection.
 
 
 
