@@ -79,8 +79,9 @@ I<key>-I<value> format. For example:
 C<{"key": "serverType", "value": "webServer"}>
 
 For a complete list of filter options and guidance about using them
-with this action, see Querying Discovered Configuration Items
-(http://docs.aws.amazon.com/application-discovery/latest/APIReference/discovery-api-queries.html#ListConfigurations).
+with this action, see Using the ListConfigurations Action
+(https://docs.aws.amazon.com/application-discovery/latest/userguide/discovery-api-queries.html#ListConfigurations)
+in the I<AWS Application Discovery Service User Guide>.
 
 
 
@@ -105,7 +106,8 @@ next set of 10.
 Certain filter criteria return output that can be sorted in ascending
 or descending order. For a list of output characteristics for each
 filter, see Using the ListConfigurations Action
-(http://docs.aws.amazon.com/application-discovery/latest/APIReference/discovery-api-queries.html#ListConfigurations).
+(https://docs.aws.amazon.com/application-discovery/latest/userguide/discovery-api-queries.html#ListConfigurations)
+in the I<AWS Application Discovery Service User Guide>.
 
 
 
