@@ -37,9 +37,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       ],                                            # OPTIONAL
       Filters => [
         {
-          condition => 'MyCondition',
-          name      => 'MyFilterName',
-          values    => [ 'MyFilterValue', ... ],
+          Condition => 'MyCondition',
+          Name      => 'MyFilterName',
+          Values    => [ 'MyFilterValue', ... ],
 
         },
         ...
