@@ -50,7 +50,7 @@ the partition key and the sort key.
 
   This is a legacy parameter. Use C<ProjectionExpression> instead. For
 more information, see Legacy Conditional Parameters
-(http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/LegacyConditionalParameters.html)
+(https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/LegacyConditionalParameters.html)
 in the I<Amazon DynamoDB Developer Guide>.
 
 
@@ -99,7 +99,7 @@ C<Percentile>
 The name of this attribute conflicts with a reserved word, so it cannot
 be used directly in an expression. (For the complete list of reserved
 words, see Reserved Words
-(http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ReservedWords.html)
+(https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ReservedWords.html)
 in the I<Amazon DynamoDB Developer Guide>). To work around this, you
 could specify the following for C<ExpressionAttributeNames>:
 
@@ -127,7 +127,7 @@ values>, which are placeholders for the actual value at runtime.
 
 For more information on expression attribute names, see Accessing Item
 Attributes
-(http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Expressions.AccessingItemAttributes.html)
+(https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Expressions.AccessingItemAttributes.html)
 in the I<Amazon DynamoDB Developer Guide>.
 
 
@@ -149,7 +149,7 @@ returned. If any of the requested attributes are not found, they will
 not appear in the result.
 
 For more information, see Accessing Item Attributes
-(http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Expressions.AccessingItemAttributes.html)
+(https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Expressions.AccessingItemAttributes.html)
 in the I<Amazon DynamoDB Developer Guide>.
 
 
