@@ -1,15 +1,18 @@
 package Paws::DynamoDB::TableDescription;
   use Moose;
+  has ArchivalSummary => (is => 'ro', isa => 'Paws::DynamoDB::ArchivalSummary');
   has AttributeDefinitions => (is => 'ro', isa => 'ArrayRef[Paws::DynamoDB::AttributeDefinition]');
   has BillingModeSummary => (is => 'ro', isa => 'Paws::DynamoDB::BillingModeSummary');
   has CreationDateTime => (is => 'ro', isa => 'Str');
   has GlobalSecondaryIndexes => (is => 'ro', isa => 'ArrayRef[Paws::DynamoDB::GlobalSecondaryIndexDescription]');
+  has GlobalTableVersion => (is => 'ro', isa => 'Str');
   has ItemCount => (is => 'ro', isa => 'Int');
   has KeySchema => (is => 'ro', isa => 'ArrayRef[Paws::DynamoDB::KeySchemaElement]');
   has LatestStreamArn => (is => 'ro', isa => 'Str');
   has LatestStreamLabel => (is => 'ro', isa => 'Str');
   has LocalSecondaryIndexes => (is => 'ro', isa => 'ArrayRef[Paws::DynamoDB::LocalSecondaryIndexDescription]');
   has ProvisionedThroughput => (is => 'ro', isa => 'Paws::DynamoDB::ProvisionedThroughputDescription');
+  has Replicas => (is => 'ro', isa => 'ArrayRef[Paws::DynamoDB::ReplicaDescription]');
   has RestoreSummary => (is => 'ro', isa => 'Paws::DynamoDB::RestoreSummary');
   has SSEDescription => (is => 'ro', isa => 'Paws::DynamoDB::SSEDescription');
   has StreamSpecification => (is => 'ro', isa => 'Paws::DynamoDB::StreamSpecification');
@@ -37,14 +40,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::DynamoDB::TableDescription object:
 
-  $service_obj->Method(Att1 => { AttributeDefinitions => $value, ..., TableStatus => $value  });
+  $service_obj->Method(Att1 => { ArchivalSummary => $value, ..., TableStatus => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::DynamoDB::TableDescription object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->AttributeDefinitions
+  $result->Att1->ArchivalSummary
 
 =head1 DESCRIPTION
 
@@ -53,6 +56,11 @@ Represents the properties of a table.
 =head1 ATTRIBUTES
 
 
+=head2 ArchivalSummary => L<Paws::DynamoDB::ArchivalSummary>
+
+  Contains information about the table archive.
+
+
 =head2 AttributeDefinitions => ArrayRef[L<Paws::DynamoDB::AttributeDefinition>]
 
   An array of C<AttributeDefinition> objects. Each of these objects
@@ -96,11 +104,18 @@ scoped to a given partition key value. Each element is composed of:
 
 C<Backfilling> - If true, then the index is currently in the
 backfilling phase. Backfilling occurs only when a new global secondary
-index is added to the table; it is the process by which DynamoDB
+index is added to the table. It is the process by which DynamoDB
 populates the new index with data from the table. (This attribute does
 not appear for indexes that were created during a C<CreateTable>
 operation.)
 
+You can delete an index that is being created during the C<Backfilling>
+phase when C<IndexStatus> is set to CREATING and C<Backfilling> is
+true. You can't delete the index that is being created when
+C<IndexStatus> is set to CREATING and C<Backfilling> is false. (This
+attribute does not appear for indexes that were created during a
+C<CreateTable> operation.)
+
 =item *
 
 C<IndexName> - The name of the global secondary index.
@@ -171,7 +186,7 @@ index.
 =item *
 
 C<INCLUDE> - Only the specified table attributes are projected into the
-index. The list of projected attributes are in C<NonKeyAttributes>.
+index. The list of projected attributes is in C<NonKeyAttributes>.
 
 =item *
 
@@ -202,6 +217,13 @@ If the table is in the C<DELETING> state, no information about indexes
 will be returned.
 
 
+=head2 GlobalTableVersion => Str
+
+  Represents the version of global tables
+(https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/GlobalTables.html)
+in use, if the table is replicated across AWS Regions.
+
+
 =head2 ItemCount => Int
 
   The number of items in the specified table. DynamoDB updates this value
@@ -272,15 +294,15 @@ three elements is guaranteed to be unique:
 
 =item *
 
-the AWS customer ID.
+AWS customer ID
 
 =item *
 
-the table name.
+Table name
 
 =item *
 
-the C<StreamLabel>.
+C<StreamLabel>
 
 =back
 
@@ -330,7 +352,7 @@ index.
 =item *
 
 C<INCLUDE> - Only the specified table attributes are projected into the
-index. The list of projected attributes are in C<NonKeyAttributes>.
+index. The list of projected attributes is in C<NonKeyAttributes>.
 
 =item *
 
@@ -374,6 +396,11 @@ and write capacity units, along with data about increases and
 decreases.
 
 
+=head2 Replicas => ArrayRef[L<Paws::DynamoDB::ReplicaDescription>]
+
+  Represents replicas of the table.
+
+
 =head2 RestoreSummary => L<Paws::DynamoDB::RestoreSummary>
 
   Contains details for the restore.
@@ -434,6 +461,24 @@ C<DELETING> - The table is being deleted.
 
 C<ACTIVE> - The table is ready for use.
 
+=item *
+
+C<INACCESSIBLE_ENCRYPTION_CREDENTIALS> - The AWS KMS key used to
+encrypt the table in inaccessible. Table operations may fail due to
+failure to use the AWS KMS key. DynamoDB will initiate the table
+archival process when a table's AWS KMS key remains inaccessible for
+more than seven days.
+
+=item *
+
+C<ARCHIVING> - The table is being archived. Operations are not allowed
+until archival is complete.
+
+=item *
+
+C<ARCHIVED> - The table has been archived. See the ArchivalReason for
+more information.
+
 =back
 
 
