@@ -35,14 +35,14 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::DynamoDB::T
 Describes a tag. A tag is a key-value pair. You can add up to 50 tags
 to a single DynamoDB table.
 
-AWS-assigned tag names and values are automatically assigned the aws:
-prefix, which the user cannot assign. AWS-assigned tag names do not
-count towards the tag limit of 50. User-assigned tag names have the
-prefix user: in the Cost Allocation Report. You cannot backdate the
+AWS-assigned tag names and values are automatically assigned the
+C<aws:> prefix, which the user cannot assign. AWS-assigned tag names do
+not count towards the tag limit of 50. User-assigned tag names have the
+prefix C<user:> in the Cost Allocation Report. You cannot backdate the
 application of a tag.
 
 For an overview on tagging DynamoDB resources, see Tagging for DynamoDB
-(http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Tagging.html)
+(https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Tagging.html)
 in the I<Amazon DynamoDB Developer Guide>.
 
 =head1 ATTRIBUTES
@@ -50,8 +50,8 @@ in the I<Amazon DynamoDB Developer Guide>.
 
 =head2 B<REQUIRED> Key => Str
 
-  The key of the tag.Tag keys are case sensitive. Each DynamoDB table can
-only have up to one tag with the same key. If you try to add an
+  The key of the tag. Tag keys are case sensitive. Each DynamoDB table
+can only have up to one tag with the same key. If you try to add an
 existing tag (same key), the existing tag value will be updated to the
 new value.
 
