@@ -36,10 +36,10 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $ec2 = Paws->service('EC2');
     $ec2->AuthorizeSecurityGroupEgress(
-      GroupId       => 'MyString',
-      CidrIp        => 'MyString',    # OPTIONAL
-      DryRun        => 1,             # OPTIONAL
-      FromPort      => 1,             # OPTIONAL
+      GroupId       => 'MySecurityGroupId',
+      CidrIp        => 'MyString',            # OPTIONAL
+      DryRun        => 1,                     # OPTIONAL
+      FromPort      => 1,                     # OPTIONAL
       IpPermissions => [
         {
           FromPort   => 1,
@@ -50,21 +50,21 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               Description => 'MyString',
             },
             ...
-          ],                          # OPTIONAL
+          ],                                  # OPTIONAL
           Ipv6Ranges => [
             {
               CidrIpv6    => 'MyString',
               Description => 'MyString',
             },
             ...
-          ],                          # OPTIONAL
+          ],                                  # OPTIONAL
           PrefixListIds => [
             {
               Description  => 'MyString',
               PrefixListId => 'MyString',
             },
             ...
-          ],                          # OPTIONAL
+          ],                                  # OPTIONAL
           ToPort           => 1,
           UserIdGroupPairs => [
             {
