@@ -15,6 +15,7 @@ package Paws::EC2::ClientVpnEndpoint;
   has Status => (is => 'ro', isa => 'Paws::EC2::ClientVpnEndpointStatus', request_name => 'status', traits => ['NameInRequest']);
   has Tags => (is => 'ro', isa => 'ArrayRef[Paws::EC2::Tag]', request_name => 'tagSet', traits => ['NameInRequest']);
   has TransportProtocol => (is => 'ro', isa => 'Str', request_name => 'transportProtocol', traits => ['NameInRequest']);
+  has VpnPort => (is => 'ro', isa => 'Int', request_name => 'vpnPort', traits => ['NameInRequest']);
   has VpnProtocol => (is => 'ro', isa => 'Str', request_name => 'vpnProtocol', traits => ['NameInRequest']);
 1;
 
@@ -113,7 +114,13 @@ endpoint.
 
 =head2 SplitTunnel => Bool
 
-  Indicates whether VPN split tunneling is supported.
+  Indicates whether split-tunnel is enabled in the AWS Client VPN
+endpoint.
+
+For information about split-tunnel VPN endpoints, see Split-Tunnel AWS
+Client VPN Endpoint
+(https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/split-tunnel-vpn.html)
+in the I<AWS Client VPN Administrator Guide>.
 
 
 =head2 Status => L<Paws::EC2::ClientVpnEndpointStatus>
@@ -131,6 +138,11 @@ endpoint.
   The transport protocol used by the Client VPN endpoint.
 
 
+=head2 VpnPort => Int
+
+  The port number for the Client VPN endpoint.
+
+
 =head2 VpnProtocol => Str
 
   The protocol used by the VPN session.
