@@ -33,7 +33,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $ec2 = Paws->service('EC2');
     my $CreateImageResult = $ec2->CreateImage(
-      InstanceId          => 'MyString',
+      InstanceId          => 'MyInstanceId',
       Name                => 'MyString',
       BlockDeviceMappings => [
         {
