@@ -31,22 +31,22 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     my $ec2 = Paws->service('EC2');
     my $CreateTransitGatewayRouteTableResult =
       $ec2->CreateTransitGatewayRouteTable(
-      TransitGatewayId  => 'MyString',
-      DryRun            => 1,            # OPTIONAL
+      TransitGatewayId  => 'MyTransitGatewayId',
+      DryRun            => 1,                      # OPTIONAL
       TagSpecifications => [
         {
           ResourceType => 'client-vpn-endpoint'
-          , # values: client-vpn-endpoint, customer-gateway, dedicated-host, dhcp-options, elastic-ip, fleet, fpga-image, host-reservation, image, instance, internet-gateway, launch-template, natgateway, network-acl, network-interface, reserved-instances, route-table, security-group, snapshot, spot-instances-request, subnet, traffic-mirror-filter, traffic-mirror-session, traffic-mirror-target, transit-gateway, transit-gateway-attachment, transit-gateway-route-table, volume, vpc, vpc-peering-connection, vpn-connection, vpn-gateway; OPTIONAL
+          , # values: client-vpn-endpoint, customer-gateway, dedicated-host, dhcp-options, elastic-ip, fleet, fpga-image, host-reservation, image, instance, internet-gateway, key-pair, launch-template, natgateway, network-acl, network-interface, placement-group, reserved-instances, route-table, security-group, snapshot, spot-fleet-request, spot-instances-request, subnet, traffic-mirror-filter, traffic-mirror-session, traffic-mirror-target, transit-gateway, transit-gateway-attachment, transit-gateway-multicast-domain, transit-gateway-route-table, volume, vpc, vpc-peering-connection, vpn-connection, vpn-gateway; OPTIONAL
           Tags => [
             {
-              Key   => 'MyString',
-              Value => 'MyString',
+              Key   => 'MyString',    # OPTIONAL
+              Value => 'MyString',    # OPTIONAL
             },
             ...
-          ],    # OPTIONAL
+          ],                          # OPTIONAL
         },
         ...
-      ],        # OPTIONAL
+      ],                              # OPTIONAL
       );
 
     # Results:
