@@ -34,10 +34,10 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     my $ec2 = Paws->service('EC2');
     my $CreateTransitGatewayVpcAttachmentResult =
       $ec2->CreateTransitGatewayVpcAttachment(
-      SubnetIds        => [ 'MyString', ... ],
-      TransitGatewayId => 'MyString',
-      VpcId            => 'MyString',
-      DryRun           => 1,                     # OPTIONAL
+      SubnetIds        => [ 'MySubnetId', ... ],
+      TransitGatewayId => 'MyTransitGatewayId',
+      VpcId            => 'MyVpcId',
+      DryRun           => 1,                       # OPTIONAL
       Options          => {
         DnsSupport  => 'enable',    # values: enable, disable; OPTIONAL
         Ipv6Support => 'enable',    # values: enable, disable; OPTIONAL
@@ -45,17 +45,17 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       TagSpecifications => [
         {
           ResourceType => 'client-vpn-endpoint'
-          , # values: client-vpn-endpoint, customer-gateway, dedicated-host, dhcp-options, elastic-ip, fleet, fpga-image, host-reservation, image, instance, internet-gateway, launch-template, natgateway, network-acl, network-interface, reserved-instances, route-table, security-group, snapshot, spot-instances-request, subnet, traffic-mirror-filter, traffic-mirror-session, traffic-mirror-target, transit-gateway, transit-gateway-attachment, transit-gateway-route-table, volume, vpc, vpc-peering-connection, vpn-connection, vpn-gateway; OPTIONAL
+          , # values: client-vpn-endpoint, customer-gateway, dedicated-host, dhcp-options, elastic-ip, fleet, fpga-image, host-reservation, image, instance, internet-gateway, key-pair, launch-template, natgateway, network-acl, network-interface, placement-group, reserved-instances, route-table, security-group, snapshot, spot-fleet-request, spot-instances-request, subnet, traffic-mirror-filter, traffic-mirror-session, traffic-mirror-target, transit-gateway, transit-gateway-attachment, transit-gateway-multicast-domain, transit-gateway-route-table, volume, vpc, vpc-peering-connection, vpn-connection, vpn-gateway; OPTIONAL
           Tags => [
             {
-              Key   => 'MyString',
-              Value => 'MyString',
+              Key   => 'MyString',    # OPTIONAL
+              Value => 'MyString',    # OPTIONAL
             },
             ...
-          ],    # OPTIONAL
+          ],                          # OPTIONAL
         },
         ...
-      ],        # OPTIONAL
+      ],                              # OPTIONAL
       );
 
     # Results:
