@@ -3,6 +3,7 @@ package Paws::EC2::DescribeEgressOnlyInternetGateways;
   use Moose;
   has DryRun => (is => 'ro', isa => 'Bool');
   has EgressOnlyInternetGatewayIds => (is => 'ro', isa => 'ArrayRef[Str|Undef]', traits => ['NameInRequest'], request_name => 'EgressOnlyInternetGatewayId' );
+  has Filters => (is => 'ro', isa => 'ArrayRef[Paws::EC2::Filter]', traits => ['NameInRequest'], request_name => 'Filter' );
   has MaxResults => (is => 'ro', isa => 'Int');
   has NextToken => (is => 'ro', isa => 'Str');
 
@@ -35,6 +36,15 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       DryRun => 1,    # OPTIONAL
       EgressOnlyInternetGatewayIds => [ 'MyEgressOnlyInternetGatewayId', ... ]
       ,               # OPTIONAL
+      Filters => [
+        {
+          Name   => 'MyString',    # OPTIONAL
+          Values => [
+            'MyString', ...        # OPTIONAL
+          ],                       # OPTIONAL
+        },
+        ...
+      ],                           # OPTIONAL
       MaxResults => 1,             # OPTIONAL
       NextToken  => 'MyString',    # OPTIONAL
       );
@@ -67,6 +77,31 @@ One or more egress-only internet gateway IDs.
 
 
 
+=head2 Filters => ArrayRef[L<Paws::EC2::Filter>]
+
+One or more filters.
+
+=over
+
+=item *
+
+C<tag>:E<lt>keyE<gt> - The key/value combination of a tag assigned to
+the resource. Use the tag key in the filter name and the tag value as
+the filter value. For example, to find all resources that have a tag
+with the key C<Owner> and the value C<TeamA>, specify C<tag:Owner> for
+the filter name and C<TeamA> for the filter value.
+
+=item *
+
+C<tag-key> - The key of a tag assigned to the resource. Use this filter
+to find all resources assigned a tag with a specific key, regardless of
+the tag value.
+
+=back
+
+
+
+
 =head2 MaxResults => Int
 
 The maximum number of results to return with a single call. To retrieve
