@@ -32,17 +32,19 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $ec2 = Paws->service('EC2');
     my $DescribeElasticGpusResult = $ec2->DescribeElasticGpus(
-      DryRun        => 1,                      # OPTIONAL
-      ElasticGpuIds => [ 'MyString', ... ],    # OPTIONAL
+      DryRun        => 1,                            # OPTIONAL
+      ElasticGpuIds => [ 'MyElasticGpuId', ... ],    # OPTIONAL
       Filters       => [
         {
-          Name   => 'MyString',
-          Values => [ 'MyString', ... ],       # OPTIONAL
+          Name   => 'MyString',                      # OPTIONAL
+          Values => [
+            'MyString', ...                          # OPTIONAL
+          ],                                         # OPTIONAL
         },
         ...
-      ],                                       # OPTIONAL
-      MaxResults => 1,                         # OPTIONAL
-      NextToken  => 'MyString',                # OPTIONAL
+      ],                                             # OPTIONAL
+      MaxResults => 1,                               # OPTIONAL
+      NextToken  => 'MyString',                      # OPTIONAL
     );
 
     # Results:
