@@ -43,14 +43,12 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      FpgaImageIds => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
-      MaxResults => 1,             # OPTIONAL
-      NextToken  => 'MyNextToken', # OPTIONAL
-      Owners     => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
+      FpgaImageIds => [ 'MyFpgaImageId', ... ],    # OPTIONAL
+      MaxResults   => 1,                           # OPTIONAL
+      NextToken    => 'MyNextToken',               # OPTIONAL
+      Owners       => [
+        'MyString', ...                            # OPTIONAL
+      ],                                           # OPTIONAL
     );
 
     # Results:
