@@ -40,11 +40,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      HostReservationIdSet => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
-      MaxResults => 1,             # OPTIONAL
-      NextToken  => 'MyString',    # OPTIONAL
+      HostReservationIdSet => [ 'MyHostReservationId', ... ],    # OPTIONAL
+      MaxResults           => 1,                                 # OPTIONAL
+      NextToken            => 'MyString',                        # OPTIONAL
     );
 
     # Results:
