@@ -42,11 +42,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      ImportTaskIds => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
-      MaxResults => 1,             # OPTIONAL
-      NextToken  => 'MyString',    # OPTIONAL
+      ImportTaskIds => [ 'MyImportSnapshotTaskId', ... ],    # OPTIONAL
+      MaxResults    => 1,                                    # OPTIONAL
+      NextToken     => 'MyString',                           # OPTIONAL
     );
 
     # Results:
