@@ -43,11 +43,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      InstanceIds => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
-      MaxResults => 1,             # OPTIONAL
-      NextToken  => 'MyString',    # OPTIONAL
+      InstanceIds => [ 'MyInstanceId', ... ],    # OPTIONAL
+      MaxResults  => 1,                          # OPTIONAL
+      NextToken   => 'MyString',                 # OPTIONAL
       );
 
     # Results:
