@@ -43,12 +43,10 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      IncludeAllInstances => 1,    # OPTIONAL
-      InstanceIds         => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
-      MaxResults => 1,             # OPTIONAL
-      NextToken  => 'MyString',    # OPTIONAL
+      IncludeAllInstances => 1,                          # OPTIONAL
+      InstanceIds         => [ 'MyInstanceId', ... ],    # OPTIONAL
+      MaxResults          => 1,                          # OPTIONAL
+      NextToken           => 'MyString',                 # OPTIONAL
     );
 
     # Results:
