@@ -42,11 +42,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      InstanceIds => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
-      MaxResults => 1,             # OPTIONAL
-      NextToken  => 'MyString',    # OPTIONAL
+      InstanceIds => [ 'MyInstanceId', ... ],    # OPTIONAL
+      MaxResults  => 1,                          # OPTIONAL
+      NextToken   => 'MyString',                 # OPTIONAL
     );
 
     # Results:
@@ -217,6 +215,21 @@ C<launch-time> - The time when the instance was launched.
 
 =item *
 
+C<metadata-options.http-tokens> - The metadata request authorization
+state (C<optional> | C<required>)
+
+=item *
+
+C<metadata-options.http-put-response-hop-limit> - The http metadata
+request put response hop limit (integer, possible values C<1> to C<64>)
+
+=item *
+
+C<metadata-options.http-endpoint> - Enable or disable metadata access
+on http endpoint (C<enabled> | C<disabled>)
+
+=item *
+
 C<monitoring-state> - Indicates whether detailed monitoring is enabled
 (C<disabled> | C<enabled>).
 
