@@ -36,17 +36,19 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       DryRun  => 1,    # OPTIONAL
       Filters => [
         {
-          Name   => 'MyString',
-          Values => [ 'MyString', ... ],    # OPTIONAL
+          Name   => 'MyString',    # OPTIONAL
+          Values => [
+            'MyString', ...        # OPTIONAL
+          ],                       # OPTIONAL
         },
         ...
-      ],                                    # OPTIONAL
-      LaunchTemplateIds   => [ 'MyString', ... ],    # OPTIONAL
+      ],                           # OPTIONAL
+      LaunchTemplateIds   => [ 'MyLaunchTemplateId', ... ],    # OPTIONAL
       LaunchTemplateNames => [
-        'MyLaunchTemplateName', ...                  # min: 3, max: 128
-      ],                                             # OPTIONAL
-      MaxResults => 1,                               # OPTIONAL
-      NextToken  => 'MyString',                      # OPTIONAL
+        'MyLaunchTemplateName', ...    # min: 3, max: 128
+      ],                               # OPTIONAL
+      MaxResults => 1,                 # OPTIONAL
+      NextToken  => 'MyString',        # OPTIONAL
     );
 
     # Results:
