@@ -41,11 +41,10 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      MaxResults                    => 1,    # OPTIONAL
-      NetworkInterfacePermissionIds => [
-        'MyString', ...                      # OPTIONAL
-      ],                                     # OPTIONAL
-      NextToken => 'MyString',               # OPTIONAL
+      MaxResults => 1,             # OPTIONAL
+      NetworkInterfacePermissionIds =>
+        [ 'MyNetworkInterfacePermissionId', ... ],    # OPTIONAL
+      NextToken => 'MyString',                        # OPTIONAL
       );
 
     # Results:
