@@ -3,6 +3,7 @@ package Paws::EC2::DescribePlacementGroups;
   use Moose;
   has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );
   has Filters => (is => 'ro', isa => 'ArrayRef[Paws::EC2::Filter]', traits => ['NameInRequest'], request_name => 'Filter' );
+  has GroupIds => (is => 'ro', isa => 'ArrayRef[Str|Undef]', traits => ['NameInRequest'], request_name => 'GroupId' );
   has GroupNames => (is => 'ro', isa => 'ArrayRef[Str|Undef]', traits => ['NameInRequest'], request_name => 'groupName' );
 
   use MooseX::ClassAttribute;
@@ -40,9 +41,8 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      GroupNames => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
+      GroupIds   => [ 'MyPlacementGroupId',   ... ],    # OPTIONAL
+      GroupNames => [ 'MyPlacementGroupName', ... ],    # OPTIONAL
     );
 
     # Results:
@@ -90,6 +90,12 @@ C<spread> | C<partition>).
 
 
 
+=head2 GroupIds => ArrayRef[Str|Undef]
+
+The IDs of the placement groups.
+
+
+
 =head2 GroupNames => ArrayRef[Str|Undef]
 
 The names of the placement groups.
