@@ -42,11 +42,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      MaxResults    => 1,          # OPTIONAL
-      NextToken     => 'MyString', # OPTIONAL
-      PrefixListIds => [
-        'MyString', ...            # OPTIONAL
-      ],                           # OPTIONAL
+      MaxResults    => 1,                                    # OPTIONAL
+      NextToken     => 'MyString',                           # OPTIONAL
+      PrefixListIds => [ 'MyPrefixListResourceId', ... ],    # OPTIONAL
     );
 
     # Results:
