@@ -35,14 +35,16 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       DryRun  => 1,    # OPTIONAL
       Filters => [
         {
-          Name   => 'MyString',
-          Values => [ 'MyString', ... ],    # OPTIONAL
+          Name   => 'MyString',    # OPTIONAL
+          Values => [
+            'MyString', ...        # OPTIONAL
+          ],                       # OPTIONAL
         },
         ...
-      ],                                    # OPTIONAL
-      OfferingClass        => 'standard',             # OPTIONAL
-      OfferingType         => 'Heavy Utilization',    # OPTIONAL
-      ReservedInstancesIds => [ 'MyString', ... ],    # OPTIONAL
+      ],                           # OPTIONAL
+      OfferingClass        => 'standard',                    # OPTIONAL
+      OfferingType         => 'Heavy Utilization',           # OPTIONAL
+      ReservedInstancesIds => [ 'MyReservationId', ... ],    # OPTIONAL
     );
 
     # Results:
