@@ -33,13 +33,16 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       $ec2->DescribeReservedInstancesModifications(
       Filters => [
         {
-          Name   => 'MyString',
-          Values => [ 'MyString', ... ],    # OPTIONAL
+          Name   => 'MyString',    # OPTIONAL
+          Values => [
+            'MyString', ...        # OPTIONAL
+          ],                       # OPTIONAL
         },
         ...
-      ],                                    # OPTIONAL
-      NextToken                        => 'MyString',             # OPTIONAL
-      ReservedInstancesModificationIds => [ 'MyString', ... ],    # OPTIONAL
+      ],                           # OPTIONAL
+      NextToken => 'MyString',     # OPTIONAL
+      ReservedInstancesModificationIds =>
+        [ 'MyReservedInstancesModificationId', ... ],    # OPTIONAL
       );
 
     # Results:
