@@ -36,14 +36,17 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       DryRun  => 1,    # OPTIONAL
       Filters => [
         {
-          Name   => 'MyString',
-          Values => [ 'MyString', ... ],    # OPTIONAL
+          Name   => 'MyString',    # OPTIONAL
+          Values => [
+            'MyString', ...        # OPTIONAL
+          ],                       # OPTIONAL
         },
         ...
-      ],                                    # OPTIONAL
-      MaxResults                  => 1,                      # OPTIONAL
-      NextToken                   => 'MyString',             # OPTIONAL
-      TransitGatewayAttachmentIds => [ 'MyString', ... ],    # OPTIONAL
+      ],                           # OPTIONAL
+      MaxResults => 1,             # OPTIONAL
+      NextToken  => 'MyString',    # OPTIONAL
+      TransitGatewayAttachmentIds => [ 'MyTransitGatewayAttachmentId', ... ]
+      ,                            # OPTIONAL
       );
 
     # Results:
