@@ -42,11 +42,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      MaxResults     => 1,             # OPTIONAL
-      NextToken      => 'MyString',    # OPTIONAL
-      VpcEndpointIds => [
-        'MyString', ...                # OPTIONAL
-      ],                               # OPTIONAL
+      MaxResults     => 1,                             # OPTIONAL
+      NextToken      => 'MyString',                    # OPTIONAL
+      VpcEndpointIds => [ 'MyVpcEndpointId', ... ],    # OPTIONAL
     );
 
     # Results:
@@ -78,20 +76,21 @@ One or more filters.
 
 =item *
 
-C<service-name>: The name of the service.
+C<service-name> - The name of the service.
 
 =item *
 
-C<vpc-id>: The ID of the VPC in which the endpoint resides.
+C<vpc-id> - The ID of the VPC in which the endpoint resides.
 
 =item *
 
-C<vpc-endpoint-id>: The ID of the endpoint.
+C<vpc-endpoint-id> - The ID of the endpoint.
 
 =item *
 
-C<vpc-endpoint-state>: The state of the endpoint. (C<pending> |
-C<available> | C<deleting> | C<deleted>)
+C<vpc-endpoint-state> - The state of the endpoint (C<pendingAcceptance>
+| C<pending> | C<available> | C<deleting> | C<deleted> | C<rejected> |
+C<failed>).
 
 =item *
 
@@ -118,7 +117,7 @@ The maximum number of items to return for this request. The request
 returns a token that you can specify in a subsequent call to get the
 next set of results.
 
-Constraint: If the value is greater than 1000, we return only 1000
+Constraint: If the value is greater than 1,000, we return only 1,000
 items.
 
 
