@@ -43,11 +43,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         },
         ...
       ],                           # OPTIONAL
-      MaxResults              => 1,             # OPTIONAL
-      NextToken               => 'MyString',    # OPTIONAL
-      VpcPeeringConnectionIds => [
-        'MyString', ...                         # OPTIONAL
-      ],                                        # OPTIONAL
+      MaxResults              => 1,                                   # OPTIONAL
+      NextToken               => 'MyString',                          # OPTIONAL
+      VpcPeeringConnectionIds => [ 'MyVpcPeeringConnectionId', ... ], # OPTIONAL
       );
 
     # Results:
