@@ -33,12 +33,14 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       DryRun  => 1,    # OPTIONAL
       Filters => [
         {
-          Name   => 'MyString',
-          Values => [ 'MyString', ... ],    # OPTIONAL
+          Name   => 'MyString',    # OPTIONAL
+          Values => [
+            'MyString', ...        # OPTIONAL
+          ],                       # OPTIONAL
         },
         ...
-      ],                                    # OPTIONAL
-      VpnGatewayIds => [ 'MyString', ... ], # OPTIONAL
+      ],                           # OPTIONAL
+      VpnGatewayIds => [ 'MyVpnGatewayId', ... ],    # OPTIONAL
     );
 
     # Results:
