@@ -32,15 +32,15 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     my $ec2 = Paws->service('EC2');
     my $ExportTransitGatewayRoutesResult = $ec2->ExportTransitGatewayRoutes(
       S3Bucket                   => 'MyString',
-      TransitGatewayRouteTableId => 'MyString',
-      DryRun                     => 1,            # OPTIONAL
+      TransitGatewayRouteTableId => 'MyTransitGatewayRouteTableId',
+      DryRun                     => 1,                                # OPTIONAL
       Filters                    => [
         {
           Name   => 'MyString',
-          Values => [ 'MyString', ... ],          # OPTIONAL
+          Values => [ 'MyString', ... ],                              # OPTIONAL
         },
         ...
-      ],                                          # OPTIONAL
+      ],                                                              # OPTIONAL
     );
 
     # Results:
