@@ -67,8 +67,9 @@ C<pending_termination> while instances are terminating.
 
 =head2 ClientToken => Str
 
-  Unique, case-sensitive identifier you provide to ensure the idempotency
-of the request. For more information, see Ensuring Idempotency
+  Unique, case-sensitive identifier that you provide to ensure the
+idempotency of the request. For more information, see Ensuring
+Idempotency
 (https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html).
 
 Constraints: Maximum 64 ASCII characters
@@ -166,10 +167,10 @@ Fleet expires.
 the target capacity, or also attempts to C<maintain> it. If you request
 a certain target capacity, EC2 Fleet only places the required requests;
 it does not attempt to replenish instances if capacity is diminished,
-and does not submit requests in alternative capacity pools if capacity
-is unavailable. To maintain a certain target capacity, EC2 Fleet places
-the required requests to meet this target capacity. It also
-automatically replenishes any interrupted Spot Instances. Default:
+and it does not submit requests in alternative capacity pools if
+capacity is unavailable. To maintain a certain target capacity, EC2
+Fleet places the required requests to meet this target capacity. It
+also automatically replenishes any interrupted Spot Instances. Default:
 C<maintain>.
 
 
