@@ -1,6 +1,7 @@
 package Paws::EC2::HostProperties;
   use Moose;
   has Cores => (is => 'ro', isa => 'Int', request_name => 'cores', traits => ['NameInRequest']);
+  has InstanceFamily => (is => 'ro', isa => 'Str', request_name => 'instanceFamily', traits => ['NameInRequest']);
   has InstanceType => (is => 'ro', isa => 'Str', request_name => 'instanceType', traits => ['NameInRequest']);
   has Sockets => (is => 'ro', isa => 'Int', request_name => 'sockets', traits => ['NameInRequest']);
   has TotalVCpus => (is => 'ro', isa => 'Int', request_name => 'totalVCpus', traits => ['NameInRequest']);
@@ -44,10 +45,17 @@ This class has no description
   The number of cores on the Dedicated Host.
 
 
+=head2 InstanceFamily => Str
+
+  The instance family supported by the Dedicated Host. For example,
+C<m5>.
+
+
 =head2 InstanceType => Str
 
-  The instance type size that the Dedicated Host supports (for example,
-C<m3.medium>).
+  The instance type supported by the Dedicated Host. For example,
+C<m5.large>. If the host supports multiple instance types, no
+B<instanceType> is returned.
 
 
 =head2 Sockets => Int
@@ -57,7 +65,7 @@ C<m3.medium>).
 
 =head2 TotalVCpus => Int
 
-  The number of vCPUs on the Dedicated Host.
+  The total number of vCPUs on the Dedicated Host.
 
 
 
