@@ -52,10 +52,10 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           S3Key    => 'MyString',     # OPTIONAL
         },    # OPTIONAL
       },    # OPTIONAL
-      DryRun    => 1,             # OPTIONAL
-      Encrypted => 1,             # OPTIONAL
-      KmsKeyId  => 'MyString',    # OPTIONAL
-      RoleName  => 'MyString',    # OPTIONAL
+      DryRun    => 1,               # OPTIONAL
+      Encrypted => 1,               # OPTIONAL
+      KmsKeyId  => 'MyKmsKeyId',    # OPTIONAL
+      RoleName  => 'MyString',      # OPTIONAL
     );
 
     # Results:
@@ -117,11 +117,11 @@ in the I<Amazon Elastic Compute Cloud User Guide>.
 
 =head2 KmsKeyId => Str
 
-An identifier for the AWS Key Management Service (AWS KMS) customer
-master key (CMK) to use when creating the encrypted snapshot. This
-parameter is only required if you want to use a non-default CMK; if
-this parameter is not specified, the default CMK for EBS is used. If a
-C<KmsKeyId> is specified, the C<Encrypted> flag must also be set.
+An identifier for the symmetric AWS Key Management Service (AWS KMS)
+customer master key (CMK) to use when creating the encrypted snapshot.
+This parameter is only required if you want to use a non-default CMK;
+if this parameter is not specified, the default CMK for EBS is used. If
+a C<KmsKeyId> is specified, the C<Encrypted> flag must also be set.
 
 The CMK identifier may be provided in any of the following formats:
 
@@ -161,6 +161,8 @@ This action will eventually report failure.
 The specified CMK must exist in the Region that the snapshot is being
 copied to.
 
+Amazon EBS does not support asymmetric CMKs.
+
 
 
 =head2 RoleName => Str
