@@ -52,48 +52,46 @@ codes.
 
 =head2 IpProtocol => Str
 
-  The IP protocol name (C<tcp>, C<udp>, C<icmp>) or number (see Protocol
-Numbers
+  The IP protocol name (C<tcp>, C<udp>, C<icmp>, C<icmpv6>) or number
+(see Protocol Numbers
 (http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml)).
 
-[EC2-VPC only] Use C<-1> to specify all protocols. When authorizing
+[VPC only] Use C<-1> to specify all protocols. When authorizing
 security group rules, specifying C<-1> or a protocol number other than
-C<tcp>, C<udp>, C<icmp>, or C<58> (ICMPv6) allows traffic on all ports,
+C<tcp>, C<udp>, C<icmp>, or C<icmpv6> allows traffic on all ports,
 regardless of any port range you specify. For C<tcp>, C<udp>, and
-C<icmp>, you must specify a port range. For C<58> (ICMPv6), you can
-optionally specify a port range; if you don't, traffic for all types
-and codes is allowed when authorizing rules.
+C<icmp>, you must specify a port range. For C<icmpv6>, the port range
+is optional; if you omit the port range, traffic for all types and
+codes is allowed.
 
 
 =head2 IpRanges => ArrayRef[L<Paws::EC2::IpRange>]
 
-  One or more IPv4 ranges.
+  The IPv4 ranges.
 
 
 =head2 Ipv6Ranges => ArrayRef[L<Paws::EC2::Ipv6Range>]
 
-  [EC2-VPC only] One or more IPv6 ranges.
+  [VPC only] The IPv6 ranges.
 
 
 =head2 PrefixListIds => ArrayRef[L<Paws::EC2::PrefixListId>]
 
-  [EC2-VPC only] One or more prefix list IDs for an AWS service. With
-AuthorizeSecurityGroupEgress, this is the AWS service that you want to
-access through a VPC endpoint from instances associated with the
-security group.
+  [VPC only] The prefix list IDs for an AWS service. With outbound rules,
+this is the AWS service to access through a VPC endpoint from instances
+associated with the security group.
 
 
 =head2 ToPort => Int
 
   The end of port range for the TCP and UDP protocols, or an ICMP/ICMPv6
-code. A value of C<-1> indicates all ICMP/ICMPv6 codes for the
-specified ICMP type. If you specify all ICMP/ICMPv6 types, you must
-specify all codes.
+code. A value of C<-1> indicates all ICMP/ICMPv6 codes. If you specify
+all ICMP/ICMPv6 types, you must specify all codes.
 
 
 =head2 UserIdGroupPairs => ArrayRef[L<Paws::EC2::UserIdGroupPair>]
 
-  One or more security group and AWS account ID pairs.
+  The security group and AWS account ID pairs.
 
 
 
