@@ -2,6 +2,8 @@ package Paws::EC2::KeyPairInfo;
   use Moose;
   has KeyFingerprint => (is => 'ro', isa => 'Str', request_name => 'keyFingerprint', traits => ['NameInRequest']);
   has KeyName => (is => 'ro', isa => 'Str', request_name => 'keyName', traits => ['NameInRequest']);
+  has KeyPairId => (is => 'ro', isa => 'Str', request_name => 'keyPairId', traits => ['NameInRequest']);
+  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::EC2::Tag]', request_name => 'tagSet', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -21,7 +23,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::EC2::KeyPairInfo object:
 
-  $service_obj->Method(Att1 => { KeyFingerprint => $value, ..., KeyName => $value  });
+  $service_obj->Method(Att1 => { KeyFingerprint => $value, ..., Tags => $value  });
 
 =head3 Results returned from an API call
 
@@ -50,6 +52,16 @@ specified in section 4 of RFC4716.
   The name of the key pair.
 
 
+=head2 KeyPairId => Str
+
+  The ID of the key pair.
+
+
+=head2 Tags => ArrayRef[L<Paws::EC2::Tag>]
+
+  Any tags applied to the key pair.
+
+
 
 =head1 SEE ALSO
 
