@@ -4,6 +4,7 @@ package Paws::EC2::Placement;
   has AvailabilityZone => (is => 'ro', isa => 'Str', request_name => 'availabilityZone', traits => ['NameInRequest']);
   has GroupName => (is => 'ro', isa => 'Str', request_name => 'groupName', traits => ['NameInRequest']);
   has HostId => (is => 'ro', isa => 'Str', request_name => 'hostId', traits => ['NameInRequest']);
+  has HostResourceGroupArn => (is => 'ro', isa => 'Str', request_name => 'hostResourceGroupArn', traits => ['NameInRequest']);
   has PartitionNumber => (is => 'ro', isa => 'Int', request_name => 'partitionNumber', traits => ['NameInRequest']);
   has SpreadDomain => (is => 'ro', isa => 'Str', request_name => 'spreadDomain', traits => ['NameInRequest']);
   has Tenancy => (is => 'ro', isa => 'Str', request_name => 'tenancy', traits => ['NameInRequest']);
@@ -47,6 +48,8 @@ This class has no description
   The affinity setting for the instance on the Dedicated Host. This
 parameter is not supported for the ImportInstance command.
 
+This parameter is not supported by .
+
 
 =head2 AvailabilityZone => Str
 
@@ -55,6 +58,8 @@ parameter is not supported for the ImportInstance command.
 If not specified, an Availability Zone will be automatically chosen for
 you based on the load balancing criteria for the Region.
 
+This parameter is not supported by .
+
 
 =head2 GroupName => Str
 
@@ -66,17 +71,32 @@ you based on the load balancing criteria for the Region.
   The ID of the Dedicated Host on which the instance resides. This
 parameter is not supported for the ImportInstance command.
 
+This parameter is not supported by .
+
+
+=head2 HostResourceGroupArn => Str
+
+  The ARN of the host resource group in which to launch the instances. If
+you specify a host resource group ARN, omit the B<Tenancy> parameter or
+set it to C<host>.
+
+This parameter is not supported by .
+
 
 =head2 PartitionNumber => Int
 
   The number of the partition the instance is in. Valid only if the
 placement group strategy is set to C<partition>.
 
+This parameter is not supported by .
+
 
 =head2 SpreadDomain => Str
 
   Reserved for future use.
 
+This parameter is not supported by .
+
 
 =head2 Tenancy => Str
 
@@ -84,6 +104,8 @@ placement group strategy is set to C<partition>.
 instance with a tenancy of C<dedicated> runs on single-tenant hardware.
 The C<host> tenancy is not supported for the ImportInstance command.
 
+This parameter is not supported by .
+
 
 
 =head1 SEE ALSO
