@@ -1,6 +1,7 @@
 package Paws::EC2::Region;
   use Moose;
   has Endpoint => (is => 'ro', isa => 'Str', request_name => 'regionEndpoint', traits => ['NameInRequest']);
+  has OptInStatus => (is => 'ro', isa => 'Str', request_name => 'optInStatus', traits => ['NameInRequest']);
   has RegionName => (is => 'ro', isa => 'Str', request_name => 'regionName', traits => ['NameInRequest']);
 1;
 
@@ -42,6 +43,12 @@ This class has no description
   The Region service endpoint.
 
 
+=head2 OptInStatus => Str
+
+  The Region opt-in status. The possible values are
+C<opt-in-not-required>, C<opted-in>, and C<not-opted-in>.
+
+
 =head2 RegionName => Str
 
   The name of the Region.
