@@ -141,7 +141,9 @@ groups.
 
 =head2 SubnetId => Str
 
-  The ID of the subnet in which to launch the instance.
+  The IDs of the subnets in which to launch the instance. To specify
+multiple subnets, separate them using commas; for example,
+"subnet-1234abcdeexample1, subnet-0987cdef6example2".
 
 
 =head2 UserData => Str
