@@ -49,7 +49,7 @@ This class has no description
 
   A unique, case-sensitive key supplied by the client to ensure that the
 request is idempotent. For more information, see Ensuring Idempotency
-(http://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html).
+(https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html).
 
 
 =head2 CreateDate => Str
