@@ -37,11 +37,11 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $ec2 = Paws->service('EC2');
     $ec2->RevokeSecurityGroupIngress(
-      CidrIp        => 'MyString',    # OPTIONAL
-      DryRun        => 1,             # OPTIONAL
-      FromPort      => 1,             # OPTIONAL
-      GroupId       => 'MyString',    # OPTIONAL
-      GroupName     => 'MyString',    # OPTIONAL
+      CidrIp        => 'MyString',               # OPTIONAL
+      DryRun        => 1,                        # OPTIONAL
+      FromPort      => 1,                        # OPTIONAL
+      GroupId       => 'MySecurityGroupId',      # OPTIONAL
+      GroupName     => 'MySecurityGroupName',    # OPTIONAL
       IpPermissions => [
         {
           FromPort   => 1,
@@ -52,21 +52,21 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               Description => 'MyString',
             },
             ...
-          ],                          # OPTIONAL
+          ],                                     # OPTIONAL
           Ipv6Ranges => [
             {
               CidrIpv6    => 'MyString',
               Description => 'MyString',
             },
             ...
-          ],                          # OPTIONAL
+          ],                                     # OPTIONAL
           PrefixListIds => [
             {
               Description  => 'MyString',
               PrefixListId => 'MyString',
             },
             ...
-          ],                          # OPTIONAL
+          ],                                     # OPTIONAL
           ToPort           => 1,
           UserIdGroupPairs => [
             {
