@@ -39,8 +39,8 @@ This class has no description
 
 =head2 ResourceType => Str
 
-  The type of resource. Currently, the only resource type that is
-supported is C<instance>.
+  The type of resource. Currently, the only resource types that are
+supported are C<spot-fleet-request> and C<instance>.
 
 
 =head2 Tags => ArrayRef[L<Paws::EC2::Tag>]
