@@ -1,6 +1,7 @@
 package Paws::EC2::VgwTelemetry;
   use Moose;
   has AcceptedRouteCount => (is => 'ro', isa => 'Int', request_name => 'acceptedRouteCount', traits => ['NameInRequest']);
+  has CertificateArn => (is => 'ro', isa => 'Str', request_name => 'certificateArn', traits => ['NameInRequest']);
   has LastStatusChange => (is => 'ro', isa => 'Str', request_name => 'lastStatusChange', traits => ['NameInRequest']);
   has OutsideIpAddress => (is => 'ro', isa => 'Str', request_name => 'outsideIpAddress', traits => ['NameInRequest']);
   has Status => (is => 'ro', isa => 'Str', request_name => 'status', traits => ['NameInRequest']);
@@ -45,6 +46,11 @@ This class has no description
   The number of accepted routes.
 
 
+=head2 CertificateArn => Str
+
+  The Amazon Resource Name (ARN) of the VPN tunnel endpoint certificate.
+
+
 =head2 LastStatusChange => Str
 
   The date and time of the last change in status.
