@@ -1,8 +1,10 @@
 package Paws::EC2::VolumeStatusItem;
   use Moose;
   has Actions => (is => 'ro', isa => 'ArrayRef[Paws::EC2::VolumeStatusAction]', request_name => 'actionsSet', traits => ['NameInRequest']);
+  has AttachmentStatuses => (is => 'ro', isa => 'ArrayRef[Paws::EC2::VolumeStatusAttachmentStatus]', request_name => 'attachmentStatuses', traits => ['NameInRequest']);
   has AvailabilityZone => (is => 'ro', isa => 'Str', request_name => 'availabilityZone', traits => ['NameInRequest']);
   has Events => (is => 'ro', isa => 'ArrayRef[Paws::EC2::VolumeStatusEvent]', request_name => 'eventsSet', traits => ['NameInRequest']);
+  has OutpostArn => (is => 'ro', isa => 'Str', request_name => 'outpostArn', traits => ['NameInRequest']);
   has VolumeId => (is => 'ro', isa => 'Str', request_name => 'volumeId', traits => ['NameInRequest']);
   has VolumeStatus => (is => 'ro', isa => 'Paws::EC2::VolumeStatusInfo', request_name => 'volumeStatus', traits => ['NameInRequest']);
 1;
@@ -45,6 +47,11 @@ This class has no description
   The details of the operation.
 
 
+=head2 AttachmentStatuses => ArrayRef[L<Paws::EC2::VolumeStatusAttachmentStatus>]
+
+  Information about the instances to which the volume is attached.
+
+
 =head2 AvailabilityZone => Str
 
   The Availability Zone of the volume.
@@ -55,6 +62,11 @@ This class has no description
   A list of events associated with the volume.
 
 
+=head2 OutpostArn => Str
+
+  The Amazon Resource Name (ARN) of the Outpost.
+
+
 =head2 VolumeId => Str
 
   The volume ID.
