@@ -41,7 +41,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       ImageIds => [
         {
           ImageDigest => 'MyImageDigest',    # OPTIONAL
-          ImageTag    => 'MyImageTag',       # OPTIONAL
+          ImageTag    => 'MyImageTag',       # min: 1, max: 300; OPTIONAL
         },
         ...
       ],                                     # OPTIONAL
