@@ -1,6 +1,8 @@
 package Paws::ECR::Repository;
   use Moose;
   has CreatedAt => (is => 'ro', isa => 'Str', request_name => 'createdAt', traits => ['NameInRequest']);
+  has ImageScanningConfiguration => (is => 'ro', isa => 'Paws::ECR::ImageScanningConfiguration', request_name => 'imageScanningConfiguration', traits => ['NameInRequest']);
+  has ImageTagMutability => (is => 'ro', isa => 'Str', request_name => 'imageTagMutability', traits => ['NameInRequest']);
   has RegistryId => (is => 'ro', isa => 'Str', request_name => 'registryId', traits => ['NameInRequest']);
   has RepositoryArn => (is => 'ro', isa => 'Str', request_name => 'repositoryArn', traits => ['NameInRequest']);
   has RepositoryName => (is => 'ro', isa => 'Str', request_name => 'repositoryName', traits => ['NameInRequest']);
@@ -46,6 +48,16 @@ An object representing a repository.
 created.
 
 
+=head2 ImageScanningConfiguration => L<Paws::ECR::ImageScanningConfiguration>
+
+  
+
+
+=head2 ImageTagMutability => Str
+
+  The tag mutability setting for the repository.
+
+
 =head2 RegistryId => Str
 
   The AWS account ID associated with the registry that contains the
