@@ -3,7 +3,9 @@ package Paws::ECS::LinuxParameters;
   has Capabilities => (is => 'ro', isa => 'Paws::ECS::KernelCapabilities', request_name => 'capabilities', traits => ['NameInRequest']);
   has Devices => (is => 'ro', isa => 'ArrayRef[Paws::ECS::Device]', request_name => 'devices', traits => ['NameInRequest']);
   has InitProcessEnabled => (is => 'ro', isa => 'Bool', request_name => 'initProcessEnabled', traits => ['NameInRequest']);
+  has MaxSwap => (is => 'ro', isa => 'Int', request_name => 'maxSwap', traits => ['NameInRequest']);
   has SharedMemorySize => (is => 'ro', isa => 'Int', request_name => 'sharedMemorySize', traits => ['NameInRequest']);
+  has Swappiness => (is => 'ro', isa => 'Int', request_name => 'swappiness', traits => ['NameInRequest']);
   has Tmpfs => (is => 'ro', isa => 'ArrayRef[Paws::ECS::Tmpfs]', request_name => 'tmpfs', traits => ['NameInRequest']);
 1;
 
@@ -75,6 +77,23 @@ following command: C<sudo docker version --format
 '{{.Server.APIVersion}}'>
 
 
+=head2 MaxSwap => Int
+
+  The total amount of swap memory (in MiB) a container can use. This
+parameter will be translated to the C<--memory-swap> option to docker
+run (https://docs.docker.com/engine/reference/run/) where the value
+would be the sum of the container memory plus the C<maxSwap> value.
+
+If a C<maxSwap> value of C<0> is specified, the container will not use
+swap. Accepted values are C<0> or any positive integer. If the
+C<maxSwap> parameter is omitted, the container will use the swap
+configuration for the container instance it is running on. A C<maxSwap>
+value must be set for the C<swappiness> parameter to be used.
+
+If you are using tasks that use the Fargate launch type, the C<maxSwap>
+parameter is not supported.
+
+
 =head2 SharedMemorySize => Int
 
   The value for the size (in MiB) of the C</dev/shm> volume. This
@@ -85,6 +104,22 @@ If you are using tasks that use the Fargate launch type, the
 C<sharedMemorySize> parameter is not supported.
 
 
+=head2 Swappiness => Int
+
+  This allows you to tune a container's memory swappiness behavior. A
+C<swappiness> value of C<0> will cause swapping to not happen unless
+absolutely necessary. A C<swappiness> value of C<100> will cause pages
+to be swapped very aggressively. Accepted values are whole numbers
+between C<0> and C<100>. If the C<swappiness> parameter is not
+specified, a default value of C<60> is used. If a value is not
+specified for C<maxSwap> then this parameter is ignored. This parameter
+maps to the C<--memory-swappiness> option to docker run
+(https://docs.docker.com/engine/reference/run/).
+
+If you are using tasks that use the Fargate launch type, the
+C<swappiness> parameter is not supported.
+
+
 =head2 Tmpfs => ArrayRef[L<Paws::ECS::Tmpfs>]
 
   The container path, mount options, and size (in MiB) of the tmpfs
