@@ -34,28 +34,8 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::ECS::LoadBa
 
 =head1 DESCRIPTION
 
-Details on a load balancer to be used with a service or task set.
-
-If the service is using the C<ECS> deployment controller, you are
-limited to one load balancer or target group.
-
-If the service is using the C<CODE_DEPLOY> deployment controller, the
-service is required to use either an Application Load Balancer or
-Network Load Balancer. When you are creating an AWS CodeDeploy
-deployment group, you specify two target groups (referred to as a
-C<targetGroupPair>). Each target group binds to a separate task set in
-the deployment. The load balancer can also have up to two listeners, a
-required listener for production traffic and an optional listener that
-allows you to test new revisions of the service before routing
-production traffic to it.
-
-Services with tasks that use the C<awsvpc> network mode (for example,
-those with the Fargate launch type) only support Application Load
-Balancers and Network Load Balancers. Classic Load Balancers are not
-supported. Also, when you create any target groups for these services,
-you must choose C<ip> as the target type, not C<instance>. Tasks that
-use the C<awsvpc> network mode are associated with an elastic network
-interface, not an Amazon EC2 instance.
+Details on the load balancer or load balancers to use with a service or
+task set.
 
 =head1 ATTRIBUTES
 
@@ -69,9 +49,10 @@ associate with the load balancer.
 =head2 ContainerPort => Int
 
   The port on the container to associate with the load balancer. This
-port must correspond to a C<containerPort> in the service's task
-definition. Your container instances must allow ingress traffic on the
-C<hostPort> of the port mapping.
+port must correspond to a C<containerPort> in the task definition the
+tasks in the service are using. For tasks that use the EC2 launch type,
+the container instance they are launched on must allow ingress traffic
+on the C<hostPort> of the port mapping.
 
 
 =head2 LoadBalancerName => Str
@@ -79,9 +60,9 @@ C<hostPort> of the port mapping.
   The name of the load balancer to associate with the Amazon ECS service
 or task set.
 
-A load balancer name is only specified when using a classic load
-balancer. If you are using an application load balancer or a network
-load balancer this should be omitted.
+A load balancer name is only specified when using a Classic Load
+Balancer. If you are using an Application Load Balancer or a Network
+Load Balancer this should be omitted.
 
 
 =head2 TargetGroupArn => Str
@@ -89,20 +70,27 @@ load balancer this should be omitted.
   The full Amazon Resource Name (ARN) of the Elastic Load Balancing
 target group or groups associated with a service or task set.
 
-A target group ARN is only specified when using an application load
-balancer or a network load balancer. If you are using a classic load
-balancer this should be omitted.
+A target group ARN is only specified when using an Application Load
+Balancer or Network Load Balancer. If you are using a Classic Load
+Balancer this should be omitted.
 
-For services using the C<ECS> deployment controller, you are limited to
-one target group. For services using the C<CODE_DEPLOY> deployment
-controller, you are required to define two target groups for the load
-balancer.
+For services using the C<ECS> deployment controller, you can specify
+one or multiple target groups. For more information, see Registering
+Multiple Target Groups with a Service
+(https://docs.aws.amazon.com/AmazonECS/latest/developerguide/register-multiple-targetgroups.html)
+in the I<Amazon Elastic Container Service Developer Guide>.
+
+For services using the C<CODE_DEPLOY> deployment controller, you are
+required to define two target groups for the load balancer. For more
+information, see Blue/Green Deployment with CodeDeploy
+(https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-bluegreen.html)
+in the I<Amazon Elastic Container Service Developer Guide>.
 
 If your service's task definition uses the C<awsvpc> network mode
 (which is required for the Fargate launch type), you must choose C<ip>
-as the target type, not C<instance>, because tasks that use the
-C<awsvpc> network mode are associated with an elastic network
-interface, not an Amazon EC2 instance.
+as the target type, not C<instance>, when creating your target groups
+because tasks that use the C<awsvpc> network mode are associated with
+an elastic network interface, not an Amazon EC2 instance.
 
 
 
