@@ -32,10 +32,12 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::ECS::Resour
 
 =head1 DESCRIPTION
 
-The type and amount of a resource to assign to a container. The only
-supported resource is a GPU. For more information, see Working with
-GPUs on Amazon ECS
+The type and amount of a resource to assign to a container. The
+supported resource types are GPUs and Elastic Inference accelerators.
+For more information, see Working with GPUs on Amazon ECS
 (https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-gpu.html)
+or Working with Amazon Elastic Inference on Amazon ECS
+(https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-eia.html)
 in the I<Amazon Elastic Container Service Developer Guide>
 
 =head1 ATTRIBUTES
@@ -43,16 +45,23 @@ in the I<Amazon Elastic Container Service Developer Guide>
 
 =head2 B<REQUIRED> Type => Str
 
-  The type of resource to assign to a container. The only supported value
-is C<GPU>.
+  The type of resource to assign to a container. The supported values are
+C<GPU> or C<InferenceAccelerator>.
 
 
 =head2 B<REQUIRED> Value => Str
 
-  The number of physical C<GPUs> the Amazon ECS container agent will
-reserve for the container. The number of GPUs reserved for all
-containers in a task should not exceed the number of available GPUs on
-the container instance the task is launched on.
+  The value for the specified resource type.
+
+If the C<GPU> type is used, the value is the number of physical C<GPUs>
+the Amazon ECS container agent will reserve for the container. The
+number of GPUs reserved for all containers in a task should not exceed
+the number of available GPUs on the container instance the task is
+launched on.
+
+If the C<InferenceAccelerator> type is used, the C<value> should match
+the C<deviceName> for an InferenceAccelerator specified in a task
+definition.
 
 
 
