@@ -5,6 +5,7 @@ package Paws::ECS::TaskDefinition;
   has Cpu => (is => 'ro', isa => 'Str', request_name => 'cpu', traits => ['NameInRequest']);
   has ExecutionRoleArn => (is => 'ro', isa => 'Str', request_name => 'executionRoleArn', traits => ['NameInRequest']);
   has Family => (is => 'ro', isa => 'Str', request_name => 'family', traits => ['NameInRequest']);
+  has InferenceAccelerators => (is => 'ro', isa => 'ArrayRef[Paws::ECS::InferenceAccelerator]', request_name => 'inferenceAccelerators', traits => ['NameInRequest']);
   has IpcMode => (is => 'ro', isa => 'Str', request_name => 'ipcMode', traits => ['NameInRequest']);
   has Memory => (is => 'ro', isa => 'Str', request_name => 'memory', traits => ['NameInRequest']);
   has NetworkMode => (is => 'ro', isa => 'Str', request_name => 'networkMode', traits => ['NameInRequest']);
@@ -123,11 +124,19 @@ granted the permissions that are specified in this role.
 
 =head2 Family => Str
 
-  The name of a family that this task definition is registered to. A
-family groups multiple versions of a task definition. Amazon ECS gives
-the first task definition that you registered to a family a revision
-number of 1. Amazon ECS gives sequential revision numbers to each task
-definition that you add.
+  The name of a family that this task definition is registered to. Up to
+255 letters (uppercase and lowercase), numbers, hyphens, and
+underscores are allowed.
+
+A family groups multiple versions of a task definition. Amazon ECS
+gives the first task definition that you registered to a family a
+revision number of 1. Amazon ECS gives sequential revision numbers to
+each task definition that you add.
+
+
+=head2 InferenceAccelerators => ArrayRef[L<Paws::ECS::InferenceAccelerator>]
+
+  The Elastic Inference accelerator associated with the task.
 
 
 =head2 IpcMode => Str
@@ -176,11 +185,15 @@ the Fargate launch type.
 
 =head2 Memory => Str
 
-  The amount (in MiB) of memory used by the task. If using the EC2 launch
-type, this field is optional and any value can be used. If using the
-Fargate launch type, this field is required and you must use one of the
-following values, which determines your range of valid values for the
-C<cpu> parameter:
+  The amount (in MiB) of memory used by the task.
+
+If using the EC2 launch type, this field is optional and any value can
+be used. If a task-level memory value is specified then the
+container-level memory value is optional.
+
+If using the Fargate launch type, this field is required and you must
+use one of the following values, which determines your range of valid
+values for the C<cpu> parameter:
 
 =over
 
@@ -264,7 +277,7 @@ I<Docker run reference>.
   The process namespace to use for the containers in the task. The valid
 values are C<host> or C<task>. If C<host> is specified, then all
 containers within the tasks that specified the C<host> PID mode on the
-same container instance share the same IPC resources with the host
+same container instance share the same process namespace with the host
 Amazon EC2 instance. If C<task> is specified, all containers within the
 specified task share the same process namespace. If no value is
 specified, the default is a private namespace. For more information,
@@ -335,9 +348,10 @@ deregistered previous revisions in this family.
 
 =head2 TaskRoleArn => Str
 
-  The Amazon Resource Name (ARN) of an AWS Identity and Access Management
-(IAM) role that grants containers in the task permission to call AWS
-APIs on your behalf. For more information, see Amazon ECS Task Role
+  The short name or full Amazon Resource Name (ARN) of the AWS Identity
+and Access Management (IAM) role that grants containers in the task
+permission to call AWS APIs on your behalf. For more information, see
+Amazon ECS Task Role
 (https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_IAM_role.html)
 in the I<Amazon Elastic Container Service Developer Guide>.
 
