@@ -1,5 +1,6 @@
 package Paws::ECS::TaskSet;
   use Moose;
+  has CapacityProviderStrategy => (is => 'ro', isa => 'ArrayRef[Paws::ECS::CapacityProviderStrategyItem]', request_name => 'capacityProviderStrategy', traits => ['NameInRequest']);
   has ClusterArn => (is => 'ro', isa => 'Str', request_name => 'clusterArn', traits => ['NameInRequest']);
   has ComputedDesiredCount => (is => 'ro', isa => 'Int', request_name => 'computedDesiredCount', traits => ['NameInRequest']);
   has CreatedAt => (is => 'ro', isa => 'Str', request_name => 'createdAt', traits => ['NameInRequest']);
@@ -18,6 +19,7 @@ package Paws::ECS::TaskSet;
   has StabilityStatusAt => (is => 'ro', isa => 'Str', request_name => 'stabilityStatusAt', traits => ['NameInRequest']);
   has StartedBy => (is => 'ro', isa => 'Str', request_name => 'startedBy', traits => ['NameInRequest']);
   has Status => (is => 'ro', isa => 'Str', request_name => 'status', traits => ['NameInRequest']);
+  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::ECS::Tag]', request_name => 'tags', traits => ['NameInRequest']);
   has TaskDefinition => (is => 'ro', isa => 'Str', request_name => 'taskDefinition', traits => ['NameInRequest']);
   has TaskSetArn => (is => 'ro', isa => 'Str', request_name => 'taskSetArn', traits => ['NameInRequest']);
   has UpdatedAt => (is => 'ro', isa => 'Str', request_name => 'updatedAt', traits => ['NameInRequest']);
@@ -40,14 +42,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::ECS::TaskSet object:
 
-  $service_obj->Method(Att1 => { ClusterArn => $value, ..., UpdatedAt => $value  });
+  $service_obj->Method(Att1 => { CapacityProviderStrategy => $value, ..., UpdatedAt => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::ECS::TaskSet object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->ClusterArn
+  $result->Att1->CapacityProviderStrategy
 
 =head1 DESCRIPTION
 
@@ -59,6 +61,11 @@ whether the task set serves production traffic.
 =head1 ATTRIBUTES
 
 
+=head2 CapacityProviderStrategy => ArrayRef[L<Paws::ECS::CapacityProviderStrategyItem>]
+
+  The capacity provider strategy associated with the task set.
+
+
 =head2 ClusterArn => Str
 
   The Amazon Resource Name (ARN) of the cluster that the service that
@@ -183,11 +190,6 @@ status.
 All tasks are reporting a healthy status from the load balancers,
 service discovery, and container health checks.
 
-If a C<healthCheckGracePeriodSeconds> value was set when the service
-was created, you may see a C<STEADY_STATE> reached since unhealthy
-Elastic Load Balancing target health checks will be ignored until it
-expires.
-
 =back
 
 If any of those conditions are not met, the stability status returns
@@ -231,6 +233,57 @@ targets are being deregistered from their target group.
 
 
 
+=head2 Tags => ArrayRef[L<Paws::ECS::Tag>]
+
+  The metadata that you apply to the task set to help you categorize and
+organize them. Each tag consists of a key and an optional value, both
+of which you define.
+
+The following basic restrictions apply to tags:
+
+=over
+
+=item *
+
+Maximum number of tags per resource - 50
+
+=item *
+
+For each resource, each tag key must be unique, and each tag key can
+have only one value.
+
+=item *
+
+Maximum key length - 128 Unicode characters in UTF-8
+
+=item *
+
+Maximum value length - 256 Unicode characters in UTF-8
+
+=item *
+
+If your tagging schema is used across multiple services and resources,
+remember that other services may have restrictions on allowed
+characters. Generally allowed characters are: letters, numbers, and
+spaces representable in UTF-8, and the following characters: + - = . _
+: / @.
+
+=item *
+
+Tag keys and values are case-sensitive.
+
+=item *
+
+Do not use C<aws:>, C<AWS:>, or any upper or lowercase combination of
+such as a prefix for either keys or values as it is reserved for AWS
+use. You cannot edit or delete tag keys or values with this prefix.
+Tags with this prefix do not count against your tags per resource
+limit.
+
+=back
+
+
+
 =head2 TaskDefinition => Str
 
   The task definition the task set is using.
