@@ -6,6 +6,7 @@ package Paws::EKS::CreateCluster;
   has Name => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'name', required => 1);
   has ResourcesVpcConfig => (is => 'ro', isa => 'Paws::EKS::VpcConfigRequest', traits => ['NameInRequest'], request_name => 'resourcesVpcConfig', required => 1);
   has RoleArn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'roleArn', required => 1);
+  has Tags => (is => 'ro', isa => 'Paws::EKS::TagMap', traits => ['NameInRequest'], request_name => 'tags');
   has Version => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'version');
 
   use MooseX::ClassAttribute;
@@ -38,6 +39,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       ResourcesVpcConfig => {
         EndpointPrivateAccess => 1,                      # OPTIONAL
         EndpointPublicAccess  => 1,                      # OPTIONAL
+        PublicAccessCidrs     => [ 'MyString', ... ],    # OPTIONAL
         SecurityGroupIds      => [ 'MyString', ... ],    # OPTIONAL
         SubnetIds             => [ 'MyString', ... ],    # OPTIONAL
       },
@@ -55,6 +57,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           ...
         ],        # OPTIONAL
       },    # OPTIONAL
+      Tags => {
+        'MyTagKey' => 'MyTagValue',    # key: min: 1, max: 128, value: max: 256
+      },    # OPTIONAL
       Version => 'MyString',    # OPTIONAL
     );
 
@@ -121,6 +126,14 @@ in the I< I<Amazon EKS User Guide> >.
 
 
 
+=head2 Tags => L<Paws::EKS::TagMap>
+
+The metadata to apply to the cluster to assist with categorization and
+organization. Each tag consists of a key and an optional value, both of
+which you define.
+
+
+
 =head2 Version => Str
 
 The desired Kubernetes version for your cluster. If you don't specify a
