@@ -2,7 +2,9 @@ package Paws::ES::ElasticsearchDomainConfig;
   use Moose;
   has AccessPolicies => (is => 'ro', isa => 'Paws::ES::AccessPoliciesStatus');
   has AdvancedOptions => (is => 'ro', isa => 'Paws::ES::AdvancedOptionsStatus');
+  has AdvancedSecurityOptions => (is => 'ro', isa => 'Paws::ES::AdvancedSecurityOptionsStatus');
   has CognitoOptions => (is => 'ro', isa => 'Paws::ES::CognitoOptionsStatus');
+  has DomainEndpointOptions => (is => 'ro', isa => 'Paws::ES::DomainEndpointOptionsStatus');
   has EBSOptions => (is => 'ro', isa => 'Paws::ES::EBSOptionsStatus');
   has ElasticsearchClusterConfig => (is => 'ro', isa => 'Paws::ES::ElasticsearchClusterConfigStatus');
   has ElasticsearchVersion => (is => 'ro', isa => 'Paws::ES::ElasticsearchVersionStatus');
@@ -59,6 +61,11 @@ Advanced Options
 for more information.
 
 
+=head2 AdvancedSecurityOptions => L<Paws::ES::AdvancedSecurityOptionsStatus>
+
+  Specifies C<AdvancedSecurityOptions> for the domain.
+
+
 =head2 CognitoOptions => L<Paws::ES::CognitoOptionsStatus>
 
   The C<CognitoOptions> for the specified domain. For more information,
@@ -66,6 +73,11 @@ see Amazon Cognito Authentication for Kibana
 (http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-cognito-auth.html).
 
 
+=head2 DomainEndpointOptions => L<Paws::ES::DomainEndpointOptionsStatus>
+
+  Specifies the C<DomainEndpointOptions> for the Elasticsearch domain.
+
+
 =head2 EBSOptions => L<Paws::ES::EBSOptionsStatus>
 
   Specifies the C<EBSOptions> for the Elasticsearch domain.
