@@ -1,5 +1,6 @@
 package Paws::ElastiCache::PendingModifiedValues;
   use Moose;
+  has AuthTokenStatus => (is => 'ro', isa => 'Str');
   has CacheNodeIdsToRemove => (is => 'ro', isa => 'ArrayRef[Str|Undef]', request_name => 'CacheNodeId', traits => ['NameInRequest']);
   has CacheNodeType => (is => 'ro', isa => 'Str');
   has EngineVersion => (is => 'ro', isa => 'Str');
@@ -23,14 +24,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::ElastiCache::PendingModifiedValues object:
 
-  $service_obj->Method(Att1 => { CacheNodeIdsToRemove => $value, ..., NumCacheNodes => $value  });
+  $service_obj->Method(Att1 => { AuthTokenStatus => $value, ..., NumCacheNodes => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::ElastiCache::PendingModifiedValues object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->CacheNodeIdsToRemove
+  $result->Att1->AuthTokenStatus
 
 =head1 DESCRIPTION
 
@@ -40,6 +41,11 @@ that are currently being applied.
 =head1 ATTRIBUTES
 
 
+=head2 AuthTokenStatus => Str
+
+  The auth token status
+
+
 =head2 CacheNodeIdsToRemove => ArrayRef[Str|Undef]
 
   A list of cache node IDs that are being removed (or will be removed)
