@@ -45,8 +45,8 @@ Details of the resource that is not protected by the policy.
 
 =head2 ResourceType => Str
 
-  The resource type. This is in the format shown in AWS Resource Types
-Reference
+  The resource type. This is in the format shown in the AWS Resource
+Types Reference
 (https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html).
 For example: C<AWS::ElasticLoadBalancingV2::LoadBalancer> or
 C<AWS::CloudFront::Distribution>.
