@@ -37,30 +37,30 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::FMS::Policy
 
 =head1 DESCRIPTION
 
-Describes the non-compliant resources in a member account for a
-specific AWS Firewall Manager policy. A maximum of 100 entries are
-displayed. If more than 100 resources are non-compliant,
-C<EvaluationLimitExceeded> is set to C<True>.
+Describes the noncompliant resources in a member account for a specific
+AWS Firewall Manager policy. A maximum of 100 entries are displayed. If
+more than 100 resources are noncompliant, C<EvaluationLimitExceeded> is
+set to C<True>.
 
 =head1 ATTRIBUTES
 
 
 =head2 EvaluationLimitExceeded => Bool
 
-  Indicates if over 100 resources are non-compliant with the AWS Firewall
+  Indicates if over 100 resources are noncompliant with the AWS Firewall
 Manager policy.
 
 
 =head2 ExpiredAt => Str
 
-  A time stamp that indicates when the returned information should be
-considered out-of-date.
+  A timestamp that indicates when the returned information should be
+considered out of date.
 
 
 =head2 IssueInfoMap => L<Paws::FMS::IssueInfoMap>
 
   Details about problems with dependent services, such as AWS WAF or AWS
-Config, that are causing a resource to be non-compliant. The details
+Config, that are causing a resource to be noncompliant. The details
 include the name of the dependent service and the error message
 received that indicates the problem with the service.
 
@@ -82,7 +82,9 @@ received that indicates the problem with the service.
 
 =head2 Violators => ArrayRef[L<Paws::FMS::ComplianceViolator>]
 
-  An array of resources that are not protected by the policy.
+  An array of resources that aren't protected by the AWS WAF or Shield
+Advanced policy or that aren't in compliance with the security group
+policy.
 
 
 
