@@ -73,13 +73,16 @@ Describes the configuration of a destination in Amazon Redshift.
 
 =head2 RetryOptions => L<Paws::Firehose::RedshiftRetryOptions>
 
-  The retry behavior in case Kinesis Firehose is unable to deliver
+  The retry behavior in case Kinesis Data Firehose is unable to deliver
 documents to Amazon Redshift. Default value is 3600 (60 minutes).
 
 
 =head2 B<REQUIRED> RoleARN => Str
 
-  The ARN of the AWS credentials.
+  The Amazon Resource Name (ARN) of the AWS credentials. For more
+information, see Amazon Resource Names (ARNs) and AWS Service
+Namespaces
+(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html).
 
 
 =head2 S3BackupConfiguration => L<Paws::Firehose::S3DestinationConfiguration>
@@ -99,7 +102,7 @@ Amazon Redshift obtains data. Restrictions are described in the topic
 for CreateDeliveryStream.
 
 The compression formats C<SNAPPY> or C<ZIP> cannot be specified in
-B<RedshiftDestinationConfiguration.S3Configuration> because the Amazon
+C<RedshiftDestinationConfiguration.S3Configuration> because the Amazon
 Redshift C<COPY> operation that reads from the S3 bucket doesn't
 support these compression formats.
 
@@ -116,9 +119,9 @@ This class forms part of L<Paws>, describing an object used in L<Paws::Firehose>
 
 =head1 BUGS and CONTRIBUTIONS
 
-The source code is located here: https://github.com/pplu/aws-sdk-perl
+The source code is located here: L<https://github.com/pplu/aws-sdk-perl>
 
-Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues
+Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>
 
 =cut
 
