@@ -14,6 +14,7 @@ package Paws::GameLift::CreateMatchmakingConfiguration;
   has NotificationTarget => (is => 'ro', isa => 'Str');
   has RequestTimeoutSeconds => (is => 'ro', isa => 'Int', required => 1);
   has RuleSetName => (is => 'ro', isa => 'Str', required => 1);
+  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::GameLift::Tag]');
 
   use MooseX::ClassAttribute;
 
@@ -47,7 +48,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       ],
       Name                     => 'MyMatchmakingIdStringModel',
       RequestTimeoutSeconds    => 1,
-      RuleSetName              => 'MyMatchmakingIdStringModel',
+      RuleSetName              => 'MyMatchmakingRuleSetName',
       AcceptanceTimeoutSeconds => 1,                              # OPTIONAL
       AdditionalPlayerCount    => 1,                              # OPTIONAL
       BackfillMode             => 'AUTOMATIC',                    # OPTIONAL
@@ -63,6 +64,14 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       ],                                                          # OPTIONAL
       GameSessionData    => 'MyGameSessionData',                  # OPTIONAL
       NotificationTarget => 'MySnsArnStringModel',                # OPTIONAL
+      Tags               => [
+        {
+          Key   => 'MyTagKey',      # min: 1, max: 128
+          Value => 'MyTagValue',    # max: 256
+
+        },
+        ...
+      ],                            # OPTIONAL
       );
 
     # Results:
@@ -78,37 +87,39 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/gam
 
 =head2 B<REQUIRED> AcceptanceRequired => Bool
 
-Flag that determines whether a match that was created with this
+A flag that determines whether a match that was created with this
 configuration must be accepted by the matched players. To require
-acceptance, set to TRUE.
+acceptance, set to C<TRUE>.
 
 
 
 =head2 AcceptanceTimeoutSeconds => Int
 
-Length of time (in seconds) to wait for players to accept a proposed
-match. If any player rejects the match or fails to accept before the
-timeout, the ticket continues to look for an acceptable match.
+The length of time (in seconds) to wait for players to accept a
+proposed match. If any player rejects the match or fails to accept
+before the timeout, the ticket continues to look for an acceptable
+match.
 
 
 
 =head2 AdditionalPlayerCount => Int
 
-Number of player slots in a match to keep open for future players. For
-example, if the configuration's rule set specifies a match for a single
-12-person team, and the additional player count is set to 2, only 10
-players are selected for the match.
+The number of player slots in a match to keep open for future players.
+For example, assume that the configuration's rule set specifies a match
+for a single 12-person team. If the additional player count is set to
+2, only 10 players are initially selected for the match.
 
 
 
 =head2 BackfillMode => Str
 
-Method used to backfill game sessions created with this matchmaking
-configuration. Specify MANUAL when your game manages backfill requests
-manually or does not use the match backfill feature. Specify AUTOMATIC
-to have GameLift create a StartMatchBackfill request whenever a game
-session has one or more open slots. Learn more about manual and
-automatic backfill in Backfill Existing Games with FlexMatch
+The method used to backfill game sessions that are created with this
+matchmaking configuration. Specify C<MANUAL> when your game manages
+backfill requests manually or does not use the match backfill feature.
+Specify C<AUTOMATIC> to have GameLift create a StartMatchBackfill
+request whenever a game session has one or more open slots. Learn more
+about manual and automatic backfill in Backfill Existing Games with
+FlexMatch
 (https://docs.aws.amazon.com/gamelift/latest/developerguide/match-backfill.html).
 
 Valid values are: C<"AUTOMATIC">, C<"MANUAL">
@@ -122,13 +133,13 @@ configuration.
 
 =head2 Description => Str
 
-Meaningful description of the matchmaking configuration.
+A human-readable description of the matchmaking configuration.
 
 
 
 =head2 GameProperties => ArrayRef[L<Paws::GameLift::GameProperty>]
 
-Set of custom properties for a game session, formatted as key:value
+A set of custom properties for a game session, formatted as key-value
 pairs. These properties are passed to a game server process in the
 GameSession object with a request to start a new game session (see
 Start a Game Session
@@ -140,7 +151,7 @@ for a successful match.
 
 =head2 GameSessionData => Str
 
-Set of custom game session properties, formatted as a single string
+A set of custom game session properties, formatted as a single string
 value. This data is passed to a game server process in the GameSession
 object with a request to start a new game session (see Start a Game
 Session
@@ -153,42 +164,56 @@ for a successful match.
 =head2 B<REQUIRED> GameSessionQueueArns => ArrayRef[Str|Undef]
 
 Amazon Resource Name (ARN
-(https://docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html))
-that is assigned to a game session queue and uniquely identifies it.
-Format is C<arn:aws:gamelift:E<lt>regionE<gt>:E<lt>aws
-accountE<gt>:gamesessionqueue/E<lt>queue nameE<gt>>. These queues are
+(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html))
+that is assigned to a GameLift game session queue resource and uniquely
+identifies it. ARNs are unique across all Regions. These queues are
 used when placing game sessions for matches that are created with this
-matchmaking configuration. Queues can be located in any region.
+matchmaking configuration. Queues can be located in any Region.
 
 
 
 =head2 B<REQUIRED> Name => Str
 
-Unique identifier for a matchmaking configuration. This name is used to
-identify the configuration associated with a matchmaking request or
+A unique identifier for a matchmaking configuration. This name is used
+to identify the configuration associated with a matchmaking request or
 ticket.
 
 
 
 =head2 NotificationTarget => Str
 
-SNS topic ARN that is set up to receive matchmaking notifications.
+An SNS topic ARN that is set up to receive matchmaking notifications.
 
 
 
 =head2 B<REQUIRED> RequestTimeoutSeconds => Int
 
-Maximum duration, in seconds, that a matchmaking ticket can remain in
-process before timing out. Requests that fail due to timing out can be
-resubmitted as needed.
+The maximum duration, in seconds, that a matchmaking ticket can remain
+in process before timing out. Requests that fail due to timing out can
+be resubmitted as needed.
 
 
 
 =head2 B<REQUIRED> RuleSetName => Str
 
-Unique identifier for a matchmaking rule set to use with this
-configuration. A matchmaking configuration can only use rule sets that
-are defined in the same region.
+A unique identifier for a matchmaking rule set to use with this
+configuration. You can use either the rule set name or ARN value. A
+matchmaking configuration can only use rule sets that are defined in
+the same Region.
+
+
+
+=head2 Tags => ArrayRef[L<Paws::GameLift::Tag>]
+
+A list of labels to assign to the new matchmaking configuration
+resource. Tags are developer-defined key-value pairs. Tagging AWS
+resources are useful for resource management, access management and
+cost allocation. For more information, see Tagging AWS Resources
+(https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in the
+I<AWS General Reference>. Once the resource is created, you can use
+TagResource, UntagResource, and ListTagsForResource to add, remove, and
+view tags. The maximum tag limit may be lower than stated. See the AWS
+General Reference for actual tagging limits.
 
 
 
