@@ -88,7 +88,7 @@ DeleteGameSessionQueue
 
 =head2 Destinations => ArrayRef[L<Paws::GameLift::GameSessionQueueDestination>]
 
-  List of fleets that can be used to fulfill game session placement
+  A list of fleets that can be used to fulfill game session placement
 requests in the queue. Fleets are identified by either a fleet ARN or a
 fleet alias ARN. Destinations are listed in default preference order.
 
@@ -96,25 +96,25 @@ fleet alias ARN. Destinations are listed in default preference order.
 =head2 GameSessionQueueArn => Str
 
   Amazon Resource Name (ARN
-(https://docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html))
-that is assigned to a game session queue and uniquely identifies it.
-Format is C<arn:aws:gamelift:E<lt>regionE<gt>:E<lt>aws
-accountE<gt>:gamesessionqueue/E<lt>queue nameE<gt>>.
+(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html))
+that is assigned to a GameLift game session queue resource and uniquely
+identifies it. ARNs are unique across all Regions. In a GameLift game
+session queue ARN, the resource ID matches the I<Name> value.
 
 
 =head2 Name => Str
 
-  Descriptive label that is associated with game session queue. Queue
-names must be unique within each region.
+  A descriptive label that is associated with game session queue. Queue
+names must be unique within each Region.
 
 
 =head2 PlayerLatencyPolicies => ArrayRef[L<Paws::GameLift::PlayerLatencyPolicy>]
 
-  Collection of latency policies to apply when processing game sessions
+  A collection of latency policies to apply when processing game sessions
 placement requests with player latency information. Multiple policies
 are evaluated in order of the maximum latency value, starting with the
-lowest latency values. With just one policy, it is enforced at the
-start of the game session placement for the duration period. With
+lowest latency values. With just one policy, the policy is enforced at
+the start of the game session placement for the duration period. With
 multiple policies, each policy is enforced consecutively for its
 duration period. For example, a queue might enforce a 60-second policy
 followed by a 120-second policy, and then no policy for the remainder
@@ -123,7 +123,7 @@ of the placement.
 
 =head2 TimeoutInSeconds => Int
 
-  Maximum time, in seconds, that a new game session placement request
+  The maximum time, in seconds, that a new game session placement request
 remains in the queue. When a request exceeds this time, the game
 session placement changes to a C<TIMED_OUT> status.
 
