@@ -1,6 +1,7 @@
 package Paws::GameLift::MatchmakingRuleSet;
   use Moose;
   has CreationTime => (is => 'ro', isa => 'Str');
+  has RuleSetArn => (is => 'ro', isa => 'Str');
   has RuleSetBody => (is => 'ro', isa => 'Str', required => 1);
   has RuleSetName => (is => 'ro', isa => 'Str');
 1;
@@ -87,20 +88,30 @@ variance between players after 30 seconds.
 
 =head2 CreationTime => Str
 
-  Time stamp indicating when this data object was created. Format is a
-number expressed in Unix time as milliseconds (for example
+  The time stamp indicating when this data object was created. The format
+is a number expressed in Unix time as milliseconds (for example
 "1469498468.057").
 
 
+=head2 RuleSetArn => Str
+
+  Amazon Resource Name (ARN
+(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html))
+that is assigned to a GameLift matchmaking rule set resource and
+uniquely identifies it. ARNs are unique across all Regions. In a
+GameLift rule set ARN, the resource ID matches the I<RuleSetName>
+value.
+
+
 =head2 B<REQUIRED> RuleSetBody => Str
 
-  Collection of matchmaking rules, formatted as a JSON string. Comments
+  A collection of matchmaking rules, formatted as a JSON string. Comments
 are not allowed in JSON, but most elements support a description field.
 
 
 =head2 RuleSetName => Str
 
-  Unique identifier for a matchmaking rule set
+  A unique identifier for a matchmaking rule set
 
 
 
