@@ -45,27 +45,28 @@ completed.
 =head2 LatencyInMs => L<Paws::GameLift::LatencyMap>
 
   Set of values, expressed in milliseconds, indicating the amount of
-latency that a player experiences when connected to AWS regions. If
+latency that a player experiences when connected to AWS Regions. If
 this property is present, FlexMatch considers placing the match only in
-regions for which latency is reported.
+Regions for which latency is reported.
 
 If a matchmaker has a rule that evaluates player latency, players must
 report latency in order to be matched. If no latency is reported in
-this scenario, FlexMatch assumes that no regions are available to the
+this scenario, FlexMatch assumes that no Regions are available to the
 player and the ticket is not matchable.
 
 
 =head2 PlayerAttributes => L<Paws::GameLift::PlayerAttributeMap>
 
-  Collection of key:value pairs containing player information for use in
-matchmaking. Player attribute keys must match the I<playerAttributes>
-used in a matchmaking rule set. Example: C<"PlayerAttributes":
-{"skill": {"N": "23"}, "gameMode": {"S": "deathmatch"}}>.
+  A collection of key:value pairs containing player information for use
+in matchmaking. Player attribute keys must match the
+I<playerAttributes> used in a matchmaking rule set. Example:
+C<"PlayerAttributes": {"skill": {"N": "23"}, "gameMode": {"S":
+"deathmatch"}}>.
 
 
 =head2 PlayerId => Str
 
-  Unique identifier for a player
+  A unique identifier for a player
 
 
 =head2 Team => Str
