@@ -34,34 +34,35 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::GameLift::S
 
 =head1 DESCRIPTION
 
-Location in Amazon Simple Storage Service (Amazon S3) where build or
-script files are stored for access by Amazon GameLift. This location is
-specified in CreateBuild, CreateScript, and UpdateScript requests.
+The location in Amazon S3 where build or script files are stored for
+access by Amazon GameLift. This location is specified in CreateBuild,
+CreateScript, and UpdateScript requests.
 
 =head1 ATTRIBUTES
 
 
 =head2 Bucket => Str
 
-  Amazon S3 bucket identifier. This is the name of the S3 bucket.
+  An Amazon S3 bucket identifier. This is the name of the S3 bucket.
 
 
 =head2 Key => Str
 
-  Name of the zip file containing the build files or script files.
+  The name of the zip file that contains the build files or script files.
 
 
 =head2 ObjectVersion => Str
 
-  Version of the file, if object versioning is turned on for the bucket.
-Amazon GameLift uses this information when retrieving files from an S3
-bucket that you own. Use this parameter to specify a specific version
-of the file; if not set, the latest version of the file is retrieved.
+  The version of the file, if object versioning is turned on for the
+bucket. Amazon GameLift uses this information when retrieving files
+from an S3 bucket that you own. Use this parameter to specify a
+specific version of the file. If not set, the latest version of the
+file is retrieved.
 
 
 =head2 RoleArn => Str
 
-  Amazon Resource Name (ARN
+  The Amazon Resource Name (ARN
 (https://docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html))
 for an IAM role that allows Amazon GameLift to access the S3 bucket.
 
