@@ -1,8 +1,9 @@
 
 package Paws::Glacier::GetVaultNotificationsOutput;
   use Moose;
-  has VaultNotificationConfig => (is => 'ro', isa => 'Paws::Glacier::VaultNotificationConfig');
-
+  has VaultNotificationConfig => (is => 'ro', isa => 'Paws::Glacier::VaultNotificationConfig', traits => ['NameInRequest'], request_name => 'vaultNotificationConfig');
+  use MooseX::ClassAttribute;
+  class_has _stream_param => (is => 'ro', default => 'VaultNotificationConfig');
   has _request_id => (is => 'ro', isa => 'Str');
 1;
 
