@@ -1,6 +1,7 @@
 package Paws::Glue::Action;
   use Moose;
   has Arguments => (is => 'ro', isa => 'Paws::Glue::GenericMap');
+  has CrawlerName => (is => 'ro', isa => 'Str');
   has JobName => (is => 'ro', isa => 'Str');
   has NotificationProperty => (is => 'ro', isa => 'Paws::Glue::NotificationProperty');
   has SecurityConfiguration => (is => 'ro', isa => 'Str');
@@ -42,22 +43,28 @@ Defines an action to be initiated by a trigger.
 
 =head2 Arguments => L<Paws::Glue::GenericMap>
 
-  Arguments to be passed to the job run.
+  The job arguments used when this trigger fires. For this job run, they
+replace the default arguments set in the job definition itself.
 
 You can specify arguments here that your own job-execution script
 consumes, as well as arguments that AWS Glue itself consumes.
 
 For information about how to specify and consume your own Job
 arguments, see the Calling AWS Glue APIs in Python
-(http://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html)
+(https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html)
 topic in the developer guide.
 
 For information about the key-value pairs that AWS Glue consumes to set
 up your job, see the Special Parameters Used by AWS Glue
-(http://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html)
+(https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html)
 topic in the developer guide.
 
 
+=head2 CrawlerName => Str
+
+  The name of the crawler to be used with this action.
+
+
 =head2 JobName => Str
 
   The name of a job to be executed.
@@ -70,14 +77,14 @@ topic in the developer guide.
 
 =head2 SecurityConfiguration => Str
 
-  The name of the SecurityConfiguration structure to be used with this
+  The name of the C<SecurityConfiguration> structure to be used with this
 action.
 
 
 =head2 Timeout => Int
 
-  The JobRun timeout in minutes. This is the maximum time that a job run
-can consume resources before it is terminated and enters C<TIMEOUT>
+  The C<JobRun> timeout in minutes. This is the maximum time that a job
+run can consume resources before it is terminated and enters C<TIMEOUT>
 status. The default is 2,880 minutes (48 hours). This overrides the
 timeout value set in the parent job.
 
