@@ -7,10 +7,12 @@ package Paws::Glue::CreateJob;
   has DefaultArguments => (is => 'ro', isa => 'Paws::Glue::GenericMap');
   has Description => (is => 'ro', isa => 'Str');
   has ExecutionProperty => (is => 'ro', isa => 'Paws::Glue::ExecutionProperty');
+  has GlueVersion => (is => 'ro', isa => 'Str');
   has LogUri => (is => 'ro', isa => 'Str');
   has MaxCapacity => (is => 'ro', isa => 'Num');
   has MaxRetries => (is => 'ro', isa => 'Int');
   has Name => (is => 'ro', isa => 'Str', required => 1);
+  has NonOverridableArguments => (is => 'ro', isa => 'Paws::Glue::GenericMap');
   has NotificationProperty => (is => 'ro', isa => 'Paws::Glue::NotificationProperty');
   has NumberOfWorkers => (is => 'ro', isa => 'Int');
   has Role => (is => 'ro', isa => 'Str', required => 1);
@@ -64,19 +66,23 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       ExecutionProperty => {
         MaxConcurrentRuns => 1,                      # OPTIONAL
       },    # OPTIONAL
-      LogUri               => 'MyUriString',    # OPTIONAL
-      MaxCapacity          => 1,                # OPTIONAL
-      MaxRetries           => 1,                # OPTIONAL
+      GlueVersion             => 'MyGlueVersionString',    # OPTIONAL
+      LogUri                  => 'MyUriString',            # OPTIONAL
+      MaxCapacity             => 1,                        # OPTIONAL
+      MaxRetries              => 1,                        # OPTIONAL
+      NonOverridableArguments => {
+        'MyGenericString' => 'MyGenericString', # key: OPTIONAL, value: OPTIONAL
+      },    # OPTIONAL
       NotificationProperty => {
-        NotifyDelayAfter => 1,                  # min: 1; OPTIONAL
+        NotifyDelayAfter => 1,    # min: 1; OPTIONAL
       },    # OPTIONAL
       NumberOfWorkers       => 1,                 # OPTIONAL
       SecurityConfiguration => 'MyNameString',    # OPTIONAL
       Tags                  => {
         'MyTagKey' => 'MyTagValue',    # key: min: 1, max: 128, value: max: 256
       },    # OPTIONAL
-      Timeout    => 1,                 # OPTIONAL
-      WorkerType => 'MyNameString',    # OPTIONAL
+      Timeout    => 1,             # OPTIONAL
+      WorkerType => 'Standard',    # OPTIONAL
     );
 
     # Results:
@@ -146,6 +152,22 @@ runs allowed for this job.
 
 
 
+=head2 GlueVersion => Str
+
+Glue version determines the versions of Apache Spark and Python that
+AWS Glue supports. The Python version indicates the version supported
+for jobs of type Spark.
+
+For more information about the available AWS Glue versions and
+corresponding Spark and Python versions, see Glue version
+(https://docs.aws.amazon.com/glue/latest/dg/add-job.html) in the
+developer guide.
+
+Jobs that are created without specifying a Glue version default to Glue
+0.9.
+
+
+
 =head2 LogUri => Str
 
 This field is reserved for future use.
@@ -198,6 +220,12 @@ account.
 
 
 
+=head2 NonOverridableArguments => L<Paws::Glue::GenericMap>
+
+Non-overridable arguments for this job, specified as name-value pairs.
+
+
+
 =head2 NotificationProperty => L<Paws::Glue::NotificationProperty>
 
 Specifies configuration properties of a job notification.
@@ -272,7 +300,7 @@ recommend this worker type for memory-intensive jobs.
 =back
 
 
-
+Valid values are: C<"Standard">, C<"G.1X">, C<"G.2X">
 
 
 =head1 SEE ALSO
