@@ -7,11 +7,13 @@ package Paws::Glue::Job;
   has DefaultArguments => (is => 'ro', isa => 'Paws::Glue::GenericMap');
   has Description => (is => 'ro', isa => 'Str');
   has ExecutionProperty => (is => 'ro', isa => 'Paws::Glue::ExecutionProperty');
+  has GlueVersion => (is => 'ro', isa => 'Str');
   has LastModifiedOn => (is => 'ro', isa => 'Str');
   has LogUri => (is => 'ro', isa => 'Str');
   has MaxCapacity => (is => 'ro', isa => 'Num');
   has MaxRetries => (is => 'ro', isa => 'Int');
   has Name => (is => 'ro', isa => 'Str');
+  has NonOverridableArguments => (is => 'ro', isa => 'Paws::Glue::GenericMap');
   has NotificationProperty => (is => 'ro', isa => 'Paws::Glue::NotificationProperty');
   has NumberOfWorkers => (is => 'ro', isa => 'Int');
   has Role => (is => 'ro', isa => 'Str');
@@ -108,6 +110,21 @@ topic in the developer guide.
 runs allowed for this job.
 
 
+=head2 GlueVersion => Str
+
+  Glue version determines the versions of Apache Spark and Python that
+AWS Glue supports. The Python version indicates the version supported
+for jobs of type Spark.
+
+For more information about the available AWS Glue versions and
+corresponding Spark and Python versions, see Glue version
+(https://docs.aws.amazon.com/glue/latest/dg/add-job.html) in the
+developer guide.
+
+Jobs that are created without specifying a Glue version default to Glue
+0.9.
+
+
 =head2 LastModifiedOn => Str
 
   The last point in time when this job definition was modified.
@@ -160,6 +177,11 @@ allocation.
   The name you assign to this job definition.
 
 
+=head2 NonOverridableArguments => L<Paws::Glue::GenericMap>
+
+  Non-overridable arguments for this job, specified as name-value pairs.
+
+
 =head2 NotificationProperty => L<Paws::Glue::NotificationProperty>
 
   Specifies configuration properties of a job notification.
