@@ -40,14 +40,14 @@ multiple requests to be executed in parallel.
 
 =head2 B<REQUIRED> SegmentNumber => Int
 
-  The zero-based index number of the this segment. For example, if the
-total number of segments is 4, SegmentNumber values will range from
-zero through three.
+  The zero-based index number of the segment. For example, if the total
+number of segments is 4, C<SegmentNumber> values range from 0 through
+3.
 
 
 =head2 B<REQUIRED> TotalSegments => Int
 
-  The total numer of segments.
+  The total number of segments.
 
 
 
