@@ -36,8 +36,8 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Glue::Trigg
 =head1 DESCRIPTION
 
 A structure used to provide information used to update a trigger. This
-object will update the the previous trigger definition by overwriting
-it completely.
+object updates the previous trigger definition by overwriting it
+completely.
 
 =head1 ATTRIBUTES
 
@@ -66,7 +66,7 @@ it completely.
 
   A C<cron> expression used to specify the schedule (see Time-Based
 Schedules for Jobs and Crawlers
-(http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html).
+(https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html).
 For example, to run something every day at 12:15 UTC, you would
 specify: C<cron(15 12 * * ? *)>.
 
