@@ -34,6 +34,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         Actions => [
           {
             Arguments => { 'MyGenericString' => 'MyGenericString', }, # OPTIONAL
+            CrawlerName          => 'MyNameString',    # min: 1, max: 255
             JobName              => 'MyNameString',    # min: 1, max: 255
             NotificationProperty => {
               NotifyDelayAfter => 1,                   # min: 1; OPTIONAL
@@ -48,6 +49,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         Predicate   => {
           Conditions => [
             {
+              CrawlState => 'RUNNING'
+              ,    # values: RUNNING, SUCCEEDED, CANCELLED, FAILED; OPTIONAL
+              CrawlerName     => 'MyNameString',    # min: 1, max: 255
               JobName         => 'MyNameString',    # min: 1, max: 255
               LogicalOperator => 'EQUALS',          # values: EQUALS; OPTIONAL
               State           => 'STARTING'
