@@ -57,10 +57,20 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               },    # OPTIONAL
               S3MachineLearningModelResourceData => {
                 DestinationPath => 'My__string',
-                S3Uri           => 'My__string',
+                OwnerSetting    => {
+                  GroupOwner      => 'My__string',
+                  GroupPermission => 'ro',           # values: ro, rw
+
+                },    # OPTIONAL
+                S3Uri => 'My__string',
               },    # OPTIONAL
               SageMakerMachineLearningModelResourceData => {
                 DestinationPath => 'My__string',
+                OwnerSetting    => {
+                  GroupOwner      => 'My__string',
+                  GroupPermission => 'ro',           # values: ro, rw
+
+                },    # OPTIONAL
                 SageMakerJobArn => 'My__string',
               },    # OPTIONAL
               SecretsManagerSecretResourceData => {
@@ -68,10 +78,11 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                 AdditionalStagingLabelsToDownload => [ 'My__string', ... ]
                 ,    # OPTIONAL
               },    # OPTIONAL
-            },    # OPTIONAL
+            },
+
           },
           ...
-        ],        # OPTIONAL
+        ],          # OPTIONAL
       },    # OPTIONAL
       Name => 'My__string',                         # OPTIONAL
       Tags => { 'My__string' => 'My__string', },    # OPTIONAL
@@ -116,7 +127,7 @@ The name of the resource definition.
 
 =head2 Tags => L<Paws::Greengrass::Tags>
 
-Tag(s) to add to the new resource
+Tag(s) to add to the new resource.
 
 
 
