@@ -1,6 +1,7 @@
 package Paws::Greengrass::S3MachineLearningModelResourceData;
   use Moose;
   has DestinationPath => (is => 'ro', isa => 'Str');
+  has OwnerSetting => (is => 'ro', isa => 'Paws::Greengrass::ResourceDownloadOwnerSetting');
   has S3Uri => (is => 'ro', isa => 'Str');
 1;
 
@@ -42,6 +43,11 @@ Attributes that define an Amazon S3 machine learning resource.
   The absolute local path of the resource inside the Lambda environment.
 
 
+=head2 OwnerSetting => L<Paws::Greengrass::ResourceDownloadOwnerSetting>
+
+  
+
+
 =head2 S3Uri => Str
 
   The URI of the source model in an S3 bucket. The model package must be
