@@ -1,6 +1,7 @@
 package Paws::Greengrass::SageMakerMachineLearningModelResourceData;
   use Moose;
   has DestinationPath => (is => 'ro', isa => 'Str');
+  has OwnerSetting => (is => 'ro', isa => 'Paws::Greengrass::ResourceDownloadOwnerSetting');
   has SageMakerJobArn => (is => 'ro', isa => 'Str');
 1;
 
@@ -42,6 +43,11 @@ Attributes that define an Amazon SageMaker machine learning resource.
   The absolute local path of the resource inside the Lambda environment.
 
 
+=head2 OwnerSetting => L<Paws::Greengrass::ResourceDownloadOwnerSetting>
+
+  
+
+
 =head2 SageMakerJobArn => Str
 
   The ARN of the Amazon SageMaker training job that represents the source
