@@ -32,29 +32,31 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     my $health = Paws->service('Health');
     my $DescribeEventsResponse = $health->DescribeEvents(
       Filter => {
-        AvailabilityZones => [ 'MyavailabilityZone', ... ],    # OPTIONAL
-        EndTimes          => [
+        AvailabilityZones => [
+          'MyavailabilityZone', ...    # min: 6, max: 18
+        ],                             # OPTIONAL
+        EndTimes => [
           {
-            From => '1970-01-01T01:00:00',                     # OPTIONAL
-            To   => '1970-01-01T01:00:00',                     # OPTIONAL
+            From => '1970-01-01T01:00:00',    # OPTIONAL
+            To   => '1970-01-01T01:00:00',    # OPTIONAL
           },
           ...
-        ],    # min: 1, max: 10; OPTIONAL
+        ],                                    # min: 1, max: 10; OPTIONAL
         EntityArns => [
-          'MyentityArn', ...    # max: 1600
-        ],                      # min: 1, max: 100; OPTIONAL
+          'MyentityArn', ...                  # max: 1600
+        ],                                    # min: 1, max: 100; OPTIONAL
         EntityValues => [
-          'MyentityValue', ...    # max: 256
-        ],                        # min: 1, max: 100; OPTIONAL
+          'MyentityValue', ...                # max: 256
+        ],                                    # min: 1, max: 100; OPTIONAL
         EventArns => [
-          'MyeventArn', ...       # max: 1600
-        ],                        # min: 1, max: 10; OPTIONAL
+          'MyeventArn', ...                   # max: 1600
+        ],                                    # min: 1, max: 10; OPTIONAL
         EventStatusCodes => [
-          'open', ...             # values: open, closed, upcoming
-        ],                        # min: 1, max: 6; OPTIONAL
+          'open', ...                         # values: open, closed, upcoming
+        ],                                    # min: 1, max: 6; OPTIONAL
         EventTypeCategories => [
           'issue',
-          ... # values: issue, accountNotification, scheduledChangemin: 3, max: 255
+          ... # values: issue, accountNotification, scheduledChange, investigationmin: 3, max: 255
         ],    # min: 1, max: 10; OPTIONAL
         EventTypeCodes => [
           'MyeventType', ...    # min: 3, max: 100
@@ -66,7 +68,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           },
           ...
         ],                                    # min: 1, max: 10; OPTIONAL
-        Regions  => [ 'Myregion', ... ],      # min: 1, max: 10; OPTIONAL
+        Regions => [
+          'Myregion', ...                     # min: 2, max: 25
+        ],                                    # min: 1, max: 10; OPTIONAL
         Services => [
           'Myservice', ...                    # min: 2, max: 30
         ],                                    # min: 1, max: 10; OPTIONAL
