@@ -5,6 +5,7 @@ package Paws::IAM::ResourceSpecificResult;
   has EvalResourceName => (is => 'ro', isa => 'Str', required => 1);
   has MatchedStatements => (is => 'ro', isa => 'ArrayRef[Paws::IAM::Statement]');
   has MissingContextValues => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
+  has PermissionsBoundaryDecisionDetail => (is => 'ro', isa => 'Paws::IAM::PermissionsBoundaryDecisionDetail');
 1;
 
 ### main pod documentation begin ###
@@ -24,7 +25,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::IAM::ResourceSpecificResult object:
 
-  $service_obj->Method(Att1 => { EvalDecisionDetails => $value, ..., MissingContextValues => $value  });
+  $service_obj->Method(Att1 => { EvalDecisionDetails => $value, ..., PermissionsBoundaryDecisionDetail => $value  });
 
 =head3 Results returned from an API call
 
@@ -45,11 +46,10 @@ This data type is used by a member of the EvaluationResult data type.
 
 =head2 EvalDecisionDetails => L<Paws::IAM::EvalDecisionDetailsType>
 
-  Additional details about the results of the evaluation decision. When
-there are both IAM policies and resource policies, this parameter
-explains how each set of policies contributes to the final evaluation
-decision. When simulating cross-account access to a resource, both the
-resource-based policy and the caller's IAM policy must grant access.
+  Additional details about the results of the evaluation decision on a
+single resource. This parameter is returned only for cross-account
+simulations. This parameter explains how each policy type contributes
+to the resource-specific evaluation decision.
 
 
 =head2 B<REQUIRED> EvalResourceDecision => Str
@@ -86,6 +86,12 @@ a set of policies, you can call GetContextKeysForCustomPolicy or
 GetContextKeysForPrincipalPolicy.
 
 
+=head2 PermissionsBoundaryDecisionDetail => L<Paws::IAM::PermissionsBoundaryDecisionDetail>
+
+  Contains information about the effect that a permissions boundary has
+on a policy simulation when that boundary is applied to an IAM entity.
+
+
 
 =head1 SEE ALSO
 
