@@ -8,6 +8,7 @@ package Paws::IAM::Role;
   has Path => (is => 'ro', isa => 'Str', required => 1);
   has PermissionsBoundary => (is => 'ro', isa => 'Paws::IAM::AttachedPermissionsBoundary');
   has RoleId => (is => 'ro', isa => 'Str', required => 1);
+  has RoleLastUsed => (is => 'ro', isa => 'Paws::IAM::RoleLastUsed');
   has RoleName => (is => 'ro', isa => 'Str', required => 1);
   has Tags => (is => 'ro', isa => 'ArrayRef[Paws::IAM::Tag]');
 1;
@@ -84,7 +85,7 @@ C<duration-seconds> CLI parameter.
   The path to the role. For more information about paths, see IAM
 Identifiers
 (https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html)
-in the I<Using IAM> guide.
+in the I<IAM User Guide>.
 
 
 =head2 PermissionsBoundary => L<Paws::IAM::AttachedPermissionsBoundary>
@@ -103,7 +104,19 @@ in the I<IAM User Guide>.
   The stable and unique string identifying the role. For more information
 about IDs, see IAM Identifiers
 (https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html)
-in the I<Using IAM> guide.
+in the I<IAM User Guide>.
+
+
+=head2 RoleLastUsed => L<Paws::IAM::RoleLastUsed>
+
+  Contains information about the last time that an IAM role was used.
+This includes the date and time and the Region in which the role was
+last used. Activity is only reported for the trailing 400 days. This
+period can be shorter if your Region began supporting these features
+within the last year. The role might have been used more than 400 days
+ago. For more information, see Regions Where Data Is Tracked
+(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html#access-advisor_tracking-period)
+in the I<IAM User Guide>.
 
 
 =head2 B<REQUIRED> RoleName => Str
