@@ -69,7 +69,7 @@ ListUsers
 information about ARNs and how to use ARNs in policies, see IAM
 Identifiers
 (https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html)
-in the I<Using IAM> guide.
+in the I<IAM User Guide>.
 
 
 =head2 B<REQUIRED> CreateDate => Str
@@ -85,8 +85,8 @@ in the I<Using IAM> guide.
 used to sign in to an AWS website. For a list of AWS websites that
 capture a user's last sign-in time, see the Credential Reports
 (https://docs.aws.amazon.com/IAM/latest/UserGuide/credential-reports.html)
-topic in the I<Using IAM> guide. If a password is used more than once
-in a five-minute span, only the first use is returned in this field. If
+topic in the I<IAM User Guide>. If a password is used more than once in
+a five-minute span, only the first use is returned in this field. If
 the field is null (no value), then it indicates that they never signed
 in with a password. This can be because:
 
@@ -104,9 +104,9 @@ information on October 20, 2014.
 =back
 
 A null value does not mean that the user I<never> had a password. Also,
-if the user does not currently have a password, but had one in the
-past, then this field contains the date and time the most recent
-password was used.
+if the user does not currently have a password but had one in the past,
+then this field contains the date and time the most recent password was
+used.
 
 This value is returned only in the GetUser and ListUsers operations.
 
@@ -116,7 +116,7 @@ This value is returned only in the GetUser and ListUsers operations.
   The path to the user. For more information about paths, see IAM
 Identifiers
 (https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html)
-in the I<Using IAM> guide.
+in the I<IAM User Guide>.
 
 
 =head2 PermissionsBoundary => L<Paws::IAM::AttachedPermissionsBoundary>
@@ -143,7 +143,7 @@ I<IAM User Guide>.
   The stable and unique string identifying the user. For more information
 about IDs, see IAM Identifiers
 (https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html)
-in the I<Using IAM> guide.
+in the I<IAM User Guide>.
 
 
 =head2 B<REQUIRED> UserName => Str
