@@ -4,6 +4,7 @@ package Paws::ImportExport::GetShippingLabelOutput;
   has ShippingLabelURL => (is => 'ro', isa => 'Str');
   has Warning => (is => 'ro', isa => 'Str');
 
+  has _request_id => (is => 'ro', isa => 'Str');
 1;
 
 ### main pod documentation begin ###
@@ -20,12 +21,12 @@ Paws::ImportExport::GetShippingLabelOutput
 
 
 
-
 =head2 Warning => Str
 
 
 
 
+=head2 _request_id => Str
 
 
 =cut
