@@ -1,15 +1,17 @@
 
 package Paws::IoT::CreateJob;
   use Moose;
+  has AbortConfig => (is => 'ro', isa => 'Paws::IoT::AbortConfig', traits => ['NameInRequest'], request_name => 'abortConfig');
   has Description => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'description');
   has Document => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'document');
-  has DocumentParameters => (is => 'ro', isa => 'Paws::IoT::JobDocumentParameters', traits => ['NameInRequest'], request_name => 'documentParameters');
   has DocumentSource => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'documentSource');
   has JobExecutionsRolloutConfig => (is => 'ro', isa => 'Paws::IoT::JobExecutionsRolloutConfig', traits => ['NameInRequest'], request_name => 'jobExecutionsRolloutConfig');
   has JobId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'jobId', required => 1);
   has PresignedUrlConfig => (is => 'ro', isa => 'Paws::IoT::PresignedUrlConfig', traits => ['NameInRequest'], request_name => 'presignedUrlConfig');
+  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::IoT::Tag]', traits => ['NameInRequest'], request_name => 'tags');
   has Targets => (is => 'ro', isa => 'ArrayRef[Str|Undef]', traits => ['NameInRequest'], request_name => 'targets', required => 1);
   has TargetSelection => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'targetSelection');
+  has TimeoutConfig => (is => 'ro', isa => 'Paws::IoT::TimeoutConfig', traits => ['NameInRequest'], request_name => 'timeoutConfig');
 
   use MooseX::ClassAttribute;
 
@@ -37,23 +39,51 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $iot = Paws->service('IoT');
     my $CreateJobResponse = $iot->CreateJob(
-      JobId              => 'MyJobId',
-      Targets            => [ 'MyTargetArn', ... ],
-      Description        => 'MyJobDescription',       # OPTIONAL
-      Document           => 'MyJobDocument',          # OPTIONAL
-      DocumentParameters => {
-        'MyParameterKey' =>
-          'MyParameterValue',  # key: min: 1, max: 128, value: min: 1, max: 1024
+      JobId       => 'MyJobId',
+      Targets     => [ 'MyTargetArn', ... ],
+      AbortConfig => {
+        CriteriaList => [
+          {
+            Action      => 'CANCEL',  # values: CANCEL
+            FailureType => 'FAILED',  # values: FAILED, REJECTED, TIMED_OUT, ALL
+            MinNumberOfExecutedThings => 1,    # min: 1
+            ThresholdPercentage       => 1,    # max: 100
+
+          },
+          ...
+        ],                                     # min: 1
+
       },    # OPTIONAL
+      Description                => 'MyJobDescription',       # OPTIONAL
+      Document                   => 'MyJobDocument',          # OPTIONAL
       DocumentSource             => 'MyJobDocumentSource',    # OPTIONAL
       JobExecutionsRolloutConfig => {
-        maximumPerMinute => 1,    # min: 1, max: 1000; OPTIONAL
+        ExponentialRate => {
+          BaseRatePerMinute    => 1,    # min: 1, max: 1000
+          IncrementFactor      => 1,    # min: 1, max: 5
+          RateIncreaseCriteria => {
+            NumberOfNotifiedThings  => 1,    # min: 1; OPTIONAL
+            NumberOfSucceededThings => 1,    # min: 1; OPTIONAL
+          },
+
+        },    # OPTIONAL
+        MaximumPerMinute => 1,    # min: 1; OPTIONAL
       },    # OPTIONAL
       PresignedUrlConfig => {
-        expiresInSec => 1,              # min: 60, max: 3600; OPTIONAL
-        roleArn      => 'MyRoleArn',    # min: 20, max: 2048; OPTIONAL
+        ExpiresInSec => 1,              # min: 60, max: 3600; OPTIONAL
+        RoleArn      => 'MyRoleArn',    # min: 20, max: 2048; OPTIONAL
       },    # OPTIONAL
+      Tags => [
+        {
+          Key   => 'MyTagKey',      # OPTIONAL
+          Value => 'MyTagValue',    # OPTIONAL
+        },
+        ...
+      ],                            # OPTIONAL
       TargetSelection => 'CONTINUOUS',    # OPTIONAL
+      TimeoutConfig   => {
+        InProgressTimeoutInMinutes => 1,    # OPTIONAL
+      },    # OPTIONAL
     );
 
     # Results:
@@ -69,6 +99,12 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iot
 =head1 ATTRIBUTES
 
 
+=head2 AbortConfig => L<Paws::IoT::AbortConfig>
+
+Allows you to create criteria to abort a job.
+
+
+
 =head2 Description => Str
 
 A short text description of the job.
@@ -79,11 +115,15 @@ A short text description of the job.
 
 The job document.
 
+If the job document resides in an S3 bucket, you must use a placeholder
+link when specifying the document.
 
+The placeholder link is of the following form:
 
-=head2 DocumentParameters => L<Paws::IoT::JobDocumentParameters>
+C<${aws:iot:s3-presigned-url:https://s3.amazonaws.com/I<bucket>/I<key>}>
 
-Parameters for the job document.
+where I<bucket> is your bucket name and I<key> is the object in the
+bucket to which you are linking.
 
 
 
@@ -113,6 +153,12 @@ Configuration information for pre-signed S3 URLs.
 
 
 
+=head2 Tags => ArrayRef[L<Paws::IoT::Tag>]
+
+Metadata which can be used to manage the job.
+
+
+
 =head2 B<REQUIRED> Targets => ArrayRef[Str|Undef]
 
 A list of things and thing groups to which the job should be sent.
@@ -130,6 +176,16 @@ completed by all things originally in the group.
 
 Valid values are: C<"CONTINUOUS">, C<"SNAPSHOT">
 
+=head2 TimeoutConfig => L<Paws::IoT::TimeoutConfig>
+
+Specifies the amount of time each device has to finish its execution of
+the job. The timer is started when the job execution status is set to
+C<IN_PROGRESS>. If the job execution status is not set to another
+terminal state before the time expires, it will be automatically set to
+C<TIMED_OUT>.
+
+
+
 
 =head1 SEE ALSO
 
