@@ -82,6 +82,26 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               RoleArn            => 'MyAwsArn',
               Separator          => 'MyFirehoseSeparator',    # OPTIONAL
             },    # OPTIONAL
+            Http => {
+              Url  => 'MyUrl',    # max: 2000
+              Auth => {
+                Sigv4 => {
+                  RoleArn       => 'MyAwsArn',
+                  ServiceName   => 'MyServiceName',
+                  SigningRegion => 'MySigningRegion',
+
+                },                # OPTIONAL
+              },    # OPTIONAL
+              ConfirmationUrl => 'MyUrl',    # max: 2000
+              Headers         => [
+                {
+                  Key   => 'MyHeaderKey',     # min: 1, max: 256
+                  Value => 'MyHeaderValue',
+
+                },
+                ...
+              ],                              # max: 100; OPTIONAL
+            },    # OPTIONAL
             IotAnalytics => {
               ChannelArn  => 'MyAwsArn',
               ChannelName => 'MyChannelName',    # OPTIONAL
@@ -92,6 +112,40 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               RoleArn   => 'MyAwsArn',
               MessageId => 'MyMessageId',    # max: 128; OPTIONAL
             },    # OPTIONAL
+            IotSiteWise => {
+              PutAssetPropertyValueEntries => [
+                {
+                  PropertyValues => [
+                    {
+                      Timestamp => {
+                        TimeInSeconds => 'MyAssetPropertyTimeInSeconds',
+                        OffsetInNanos =>
+                          'MyAssetPropertyOffsetInNanos',    # OPTIONAL
+                      },
+                      Value => {
+                        BooleanValue =>
+                          'MyAssetPropertyBooleanValue',     # OPTIONAL
+                        DoubleValue => 'MyAssetPropertyDoubleValue',  # OPTIONAL
+                        IntegerValue =>
+                          'MyAssetPropertyIntegerValue',              # OPTIONAL
+                        StringValue => 'MyAssetPropertyStringValue'
+                        ,    # min: 1, max: 1024; OPTIONAL
+                      },
+                      Quality => 'MyAssetPropertyQuality',    # OPTIONAL
+                    },
+                    ...
+                  ],                                          # min: 1
+                  AssetId => 'MyAssetId',                     # OPTIONAL
+                  EntryId => 'MyAssetPropertyEntryId',        # OPTIONAL
+                  PropertyAlias =>
+                    'MyAssetPropertyAlias',    # min: 1, max: 2048; OPTIONAL
+                  PropertyId => 'MyAssetPropertyId',    # OPTIONAL
+                },
+                ...
+              ],                                        # min: 1
+              RoleArn => 'MyAwsArn',
+
+            },    # OPTIONAL
             Kinesis => {
               RoleArn      => 'MyAwsArn',
               StreamName   => 'MyStreamName',
@@ -104,7 +158,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
             Republish => {
               RoleArn => 'MyAwsArn',
               Topic   => 'MyTopicPattern',
-
+              Qos     => 1,                  # max: 1; OPTIONAL
             },    # OPTIONAL
             S3 => {
               BucketName => 'MyBucketName',
@@ -188,6 +242,26 @@ You shouldn't make instances of this class. Each attribute should be used as a n
             RoleArn            => 'MyAwsArn',
             Separator          => 'MyFirehoseSeparator',    # OPTIONAL
           },    # OPTIONAL
+          Http => {
+            Url  => 'MyUrl',    # max: 2000
+            Auth => {
+              Sigv4 => {
+                RoleArn       => 'MyAwsArn',
+                ServiceName   => 'MyServiceName',
+                SigningRegion => 'MySigningRegion',
+
+              },                # OPTIONAL
+            },    # OPTIONAL
+            ConfirmationUrl => 'MyUrl',    # max: 2000
+            Headers         => [
+              {
+                Key   => 'MyHeaderKey',     # min: 1, max: 256
+                Value => 'MyHeaderValue',
+
+              },
+              ...
+            ],                              # max: 100; OPTIONAL
+          },    # OPTIONAL
           IotAnalytics => {
             ChannelArn  => 'MyAwsArn',
             ChannelName => 'MyChannelName',    # OPTIONAL
@@ -198,6 +272,38 @@ You shouldn't make instances of this class. Each attribute should be used as a n
             RoleArn   => 'MyAwsArn',
             MessageId => 'MyMessageId',    # max: 128; OPTIONAL
           },    # OPTIONAL
+          IotSiteWise => {
+            PutAssetPropertyValueEntries => [
+              {
+                PropertyValues => [
+                  {
+                    Timestamp => {
+                      TimeInSeconds => 'MyAssetPropertyTimeInSeconds',
+                      OffsetInNanos =>
+                        'MyAssetPropertyOffsetInNanos',    # OPTIONAL
+                    },
+                    Value => {
+                      BooleanValue => 'MyAssetPropertyBooleanValue',  # OPTIONAL
+                      DoubleValue  => 'MyAssetPropertyDoubleValue',   # OPTIONAL
+                      IntegerValue => 'MyAssetPropertyIntegerValue',  # OPTIONAL
+                      StringValue  => 'MyAssetPropertyStringValue'
+                      ,    # min: 1, max: 1024; OPTIONAL
+                    },
+                    Quality => 'MyAssetPropertyQuality',    # OPTIONAL
+                  },
+                  ...
+                ],                                          # min: 1
+                AssetId => 'MyAssetId',                     # OPTIONAL
+                EntryId => 'MyAssetPropertyEntryId',        # OPTIONAL
+                PropertyAlias =>
+                  'MyAssetPropertyAlias',    # min: 1, max: 2048; OPTIONAL
+                PropertyId => 'MyAssetPropertyId',    # OPTIONAL
+              },
+              ...
+            ],                                        # min: 1
+            RoleArn => 'MyAwsArn',
+
+          },    # OPTIONAL
           Kinesis => {
             RoleArn      => 'MyAwsArn',
             StreamName   => 'MyStreamName',
@@ -210,7 +316,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           Republish => {
             RoleArn => 'MyAwsArn',
             Topic   => 'MyTopicPattern',
-
+            Qos     => 1,                  # max: 1; OPTIONAL
           },    # OPTIONAL
           S3 => {
             BucketName => 'MyBucketName',
