@@ -75,7 +75,10 @@ unprocessed messages before publishing the data to a pipeline.
 
 =head2 Storage => L<Paws::IoTAnalytics::ChannelStorage>
 
-  Where channel data is stored.
+  Where channel data is stored. You may choose one of "serviceManagedS3"
+or "customerManagedS3" storage. If not specified, the default is
+"serviceManagedS3". This cannot be changed after creation of the
+channel.
 
 
 
