@@ -78,13 +78,17 @@ The name of the channel.
 
 =head2 ChannelStorage => L<Paws::IoTAnalytics::ChannelStorage>
 
-Where channel data is stored.
+Where channel data is stored. You may choose one of "serviceManagedS3"
+or "customerManagedS3" storage. If not specified, the default is
+"serviceManagedS3". This cannot be changed after creation of the
+channel.
 
 
 
 =head2 RetentionPeriod => L<Paws::IoTAnalytics::RetentionPeriod>
 
-How long, in days, message data is kept for the channel.
+How long, in days, message data is kept for the channel. When
+"customerManagedS3" storage is selected, this parameter is ignored.
 
 
 
