@@ -11,7 +11,9 @@ package Paws::Kafka::ClusterInfo;
   has EncryptionInfo => (is => 'ro', isa => 'Paws::Kafka::EncryptionInfo', request_name => 'encryptionInfo', traits => ['NameInRequest']);
   has EnhancedMonitoring => (is => 'ro', isa => 'Str', request_name => 'enhancedMonitoring', traits => ['NameInRequest']);
   has NumberOfBrokerNodes => (is => 'ro', isa => 'Int', request_name => 'numberOfBrokerNodes', traits => ['NameInRequest']);
+  has OpenMonitoring => (is => 'ro', isa => 'Paws::Kafka::OpenMonitoring', request_name => 'openMonitoring', traits => ['NameInRequest']);
   has State => (is => 'ro', isa => 'Str', request_name => 'state', traits => ['NameInRequest']);
+  has StateInfo => (is => 'ro', isa => 'Paws::Kafka::StateInfo', request_name => 'stateInfo', traits => ['NameInRequest']);
   has Tags => (is => 'ro', isa => 'Paws::Kafka::__mapOf__string', request_name => 'tags', traits => ['NameInRequest']);
   has ZookeeperConnectString => (is => 'ro', isa => 'Str', request_name => 'zookeeperConnectString', traits => ['NameInRequest']);
 1;
@@ -109,12 +111,22 @@ these three levels of monitoring, see Monitoring
   The number of broker nodes in the cluster.
 
 
+=head2 OpenMonitoring => L<Paws::Kafka::OpenMonitoring>
+
+  Settings for open monitoring using Prometheus.
+
+
 =head2 State => Str
 
   The state of the cluster. The possible states are CREATING, ACTIVE, and
 FAILED.
 
 
+=head2 StateInfo => L<Paws::Kafka::StateInfo>
+
+  
+
+
 =head2 Tags => L<Paws::Kafka::__mapOf__string>
 
   Tags attached to the cluster.
