@@ -9,6 +9,7 @@ package Paws::Kafka::CreateCluster;
   has EnhancedMonitoring => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'enhancedMonitoring');
   has KafkaVersion => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'kafkaVersion', required => 1);
   has NumberOfBrokerNodes => (is => 'ro', isa => 'Int', traits => ['NameInRequest'], request_name => 'numberOfBrokerNodes', required => 1);
+  has OpenMonitoring => (is => 'ro', isa => 'Paws::Kafka::OpenMonitoringInfo', traits => ['NameInRequest'], request_name => 'openMonitoring');
   has Tags => (is => 'ro', isa => 'Paws::Kafka::__mapOf__string', traits => ['NameInRequest'], request_name => 'tags');
 
   use MooseX::ClassAttribute;
@@ -71,7 +72,20 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           InCluster => 1,    # OPTIONAL
         },    # OPTIONAL
       },    # OPTIONAL
-      EnhancedMonitoring => 'DEFAULT',              # OPTIONAL
+      EnhancedMonitoring => 'DEFAULT',    # OPTIONAL
+      OpenMonitoring     => {
+        Prometheus => {
+          JmxExporter => {
+            EnabledInBroker => 1,         # OPTIONAL
+
+          },    # OPTIONAL
+          NodeExporter => {
+            EnabledInBroker => 1,    # OPTIONAL
+
+          },    # OPTIONAL
+        },
+
+      },    # OPTIONAL
       Tags => { 'My__string' => 'My__string', },    # OPTIONAL
     );
 
@@ -138,6 +152,12 @@ The number of broker nodes in the cluster.
 
 
 
+=head2 OpenMonitoring => L<Paws::Kafka::OpenMonitoringInfo>
+
+The settings for open monitoring.
+
+
+
 =head2 Tags => L<Paws::Kafka::__mapOf__string>
 
 Create tags when creating the cluster.
