@@ -237,9 +237,8 @@ A list of one or more tags to assign to the application. A tag is a
 key-value pair that identifies an application. Note that the maximum
 number of application tags includes system tags. The maximum number of
 user-defined application tags is 50. For more information, see Using
-Cost Allocation Tags
-(https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)
-in the I<AWS Billing and Cost Management Guide>.
+Tagging
+(https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-tagging.html).
 
 
 
