@@ -38,8 +38,9 @@ Also identifies the IAM role Amazon Kinesis Analytics can assume to
 read this object on your behalf.
 
 An Amazon Kinesis Analytics application loads reference data only once.
-If the data changes, you call the UpdateApplication operation to
-trigger reloading of data into your application.
+If the data changes, you call the UpdateApplication
+(https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_UpdateApplication.html)
+operation to trigger reloading of data into your application.
 
 =head1 ATTRIBUTES
 
