@@ -71,7 +71,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         FlinkApplicationConfiguration => {
           CheckpointConfiguration => {
             ConfigurationType          => 'DEFAULT',   # values: DEFAULT, CUSTOM
-            CheckpointInterval         => 1,           # OPTIONAL
+            CheckpointInterval         => 1,           # min: 1; OPTIONAL
             CheckpointingEnabled       => 1,
             MinPauseBetweenCheckpoints => 1,           # OPTIONAL
           },    # OPTIONAL
@@ -198,6 +198,14 @@ You shouldn't make instances of this class. Each attribute should be used as a n
             ...
           ],        # OPTIONAL
         },    # OPTIONAL
+        VpcConfigurations => [
+          {
+            SecurityGroupIds => [ 'MySecurityGroupId', ... ],  # min: 1, max: 5
+            SubnetIds        => [ 'MySubnetId',        ... ],  # min: 1, max: 16
+
+          },
+          ...
+        ],                                                     # OPTIONAL
       },    # OPTIONAL
       ApplicationDescription   => 'MyApplicationDescription',    # OPTIONAL
       CloudWatchLoggingOptions => [
@@ -273,9 +281,8 @@ A list of one or more tags to assign to the application. A tag is a
 key-value pair that identifies an application. Note that the maximum
 number of application tags includes system tags. The maximum number of
 user-defined application tags is 50. For more information, see Using
-Cost Allocation Tags
-(https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html)
-in the I<AWS Billing and Cost Management Guide>.
+Tagging
+(https://docs.aws.amazon.com/kinesisanalytics/latest/java/how-tagging.html).
 
 
 
