@@ -4,7 +4,9 @@ package Paws::MQ::UpdateBrokerOutput;
   has BrokerId => (is => 'ro', isa => 'Str', request_name => 'brokerId', traits => ['NameInRequest']);
   has Configuration => (is => 'ro', isa => 'Paws::MQ::ConfigurationId', request_name => 'configuration', traits => ['NameInRequest']);
   has EngineVersion => (is => 'ro', isa => 'Str', request_name => 'engineVersion', traits => ['NameInRequest']);
+  has HostInstanceType => (is => 'ro', isa => 'Str', request_name => 'hostInstanceType', traits => ['NameInRequest']);
   has Logs => (is => 'ro', isa => 'Paws::MQ::Logs', request_name => 'logs', traits => ['NameInRequest']);
+  has SecurityGroups => (is => 'ro', isa => 'ArrayRef[Str|Undef]', request_name => 'securityGroups', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -24,7 +26,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::MQ::UpdateBrokerOutput object:
 
-  $service_obj->Method(Att1 => { AutoMinorVersionUpgrade => $value, ..., Logs => $value  });
+  $service_obj->Method(Att1 => { AutoMinorVersionUpgrade => $value, ..., SecurityGroups => $value  });
 
 =head3 Results returned from an API call
 
@@ -62,12 +64,25 @@ engine versions, see
 https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/broker-engine.html
 
 
+=head2 HostInstanceType => Str
+
+  The host instance type of the broker to upgrade to. For a list of
+supported instance types, see
+https://docs.aws.amazon.com/amazon-mq/latest/developer-guide//broker.html#broker-instance-types
+
+
 =head2 Logs => L<Paws::MQ::Logs>
 
   The list of information about logs to be enabled for the specified
 broker.
 
 
+=head2 SecurityGroups => ArrayRef[Str|Undef]
+
+  The list of security groups (1 minimum, 5 maximum) that authorizes
+connections to brokers.
+
+
 
 =head1 SEE ALSO
 
