@@ -47,7 +47,8 @@ Description of audio output
 
 =head2 AudioNormalizationSettings => L<Paws::MediaConvert::AudioNormalizationSettings>
 
-  Advanced audio normalization settings.
+  Advanced audio normalization settings. Ignore these settings unless you
+need to comply with a loudness standard.
 
 
 =head2 AudioSourceName => Str
@@ -87,20 +88,27 @@ audioDescriptionBroadcasterMix is set to BROADCASTER_MIXED_AD.
 
   Audio codec settings (CodecSettings) under (AudioDescriptions) contains
 the group of settings related to audio encoding. The settings in this
-group vary depending on the value you choose for Audio codec (Codec).
-For each codec enum you choose, define the corresponding settings
-object. The following lists the codec enum, settings object pairs. *
-AAC, AacSettings * MP2, Mp2Settings * WAV, WavSettings * AIFF,
-AiffSettings * AC3, Ac3Settings * EAC3, Eac3Settings
+group vary depending on the value that you choose for Audio codec
+(Codec). For each codec enum that you choose, define the corresponding
+settings object. The following lists the codec enum, settings object
+pairs. * AAC, AacSettings * MP2, Mp2Settings * MP3, Mp3Settings * WAV,
+WavSettings * AIFF, AiffSettings * AC3, Ac3Settings * EAC3,
+Eac3Settings * EAC3_ATMOS, Eac3AtmosSettings
 
 
 =head2 CustomLanguageCode => Str
 
-  Specify the language for this audio output track, using the ISO 639-2
-or ISO 639-3 three-letter language code. The language specified will be
-used when 'Follow Input Language Code' is not selected or when 'Follow
-Input Language Code' is selected but there is no ISO 639 language code
-specified by the input.
+  Specify the language for this audio output track. The service puts this
+language code into your output audio track when you set Language code
+control (AudioLanguageCodeControl) to Use configured (USE_CONFIGURED).
+The service also uses your specified custom language code when you set
+Language code control (AudioLanguageCodeControl) to Follow input
+(FOLLOW_INPUT), but your input file doesn't specify a language code.
+For all outputs, you can use an ISO 639-2 or ISO 639-3 code. For
+streaming outputs, you can also use any other code in the full RFC-5646
+specification. Streaming outputs are those that are in one of the
+following output groups: CMAF, DASH ISO, Apple HLS, or Microsoft Smooth
+Streaming.
 
 
 =head2 LanguageCode => Str
@@ -114,11 +122,13 @@ the input.
 
 =head2 LanguageCodeControl => Str
 
-  Choosing FOLLOW_INPUT will cause the ISO 639 language code of the
-output to follow the ISO 639 language code of the input. The language
-specified for languageCode' will be used when USE_CONFIGURED is
-selected or when FOLLOW_INPUT is selected but there is no ISO 639
-language code specified by the input.
+  Specify which source for language code takes precedence for this audio
+track. When you choose Follow input (FOLLOW_INPUT), the service uses
+the language code from the input track if it's present. If there's no
+languge code on the input track, the service uses the code that you
+specify in the setting Language code (languageCode or
+customLanguageCode). When you choose Use configured (USE_CONFIGURED),
+the service uses the language code that you specify.
 
 
 =head2 RemixSettings => L<Paws::MediaConvert::RemixSettings>
@@ -128,9 +138,11 @@ language code specified by the input.
 
 =head2 StreamName => Str
 
-  Used for MS Smooth and Apple HLS outputs. Indicates the name displayed
-by the player (eg. English, or Director Commentary). Alphanumeric
-characters, spaces, and underscore are legal.
+  Specify a label for this output audio stream. For example, "English",
+"Director commentary", or "track_2". For streaming outputs,
+MediaConvert passes this information into destination manifests for
+display on the end-viewer's player device. For outputs in other output
+groups, the service ignores this setting.
 
 
 
