@@ -36,15 +36,25 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::MediaConver
 
 =head1 DESCRIPTION
 
-Advanced audio normalization settings.
+Advanced audio normalization settings. Ignore these settings unless you
+need to comply with a loudness standard.
 
 =head1 ATTRIBUTES
 
 
 =head2 Algorithm => Str
 
-  Audio normalization algorithm to use. 1770-1 conforms to the CALM Act
-specification, 1770-2 conforms to the EBU R-128 specification.
+  Choose one of the following audio normalization algorithms: ITU-R
+BS.1770-1: Ungated loudness. A measurement of ungated average loudness
+for an entire piece of content, suitable for measurement of short-form
+content under ATSC recommendation A/85. Supports up to 5.1 audio
+channels. ITU-R BS.1770-2: Gated loudness. A measurement of gated
+average loudness compliant with the requirements of EBU-R128. Supports
+up to 5.1 audio channels. ITU-R BS.1770-3: Modified peak. The same
+loudness measurement algorithm as 1770-2, with an updated true peak
+measurement. ITU-R BS.1770-4: Higher channel count. Allows for more
+audio channels than the other algorithms, including configurations such
+as 7.1.
 
 
 =head2 AlgorithmControl => Str
@@ -56,8 +66,7 @@ If disabled, the audio will be measured but not adjusted.
 =head2 CorrectionGateLevel => Int
 
   Content measuring above this level will be corrected to the target
-level. Content measuring below this level will not be corrected. Gating
-only applies when not using real_time_correction.
+level. Content measuring below this level will not be corrected.
 
 
 =head2 LoudnessLogging => Str
@@ -73,10 +82,12 @@ audio track loudness.
 
 =head2 TargetLkfs => Num
 
-  Target LKFS(loudness) to adjust volume to. If no value is entered, a
-default value will be used according to the chosen algorithm. The CALM
-Act (1770-1) recommends a target of -24 LKFS. The EBU R-128
-specification (1770-2) recommends a target of -23 LKFS.
+  When you use Audio normalization (AudioNormalizationSettings),
+optionally use this setting to specify a target loudness. If you don't
+specify a value here, the encoder chooses a value for you, based on the
+algorithm that you choose for Algorithm (algorithm). If you choose
+algorithm 1770-1, the encoder will choose -24 LKFS; otherwise, the
+encoder will choose -23 LKFS.
 
 
 
