@@ -50,12 +50,16 @@ be used from each input.
 
 =head2 CustomLanguageCode => Str
 
-  Indicates the language of the caption output track, using the ISO 639-2
-or ISO 639-3 three-letter language code. For most captions output
-formats, the encoder puts this language information in the output
-captions metadata. If your output captions format is DVB-Sub or Burn
-in, the encoder uses this language information to choose the font
-language for rendering the captions text.
+  Specify the language for this captions output track. For most captions
+output formats, the encoder puts this language information in the
+output captions metadata. If your output captions format is DVB-Sub or
+Burn in, the encoder uses this language information when automatically
+selecting the font script for rendering the captions text. For all
+outputs, you can use an ISO 639-2 or ISO 639-3 code. For streaming
+outputs, you can also use any other code in the full RFC-5646
+specification. Streaming outputs are those that are in one of the
+following output groups: CMAF, DASH ISO, Apple HLS, or Microsoft Smooth
+Streaming.
 
 
 =head2 DestinationSettings => L<Paws::MediaConvert::CaptionDestinationSettings>
@@ -76,9 +80,11 @@ language for rendering the captions text.
 
 =head2 LanguageDescription => Str
 
-  Human readable information to indicate captions available for players
-(eg. English, or Spanish). Alphanumeric characters, spaces, and
-underscore are legal.
+  Specify a label for this set of output captions. For example,
+"English", "Director commentary", or "track_2". For streaming outputs,
+MediaConvert passes this information into destination manifests for
+display on the end-viewer's player device. For outputs in other output
+groups, the service ignores this setting.
 
 
 
