@@ -1,5 +1,6 @@
 package Paws::MediaConvert::CmafGroupSettings;
   use Moose;
+  has AdditionalManifests => (is => 'ro', isa => 'ArrayRef[Paws::MediaConvert::CmafAdditionalManifest]', request_name => 'additionalManifests', traits => ['NameInRequest']);
   has BaseUrl => (is => 'ro', isa => 'Str', request_name => 'baseUrl', traits => ['NameInRequest']);
   has ClientCache => (is => 'ro', isa => 'Str', request_name => 'clientCache', traits => ['NameInRequest']);
   has CodecSpecification => (is => 'ro', isa => 'Str', request_name => 'codecSpecification', traits => ['NameInRequest']);
@@ -11,11 +12,13 @@ package Paws::MediaConvert::CmafGroupSettings;
   has ManifestDurationFormat => (is => 'ro', isa => 'Str', request_name => 'manifestDurationFormat', traits => ['NameInRequest']);
   has MinBufferTime => (is => 'ro', isa => 'Int', request_name => 'minBufferTime', traits => ['NameInRequest']);
   has MinFinalSegmentLength => (is => 'ro', isa => 'Num', request_name => 'minFinalSegmentLength', traits => ['NameInRequest']);
+  has MpdProfile => (is => 'ro', isa => 'Str', request_name => 'mpdProfile', traits => ['NameInRequest']);
   has SegmentControl => (is => 'ro', isa => 'Str', request_name => 'segmentControl', traits => ['NameInRequest']);
   has SegmentLength => (is => 'ro', isa => 'Int', request_name => 'segmentLength', traits => ['NameInRequest']);
   has StreamInfResolution => (is => 'ro', isa => 'Str', request_name => 'streamInfResolution', traits => ['NameInRequest']);
   has WriteDashManifest => (is => 'ro', isa => 'Str', request_name => 'writeDashManifest', traits => ['NameInRequest']);
   has WriteHlsManifest => (is => 'ro', isa => 'Str', request_name => 'writeHlsManifest', traits => ['NameInRequest']);
+  has WriteSegmentTimelineInRepresentation => (is => 'ro', isa => 'Str', request_name => 'writeSegmentTimelineInRepresentation', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -35,14 +38,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::MediaConvert::CmafGroupSettings object:
 
-  $service_obj->Method(Att1 => { BaseUrl => $value, ..., WriteHlsManifest => $value  });
+  $service_obj->Method(Att1 => { AdditionalManifests => $value, ..., WriteSegmentTimelineInRepresentation => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::MediaConvert::CmafGroupSettings object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->BaseUrl
+  $result->Att1->AdditionalManifests
 
 =head1 DESCRIPTION
 
@@ -54,6 +57,17 @@ or caption output.
 =head1 ATTRIBUTES
 
 
+=head2 AdditionalManifests => ArrayRef[L<Paws::MediaConvert::CmafAdditionalManifest>]
+
+  By default, the service creates one top-level .m3u8 HLS manifest and
+one top -level .mpd DASH manifest for each CMAF output group in your
+job. These default manifests reference every output in the output
+group. To create additional top-level manifests that reference a subset
+of the outputs in the output group, specify a list of them here. For
+each additional manifest that you specify, the service creates one HLS
+manifest and one DASH manifest.
+
+
 =head2 BaseUrl => Str
 
   A partial URI prefix that will be put in the manifest file at the top
@@ -136,6 +150,17 @@ without a minimum final segment length; when you set the minimum final
 segment length to 1, your final segment is 3.5 seconds.
 
 
+=head2 MpdProfile => Str
+
+  Specify whether your DASH profile is on-demand or main. When you choose
+Main profile (MAIN_PROFILE), the service signals
+urn:mpeg:dash:profile:isoff-main:2011 in your .mpd DASH manifest. When
+you choose On-demand (ON_DEMAND_PROFILE), the service signals
+urn:mpeg:dash:profile:isoff-on-demand:2011 in your .mpd. When you
+choose On-demand, you must also set the output group setting Segment
+control (SegmentControl) to Single file (SINGLE_FILE).
+
+
 =head2 SegmentControl => Str
 
   When set to SINGLE_FILE, a single output file is generated, which is
@@ -174,6 +199,18 @@ output.
 output.
 
 
+=head2 WriteSegmentTimelineInRepresentation => Str
+
+  When you enable Precise segment duration in DASH manifests
+(writeSegmentTimelineInRepresentation), your DASH manifest shows
+precise segment durations. The segment duration information appears
+inside the SegmentTimeline element, inside SegmentTemplate at the
+Representation level. When this feature isn't enabled, the segment
+durations in your DASH manifest are approximate. The segment duration
+information appears in the duration attribute of the SegmentTemplate
+element.
+
+
 
 =head1 SEE ALSO
 
