@@ -48,11 +48,11 @@ Settings for color correction.
 
 =head2 ColorSpaceConversion => Str
 
-  Determines if colorspace conversion will be performed. If set to
-_None_, no conversion will be performed. If _Force 601_ or _Force 709_
-are selected, conversion will be performed for inputs with differing
-colorspaces. An input's colorspace can be specified explicitly in the
-"Video Selector":#inputs-video_selector if necessary.
+  Specify the color space you want for this output. The service supports
+conversion between HDR formats, between SDR formats, and from SDR to
+HDR. The service doesn't support conversion from HDR to SDR. SDR to HDR
+conversion doesn't upgrade the dynamic range. The converted video has
+an HDR format, but visually appears the same as an unconverted output.
 
 
 =head2 Contrast => Int
@@ -62,9 +62,19 @@ colorspaces. An input's colorspace can be specified explicitly in the
 
 =head2 Hdr10Metadata => L<Paws::MediaConvert::Hdr10Metadata>
 
-  Use the HDR master display (Hdr10Metadata) settings to correct HDR
-metadata or to provide missing metadata. Note that these settings are
-not color correction.
+  Use these settings when you convert to the HDR 10 color space. Specify
+the SMPTE ST 2086 Mastering Display Color Volume static metadata that
+you want signaled in the output. These values don't affect the pixel
+values that are encoded in the video stream. They are intended to help
+the downstream video player display content in a way that reflects the
+intentions of the the content creator. When you set Color space
+conversion (ColorSpaceConversion) to HDR 10 (FORCE_HDR10), these
+settings are required. You must set values for Max frame average light
+level (maxFrameAverageLightLevel) and Max content light level
+(maxContentLightLevel); these settings don't have a default value. The
+default values for the other HDR 10 metadata settings are defined by
+the P3D65 color space. For more information about MediaConvert HDR
+jobs, see https://docs.aws.amazon.com/console/mediaconvert/hdr.
 
 
 =head2 Hue => Int
