@@ -39,7 +39,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           {
             AudioNormalizationSettings => {
               Algorithm => 'ITU_BS_1770_1'
-              ,    # values: ITU_BS_1770_1, ITU_BS_1770_2; OPTIONAL
+              , # values: ITU_BS_1770_1, ITU_BS_1770_2, ITU_BS_1770_3, ITU_BS_1770_4; OPTIONAL
               AlgorithmControl =>
                 'CORRECT_AUDIO', # values: CORRECT_AUDIO, MEASURE_ONLY; OPTIONAL
               CorrectionGateLevel => 1,        # min: -70; OPTIONAL
@@ -83,11 +83,36 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               },    # OPTIONAL
               AiffSettings => {
                 BitDepth   => 1,    # min: 16, max: 24; OPTIONAL
-                Channels   => 1,    # min: 1, max: 2; OPTIONAL
+                Channels   => 1,    # min: 1, max: 64; OPTIONAL
                 SampleRate => 1,    # min: 8000, max: 192000; OPTIONAL
               },    # OPTIONAL
               Codec => 'AAC'
-              ,  # values: AAC, MP2, WAV, AIFF, AC3, EAC3, PASSTHROUGH; OPTIONAL
+              , # values: AAC, MP2, MP3, WAV, AIFF, AC3, EAC3, EAC3_ATMOS, PASSTHROUGH; OPTIONAL
+              Eac3AtmosSettings => {
+                Bitrate => 1,    # min: 384000, max: 768000; OPTIONAL
+                BitstreamMode =>
+                  'COMPLETE_MAIN',    # values: COMPLETE_MAIN; OPTIONAL
+                CodingMode =>
+                  'CODING_MODE_9_1_6',    # values: CODING_MODE_9_1_6; OPTIONAL
+                DialogueIntelligence =>
+                  'ENABLED',              # values: ENABLED, DISABLED; OPTIONAL
+                DynamicRangeCompressionLine => 'NONE'
+                , # values: NONE, FILM_STANDARD, FILM_LIGHT, MUSIC_STANDARD, MUSIC_LIGHT, SPEECH; OPTIONAL
+                DynamicRangeCompressionRf => 'NONE'
+                , # values: NONE, FILM_STANDARD, FILM_LIGHT, MUSIC_STANDARD, MUSIC_LIGHT, SPEECH; OPTIONAL
+                LoRoCenterMixLevel   => 1,        # OPTIONAL
+                LoRoSurroundMixLevel => 1,        # OPTIONAL
+                LtRtCenterMixLevel   => 1,        # OPTIONAL
+                LtRtSurroundMixLevel => 1,        # OPTIONAL
+                MeteringMode         => 'LEQ_A'
+                , # values: LEQ_A, ITU_BS_1770_1, ITU_BS_1770_2, ITU_BS_1770_3, ITU_BS_1770_4; OPTIONAL
+                SampleRate      => 1,    # min: 48000, max: 48000; OPTIONAL
+                SpeechThreshold => 1,    # min: 1, max: 100; OPTIONAL
+                StereoDownmix => 'NOT_INDICATED'
+                ,    # values: NOT_INDICATED, STEREO, SURROUND, DPL2; OPTIONAL
+                SurroundExMode => 'NOT_INDICATED'
+                ,    # values: NOT_INDICATED, ENABLED, DISABLED; OPTIONAL
+              },    # OPTIONAL
               Eac3Settings => {
                 AttenuationControl =>
                   'ATTENUATE_3_DB',    # values: ATTENUATE_3_DB, NONE; OPTIONAL
@@ -127,16 +152,22 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                 Channels   => 1,    # min: 1, max: 2; OPTIONAL
                 SampleRate => 1,    # min: 32000, max: 48000; OPTIONAL
               },    # OPTIONAL
+              Mp3Settings => {
+                Bitrate         => 1,        # min: 16000, max: 320000; OPTIONAL
+                Channels        => 1,        # min: 1, max: 2; OPTIONAL
+                RateControlMode => 'CBR',    # values: CBR, VBR; OPTIONAL
+                SampleRate      => 1,        # min: 22050, max: 48000; OPTIONAL
+                VbrQuality      => 1,        # max: 9; OPTIONAL
+              },    # OPTIONAL
               WavSettings => {
                 BitDepth   => 1,         # min: 16, max: 24; OPTIONAL
-                Channels   => 1,         # min: 1, max: 8; OPTIONAL
+                Channels   => 1,         # min: 1, max: 64; OPTIONAL
                 Format     => 'RIFF',    # values: RIFF, RF64; OPTIONAL
                 SampleRate => 1,         # min: 8000, max: 192000; OPTIONAL
               },    # OPTIONAL
             },    # OPTIONAL
-            CustomLanguageCode =>
-              'My__stringMin3Max3PatternAZaZ3',    # min: 3, max: 3; OPTIONAL
-            LanguageCode => 'ENG'
+            CustomLanguageCode => 'My__stringPatternAZaZ23AZaZ',    # OPTIONAL
+            LanguageCode       => 'ENG'
             , # values: ENG, SPA, FRA, DEU, GER, ZHO, ARA, HIN, JPN, RUS, POR, ITA, URD, VIE, KOR, PAN, ABK, AAR, AFR, AKA, SQI, AMH, ARG, HYE, ASM, AVA, AVE, AYM, AZE, BAM, BAK, EUS, BEL, BEN, BIH, BIS, BOS, BRE, BUL, MYA, CAT, KHM, CHA, CHE, NYA, CHU, CHV, COR, COS, CRE, HRV, CES, DAN, DIV, NLD, DZO, ENM, EPO, EST, EWE, FAO, FIJ, FIN, FRM, FUL, GLA, GLG, LUG, KAT, ELL, GRN, GUJ, HAT, HAU, HEB, HER, HMO, HUN, ISL, IDO, IBO, IND, INA, ILE, IKU, IPK, GLE, JAV, KAL, KAN, KAU, KAS, KAZ, KIK, KIN, KIR, KOM, KON, KUA, KUR, LAO, LAT, LAV, LIM, LIN, LIT, LUB, LTZ, MKD, MLG, MSA, MAL, MLT, GLV, MRI, MAR, MAH, MON, NAU, NAV, NDE, NBL, NDO, NEP, SME, NOR, NOB, NNO, OCI, OJI, ORI, ORM, OSS, PLI, FAS, POL, PUS, QUE, QAA, RON, ROH, RUN, SMO, SAG, SAN, SRD, SRB, SNA, III, SND, SIN, SLK, SLV, SOM, SOT, SUN, SWA, SSW, SWE, TGL, TAH, TGK, TAM, TAT, TEL, THA, BOD, TIR, TON, TSO, TSN, TUR, TUK, TWI, UIG, UKR, UZB, VEN, VOL, WLN, CYM, FRY, WOL, XHO, YID, YOR, ZHA, ZUL, ORJ, QPC, TNG; OPTIONAL
             LanguageCodeControl =>
               'FOLLOW_INPUT',   # values: FOLLOW_INPUT, USE_CONFIGURED; OPTIONAL
@@ -151,8 +182,8 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                   ...
                 ],              # OPTIONAL
               },    # OPTIONAL
-              ChannelsIn  => 1,    # min: 1, max: 16; OPTIONAL
-              ChannelsOut => 1,    # min: 1, max: 8; OPTIONAL
+              ChannelsIn  => 1,    # min: 1, max: 64; OPTIONAL
+              ChannelsOut => 1,    # min: 1, max: 64; OPTIONAL
             },    # OPTIONAL
             StreamName => 'My__stringPatternWS',    # OPTIONAL
           },
@@ -160,8 +191,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
         ],                                          # OPTIONAL
         CaptionDescriptions => [
           {
-            CustomLanguageCode =>
-              'My__stringMin3Max3PatternAZaZ3',     # min: 3, max: 3; OPTIONAL
+            CustomLanguageCode  => 'My__stringPatternAZaZ23AZaZ',    # OPTIONAL
             DestinationSettings => {
               BurninDestinationSettings => {
                 Alignment => 'CENTERED',    # values: CENTERED, LEFT; OPTIONAL
@@ -190,7 +220,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                 YPosition => 1,    # max: 2147483647; OPTIONAL
               },    # OPTIONAL
               DestinationType => 'BURN_IN'
-              , # values: BURN_IN, DVB_SUB, EMBEDDED, EMBEDDED_PLUS_SCTE20, SCTE20_PLUS_EMBEDDED, SCC, SRT, SMI, TELETEXT, TTML, WEBVTT; OPTIONAL
+              , # values: BURN_IN, DVB_SUB, EMBEDDED, EMBEDDED_PLUS_SCTE20, IMSC, SCTE20_PLUS_EMBEDDED, SCC, SRT, SMI, TELETEXT, TTML, WEBVTT; OPTIONAL
               DvbSubDestinationSettings => {
                 Alignment => 'CENTERED',    # values: CENTERED, LEFT; OPTIONAL
                 BackgroundColor =>
@@ -212,6 +242,8 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                   1,    # min: -2147483648, max: 2147483647; OPTIONAL
                 ShadowYOffset =>
                   1,    # min: -2147483648, max: 2147483647; OPTIONAL
+                SubtitlingType => 'HEARING_IMPAIRED'
+                ,       # values: HEARING_IMPAIRED, STANDARD; OPTIONAL
                 TeletextSpacing =>
                   'FIXED_GRID',    # values: FIXED_GRID, PROPORTIONAL; OPTIONAL
                 XPosition => 1,    # max: 2147483647; OPTIONAL
@@ -219,14 +251,23 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               },    # OPTIONAL
               EmbeddedDestinationSettings => {
                 Destination608ChannelNumber => 1,    # min: 1, max: 4; OPTIONAL
+                Destination708ServiceNumber => 1,    # min: 1, max: 6; OPTIONAL
+              },    # OPTIONAL
+              ImscDestinationSettings => {
+                StylePassthrough =>
+                  'ENABLED',    # values: ENABLED, DISABLED; OPTIONAL
               },    # OPTIONAL
               SccDestinationSettings => {
                 Framerate => 'FRAMERATE_23_97'
-                , # values: FRAMERATE_23_97, FRAMERATE_24, FRAMERATE_29_97_DROPFRAME, FRAMERATE_29_97_NON_DROPFRAME; OPTIONAL
+                , # values: FRAMERATE_23_97, FRAMERATE_24, FRAMERATE_25, FRAMERATE_29_97_DROPFRAME, FRAMERATE_29_97_NON_DROPFRAME; OPTIONAL
               },    # OPTIONAL
               TeletextDestinationSettings => {
                 PageNumber => 'My__stringMin3Max3Pattern1809aFAF09aEAE'
                 ,    # min: 3, max: 3; OPTIONAL
+                PageTypes => [
+                  'PAGE_TYPE_INITIAL',
+                  ... # values: PAGE_TYPE_INITIAL, PAGE_TYPE_SUBTITLE, PAGE_TYPE_ADDL_INFO, PAGE_TYPE_PROGRAM_SCHEDULE, PAGE_TYPE_HEARING_IMPAIRED_SUBTITLE
+                ],    # OPTIONAL
               },    # OPTIONAL
               TtmlDestinationSettings => {
                 StylePassthrough =>
@@ -240,6 +281,10 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           ...
         ],    # OPTIONAL
         ContainerSettings => {
+          CmfcSettings => {
+            Scte35Esam   => 'INSERT',      # values: INSERT, NONE; OPTIONAL
+            Scte35Source => 'PASSTHROUGH', # values: PASSTHROUGH, NONE; OPTIONAL
+          },    # OPTIONAL
           Container => 'F4V'
           , # values: F4V, ISMV, M2TS, M3U8, CMFC, MOV, MP4, MPD, MXF, RAW; OPTIONAL
           F4vSettings => {
@@ -250,7 +295,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
             AudioBufferModel  => 'DVB',    # values: DVB, ATSC; OPTIONAL
             AudioFramesPerPes => 1,        # max: 2147483647; OPTIONAL
             AudioPids         => [
-              1, ...                       # min: 32, max: 8182; OPTIONAL
+              1, ...                       # min: 32, max: 8182
             ],                             # OPTIONAL
             Bitrate        => 1,           # max: 2147483647; OPTIONAL
             BufferModel    => 'MULTIPLEX', # values: MULTIPLEX, NONE; OPTIONAL
@@ -270,12 +315,12 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                 'My__stringMin1Max256',    # min: 1, max: 256; OPTIONAL
             },    # OPTIONAL
             DvbSubPids => [
-              1, ...    # min: 32, max: 8182; OPTIONAL
+              1, ...    # min: 32, max: 8182
             ],          # OPTIONAL
             DvbTdtSettings => {
               TdtInterval => 1,    # min: 1000, max: 30000; OPTIONAL
             },    # OPTIONAL
-            DvbTeletextPid => 1,    # min: 32, max: 8182; OPTIONAL
+            DvbTeletextPid   => 1,                          # min: 32, max: 8182
             EbpAudioInterval => 'VIDEO_AND_FIXED_INTERVALS'
             ,    # values: VIDEO_AND_FIXED_INTERVALS, VIDEO_INTERVAL; OPTIONAL
             EbpPlacement => 'VIDEO_AND_AUDIO_PIDS'
@@ -290,47 +335,47 @@ You shouldn't make instances of this class. Each attribute should be used as a n
             PatInterval          => 1,        # max: 1000; OPTIONAL
             PcrControl => 'PCR_EVERY_PES_PACKET'
             ,    # values: PCR_EVERY_PES_PACKET, CONFIGURED_PCR_PERIOD; OPTIONAL
-            PcrPid             => 1,        # min: 32, max: 8182; OPTIONAL
+            PcrPid             => 1,        # min: 32, max: 8182
             PmtInterval        => 1,        # max: 1000; OPTIONAL
-            PmtPid             => 1,        # min: 32, max: 8182; OPTIONAL
-            PrivateMetadataPid => 1,        # min: 32, max: 8182; OPTIONAL
+            PmtPid             => 1,        # min: 32, max: 8182
+            PrivateMetadataPid => 1,        # min: 32, max: 8182
             ProgramNumber      => 1,        # max: 65535; OPTIONAL
             RateMode           => 'VBR',    # values: VBR, CBR; OPTIONAL
             Scte35Esam         => {
-              Scte35EsamPid => 1,           # min: 32, max: 8182; OPTIONAL
+              Scte35EsamPid => 1,           # min: 32, max: 8182
             },    # OPTIONAL
-            Scte35Pid    => 1,             # min: 32, max: 8182; OPTIONAL
+            Scte35Pid    => 1,             # min: 32, max: 8182
             Scte35Source => 'PASSTHROUGH', # values: PASSTHROUGH, NONE; OPTIONAL
             SegmentationMarkers => 'NONE'
             , # values: NONE, RAI_SEGSTART, RAI_ADAPT, PSI_SEGSTART, EBP, EBP_LEGACY; OPTIONAL
             SegmentationStyle => 'MAINTAIN_CADENCE'
             ,    # values: MAINTAIN_CADENCE, RESET_CADENCE; OPTIONAL
             SegmentationTime  => 1,    # OPTIONAL
-            TimedMetadataPid  => 1,    # min: 32, max: 8182; OPTIONAL
+            TimedMetadataPid  => 1,    # min: 32, max: 8182
             TransportStreamId => 1,    # max: 65535; OPTIONAL
-            VideoPid          => 1,    # min: 32, max: 8182; OPTIONAL
+            VideoPid          => 1,    # min: 32, max: 8182
           },    # OPTIONAL
           M3u8Settings => {
             AudioFramesPerPes => 1,    # max: 2147483647; OPTIONAL
             AudioPids         => [
-              1, ...                   # min: 32, max: 8182; OPTIONAL
+              1, ...                   # min: 32, max: 8182
             ],                         # OPTIONAL
             NielsenId3  => 'INSERT',   # values: INSERT, NONE; OPTIONAL
             PatInterval => 1,          # max: 1000; OPTIONAL
             PcrControl => 'PCR_EVERY_PES_PACKET'
             ,    # values: PCR_EVERY_PES_PACKET, CONFIGURED_PCR_PERIOD; OPTIONAL
-            PcrPid             => 1,    # min: 32, max: 8182; OPTIONAL
+            PcrPid             => 1,    # min: 32, max: 8182
             PmtInterval        => 1,    # max: 1000; OPTIONAL
-            PmtPid             => 1,    # min: 32, max: 8182; OPTIONAL
-            PrivateMetadataPid => 1,    # min: 32, max: 8182; OPTIONAL
+            PmtPid             => 1,    # min: 32, max: 8182
+            PrivateMetadataPid => 1,    # min: 32, max: 8182
             ProgramNumber      => 1,    # max: 65535; OPTIONAL
-            Scte35Pid          => 1,    # min: 32, max: 8182; OPTIONAL
+            Scte35Pid          => 1,    # min: 32, max: 8182
             Scte35Source => 'PASSTHROUGH', # values: PASSTHROUGH, NONE; OPTIONAL
             TimedMetadata =>
               'PASSTHROUGH',               # values: PASSTHROUGH, NONE; OPTIONAL
-            TimedMetadataPid  => 1,        # min: 32, max: 8182; OPTIONAL
+            TimedMetadataPid  => 1,        # min: 32, max: 8182
             TransportStreamId => 1,        # max: 65535; OPTIONAL
-            VideoPid          => 1,        # min: 32, max: 8182; OPTIONAL
+            VideoPid          => 1,        # min: 32, max: 8182
           },    # OPTIONAL
           MovSettings => {
             ClapAtom => 'INCLUDE',    # values: INCLUDE, EXCLUDE; OPTIONAL
@@ -342,11 +387,18 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           },    # OPTIONAL
           Mp4Settings => {
             CslgAtom     => 'INCLUDE',    # values: INCLUDE, EXCLUDE; OPTIONAL
+            CttsVersion  => 1,            # max: 1; OPTIONAL
             FreeSpaceBox => 'INCLUDE',    # values: INCLUDE, EXCLUDE; OPTIONAL
             MoovPlacement => 'PROGRESSIVE_DOWNLOAD'
             ,    # values: PROGRESSIVE_DOWNLOAD, NORMAL; OPTIONAL
             Mp4MajorBrand => 'My__string',
           },    # OPTIONAL
+          MpdSettings => {
+            CaptionContainerType =>
+              'RAW',    # values: RAW, FRAGMENTED_MP4; OPTIONAL
+            Scte35Esam   => 'INSERT',      # values: INSERT, NONE; OPTIONAL
+            Scte35Source => 'PASSTHROUGH', # values: PASSTHROUGH, NONE; OPTIONAL
+          },    # OPTIONAL
         },    # OPTIONAL
         VideoDescription => {
           AfdSignaling  => 'NONE',        # values: NONE, AUTO, FIXED; OPTIONAL
@@ -400,22 +452,23 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               QvbrSettings => {
                 MaxAverageBitrate => 1,   # min: 1000, max: 1152000000; OPTIONAL
                 QvbrQualityLevel  => 1,   # min: 1, max: 10; OPTIONAL
+                QvbrQualityLevelFineTune => 1,    # OPTIONAL
               },    # OPTIONAL
               RateControlMode => 'VBR',    # values: VBR, CBR, QVBR; OPTIONAL
               RepeatPps => 'DISABLED',     # values: DISABLED, ENABLED; OPTIONAL
-              SceneChangeDetect =>
-                'DISABLED',                # values: DISABLED, ENABLED; OPTIONAL
-              Slices   => 1,               # min: 1, max: 32; OPTIONAL
-              SlowPal  => 'DISABLED',      # values: DISABLED, ENABLED; OPTIONAL
-              Softness => 1,               # max: 128; OPTIONAL
+              SceneChangeDetect => 'DISABLED'
+              ,    # values: DISABLED, ENABLED, TRANSITION_DETECTION; OPTIONAL
+              Slices   => 1,             # min: 1, max: 32; OPTIONAL
+              SlowPal  => 'DISABLED',    # values: DISABLED, ENABLED; OPTIONAL
+              Softness => 1,             # max: 128; OPTIONAL
               SpatialAdaptiveQuantization =>
-                'DISABLED',                # values: DISABLED, ENABLED; OPTIONAL
-              Syntax   => 'DEFAULT',       # values: DEFAULT, RP2027; OPTIONAL
-              Telecine => 'NONE',          # values: NONE, SOFT, HARD; OPTIONAL
+                'DISABLED',              # values: DISABLED, ENABLED; OPTIONAL
+              Syntax   => 'DEFAULT',     # values: DEFAULT, RP2027; OPTIONAL
+              Telecine => 'NONE',        # values: NONE, SOFT, HARD; OPTIONAL
               TemporalAdaptiveQuantization =>
-                'DISABLED',                # values: DISABLED, ENABLED; OPTIONAL
+                'DISABLED',              # values: DISABLED, ENABLED; OPTIONAL
               UnregisteredSeiTimecode =>
-                'DISABLED',                # values: DISABLED, ENABLED; OPTIONAL
+                'DISABLED',              # values: DISABLED, ENABLED; OPTIONAL
             },    # OPTIONAL
             H265Settings => {
               AdaptiveQuantization =>
@@ -457,12 +510,13 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               QvbrSettings => {
                 MaxAverageBitrate => 1,   # min: 1000, max: 1466400000; OPTIONAL
                 QvbrQualityLevel  => 1,   # min: 1, max: 10; OPTIONAL
+                QvbrQualityLevelFineTune => 1,    # OPTIONAL
               },    # OPTIONAL
               RateControlMode => 'VBR',    # values: VBR, CBR, QVBR; OPTIONAL
               SampleAdaptiveOffsetFilterMode =>
                 'DEFAULT',    # values: DEFAULT, ADAPTIVE, OFF; OPTIONAL
-              SceneChangeDetect =>
-                'DISABLED',    # values: DISABLED, ENABLED; OPTIONAL
+              SceneChangeDetect => 'DISABLED'
+              ,    # values: DISABLED, ENABLED, TRANSITION_DETECTION; OPTIONAL
               Slices  => 1,             # min: 1, max: 32; OPTIONAL
               SlowPal => 'DISABLED',    # values: DISABLED, ENABLED; OPTIONAL
               SpatialAdaptiveQuantization =>
@@ -548,7 +602,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           },    # OPTIONAL
           DropFrameTimecode => 'DISABLED', # values: DISABLED, ENABLED; OPTIONAL
           FixedAfd          => 1,          # max: 15; OPTIONAL
-          Height            => 1,          # min: 32, max: 2160; OPTIONAL
+          Height            => 1,          # min: 32, max: 8192; OPTIONAL
           Position          => {
             Height => 1,                   # min: 2, max: 2147483647; OPTIONAL
             Width  => 1,                   # min: 2, max: 2147483647; OPTIONAL
@@ -592,6 +646,15 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               Mode => 'DEINTERLACE'
               ,    # values: DEINTERLACE, INVERSE_TELECINE, ADAPTIVE; OPTIONAL
             },    # OPTIONAL
+            DolbyVision => {
+              L6Metadata => {
+                MaxCll  => 1,    # max: 65535; OPTIONAL
+                MaxFall => 1,    # max: 65535; OPTIONAL
+              },    # OPTIONAL
+              L6Mode => 'PASSTHROUGH'
+              ,     # values: PASSTHROUGH, RECALCULATE, SPECIFY; OPTIONAL
+              Profile => 'PROFILE_5',    # values: PROFILE_5; OPTIONAL
+            },    # OPTIONAL
             ImageInserter => {
               InsertableImages => [
                 {
@@ -600,7 +663,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                   FadeOut  => 1,    # max: 2147483647; OPTIONAL
                   Height   => 1,    # max: 2147483647; OPTIONAL
                   ImageInserterInput =>
-                    'My__stringMin14PatternS3BmpBMPPngPNGTgaTGA'
+'My__stringMin14PatternS3BmpBMPPngPNGTgaTGAHttpsBmpBMPPngPNGTgaTGA'
                   ,                 # min: 14; OPTIONAL
                   ImageX  => 1,     # max: 2147483647; OPTIONAL
                   ImageY  => 1,     # max: 2147483647; OPTIONAL
@@ -614,7 +677,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
             },    # OPTIONAL
             NoiseReducer => {
               Filter => 'BILATERAL'
-              , # values: BILATERAL, MEAN, GAUSSIAN, LANCZOS, SHARPEN, CONSERVE, SPATIAL; OPTIONAL
+              , # values: BILATERAL, MEAN, GAUSSIAN, LANCZOS, SHARPEN, CONSERVE, SPATIAL, TEMPORAL; OPTIONAL
               FilterSettings => {
                 Strength => 1,    # max: 3; OPTIONAL
               },    # OPTIONAL
@@ -623,6 +686,11 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                 Speed                     => 1,    # min: -2, max: 3; OPTIONAL
                 Strength                  => 1,    # max: 16; OPTIONAL
               },    # OPTIONAL
+              TemporalFilterSettings => {
+                AggressiveMode => 1,    # max: 4; OPTIONAL
+                Speed          => 1,    # min: -1, max: 3; OPTIONAL
+                Strength       => 1,    # max: 16; OPTIONAL
+              },    # OPTIONAL
             },    # OPTIONAL
             TimecodeBurnin => {
               FontSize => 1,             # min: 10, max: 48; OPTIONAL
@@ -631,7 +699,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               Prefix => 'My__stringPattern',    # OPTIONAL
             },    # OPTIONAL
           },    # OPTIONAL
-          Width => 1,    # min: 32, max: 4096; OPTIONAL
+          Width => 1,    # min: 32, max: 8192; OPTIONAL
         },    # OPTIONAL
       },
       Category    => 'My__string',                         # OPTIONAL
