@@ -65,14 +65,15 @@ channels. Only used for 3/2 coding mode.
 
 =head2 Bitrate => Int
 
-  Average bitrate in bits/second. Valid bitrates depend on the coding
-mode.
+  Specify the average bitrate in bits per second. Valid bitrates depend
+on the coding mode.
 
 
 =head2 BitstreamMode => Str
 
-  Specifies the "Bitstream Mode" (bsmod) for the emitted E-AC-3 stream.
-See ATSC A/52-2012 (Annex E) for background on these values.
+  Specify the bitstream mode for the E-AC-3 stream that the encoder
+emits. For more information about the EAC3 bitstream mode, see ATSC
+A/52-2012 (Annex E).
 
 
 =head2 CodingMode => Str
@@ -93,14 +94,14 @@ Digital Plus, dialnorm will be passed through.
 
 =head2 DynamicRangeCompressionLine => Str
 
-  Enables Dynamic Range Compression that restricts the absolute peak
-level for a signal.
+  Specify the absolute peak level for a signal with dynamic range
+compression.
 
 
 =head2 DynamicRangeCompressionRf => Str
 
-  Enables Heavy Dynamic Range Compression, ensures that the instantaneous
-signal peaks do not exceed specified levels.
+  Specify how the service limits the audio dynamic range when compressing
+the audio.
 
 
 =head2 LfeControl => Str
@@ -116,26 +117,54 @@ Only valid with 3_2_LFE coding mode.
 
 =head2 LoRoCenterMixLevel => Num
 
-  Left only/Right only center mix level. Only used for 3/2 coding mode.
-Valid values: 3.0, 1.5, 0.0, -1.5 -3.0 -4.5 -6.0 -60
+  Specify a value for the following Dolby Digital Plus setting: Left
+only/Right only center mix (Lo/Ro center). MediaConvert uses this value
+for downmixing. How the service uses this value depends on the value
+that you choose for Stereo downmix (Eac3StereoDownmix). Valid values:
+3.0, 1.5, 0.0, -1.5, -3.0, -4.5, -6.0, and -60. The value -60 mutes the
+channel. This setting applies only if you keep the default value of 3/2
+- L, R, C, Ls, Rs (CODING_MODE_3_2) for the setting Coding mode
+(Eac3CodingMode). If you choose a different value for Coding mode, the
+service ignores Left only/Right only center (loRoCenterMixLevel).
 
 
 =head2 LoRoSurroundMixLevel => Num
 
-  Left only/Right only surround mix level. Only used for 3/2 coding mode.
-Valid values: -1.5 -3.0 -4.5 -6.0 -60
+  Specify a value for the following Dolby Digital Plus setting: Left
+only/Right only (Lo/Ro surround). MediaConvert uses this value for
+downmixing. How the service uses this value depends on the value that
+you choose for Stereo downmix (Eac3StereoDownmix). Valid values: -1.5,
+-3.0, -4.5, -6.0, and -60. The value -60 mutes the channel. This
+setting applies only if you keep the default value of 3/2 - L, R, C,
+Ls, Rs (CODING_MODE_3_2) for the setting Coding mode (Eac3CodingMode).
+If you choose a different value for Coding mode, the service ignores
+Left only/Right only surround (loRoSurroundMixLevel).
 
 
 =head2 LtRtCenterMixLevel => Num
 
-  Left total/Right total center mix level. Only used for 3/2 coding mode.
-Valid values: 3.0, 1.5, 0.0, -1.5 -3.0 -4.5 -6.0 -60
+  Specify a value for the following Dolby Digital Plus setting: Left
+total/Right total center mix (Lt/Rt center). MediaConvert uses this
+value for downmixing. How the service uses this value depends on the
+value that you choose for Stereo downmix (Eac3StereoDownmix). Valid
+values: 3.0, 1.5, 0.0, -1.5, -3.0, -4.5, -6.0, and -60. The value -60
+mutes the channel. This setting applies only if you keep the default
+value of 3/2 - L, R, C, Ls, Rs (CODING_MODE_3_2) for the setting Coding
+mode (Eac3CodingMode). If you choose a different value for Coding mode,
+the service ignores Left total/Right total center (ltRtCenterMixLevel).
 
 
 =head2 LtRtSurroundMixLevel => Num
 
-  Left total/Right total surround mix level. Only used for 3/2 coding
-mode. Valid values: -1.5 -3.0 -4.5 -6.0 -60
+  Specify a value for the following Dolby Digital Plus setting: Left
+total/Right total surround mix (Lt/Rt surround). MediaConvert uses this
+value for downmixing. How the service uses this value depends on the
+value that you choose for Stereo downmix (Eac3StereoDownmix). Valid
+values: -1.5, -3.0, -4.5, -6.0, and -60. The value -60 mutes the
+channel. This setting applies only if you keep the default value of 3/2
+- L, R, C, Ls, Rs (CODING_MODE_3_2) for the setting Coding mode
+(Eac3CodingMode). If you choose a different value for Coding mode, the
+service ignores Left total/Right total surround (ltRtSurroundMixLevel).
 
 
 =head2 MetadataControl => Str
@@ -163,12 +192,16 @@ Only used for 3/2 coding mode.
 
 =head2 SampleRate => Int
 
-  Sample rate in hz. Sample rate is always 48000.
+  This value is always 48000. It represents the sample rate in Hz.
 
 
 =head2 StereoDownmix => Str
 
-  Stereo downmix preference. Only used for 3/2 coding mode.
+  Choose how the service does stereo downmixing. This setting only
+applies if you keep the default value of 3/2 - L, R, C, Ls, Rs
+(CODING_MODE_3_2) for the setting Coding mode (Eac3CodingMode). If you
+choose a different value for Coding mode, the service ignores Stereo
+downmix (Eac3StereoDownmix).
 
 
 =head2 SurroundExMode => Str
