@@ -1,6 +1,7 @@
 package Paws::MediaConvert::EmbeddedDestinationSettings;
   use Moose;
   has Destination608ChannelNumber => (is => 'ro', isa => 'Int', request_name => 'destination608ChannelNumber', traits => ['NameInRequest']);
+  has Destination708ServiceNumber => (is => 'ro', isa => 'Int', request_name => 'destination708ServiceNumber', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -20,7 +21,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::MediaConvert::EmbeddedDestinationSettings object:
 
-  $service_obj->Method(Att1 => { Destination608ChannelNumber => $value, ..., Destination608ChannelNumber => $value  });
+  $service_obj->Method(Att1 => { Destination608ChannelNumber => $value, ..., Destination708ServiceNumber => $value  });
 
 =head3 Results returned from an API call
 
@@ -40,15 +41,26 @@ Settings specific to embedded/ancillary caption outputs, including
 =head2 Destination608ChannelNumber => Int
 
   Ignore this setting unless your input captions are SCC format and your
-output container is MXF. With this combination of input captions format
-and output container, you can optionally use this setting to replace
-the input channel number with the track number that you specify.
-Specify a different number for each output captions track. If you don't
-specify an output track number, the system uses the input channel
-number for the output channel number. This setting applies to each
-output individually. You can optionally combine two captions channels
-in your output. The two output channel numbers can be one of the
-following pairs: 1,3; 2,4; 1,4; or 2,3.
+output captions are embedded in the video stream. Specify a CC number
+for each captions channel in this output. If you have two channels,
+choose CC numbers that aren't in the same field. For example, choose 1
+and 3. For more information, see
+https://docs.aws.amazon.com/console/mediaconvert/dual-scc-to-embedded.
+
+
+=head2 Destination708ServiceNumber => Int
+
+  Ignore this setting unless your input captions are SCC format and you
+want both 608 and 708 captions embedded in your output stream.
+Optionally, specify the 708 service number for each output captions
+channel. Choose a different number for each channel. To use this
+setting, also set Force 608 to 708 upconvert (Convert608To708) to
+Upconvert (UPCONVERT) in your input captions selector settings. If you
+choose to upconvert but don't specify a 708 service number,
+MediaConvert uses the number that you specify for CC channel number
+(destination608ChannelNumber) for the 708 service number. For more
+information, see
+https://docs.aws.amazon.com/console/mediaconvert/dual-scc-to-embedded.
 
 
 
