@@ -121,8 +121,14 @@ stream.
 
 =head2 Scte35Source => Str
 
-  Enables SCTE-35 passthrough (scte35Source) to pass any SCTE-35 signals
-from input to output.
+  For SCTE-35 markers from your input-- Choose Passthrough (PASSTHROUGH)
+if you want SCTE-35 markers that appear in your input to also appear in
+this output. Choose None (NONE) if you don't want SCTE-35 markers in
+this output. For SCTE-35 markers from an ESAM XML document-- Choose
+None (NONE) if you don't want manifest conditioning. Choose Passthrough
+(PASSTHROUGH) and choose Ad markers (adMarkers) if you do want manifest
+conditioning. In both cases, also provide the ESAM XML as a string in
+the setting Signal processing notification XML (sccXml).
 
 
 =head2 TimedMetadata => Str
