@@ -75,9 +75,9 @@ visual quality.
 
 =head2 Bitrate => Int
 
-  Average bitrate in bits/second. Required for VBR and CBR. For MS Smooth
-outputs, bitrates must be unique when rounded down to the nearest
-multiple of 1000.
+  Specify the average bitrate in bits per second. Required for VBR and
+CBR. For MS Smooth outputs, bitrates must be unique when rounded down
+to the nearest multiple of 1000.
 
 
 =head2 CodecLevel => Str
@@ -246,7 +246,9 @@ bitrate is variable (vbr) or constant (cbr).
 
 =head2 SceneChangeDetect => Str
 
-  Scene change detection (inserts I-frames on scene changes).
+  Enable this setting to insert I-frames at scene changes that the
+service automatically detects. This improves video quality and is
+enabled by default.
 
 
 =head2 SlowPal => Str
