@@ -38,7 +38,12 @@ Settings for SCC caption output.
 
 =head2 Framerate => Str
 
-  
+  Set Framerate (SccDestinationFramerate) to make sure that the captions
+and the video are synchronized in the output. Specify a frame rate that
+matches the frame rate of the associated video. If the video frame rate
+is 29.97, choose 29.97 dropframe (FRAMERATE_29_97_DROPFRAME) only if
+the video has video_insertion=true and drop_frame_timecode=true;
+otherwise, choose 29.97 non-dropframe (FRAMERATE_29_97_NON_DROPFRAME).
 
 
 
