@@ -34,35 +34,40 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::MediaConver
 
 =head1 DESCRIPTION
 
-Settings for use with a SPEKE key provider
+If your output group type is HLS, DASH, or Microsoft Smooth, use these
+settings when doing DRM encryption with a SPEKE-compliant key provider.
+If your output group type is CMAF, use the SpekeKeyProviderCmaf
+settings instead.
 
 =head1 ATTRIBUTES
 
 
 =head2 CertificateArn => Str
 
-  Optional AWS Certificate Manager ARN for a certificate to send to the
-keyprovider. The certificate holds a key used by the keyprovider to
-encrypt the keys in its response.
+  If you want your key provider to encrypt the content keys that it
+provides to MediaConvert, set up a certificate with a master key using
+AWS Certificate Manager. Specify the certificate's Amazon Resource Name
+(ARN) here.
 
 
 =head2 ResourceId => Str
 
-  The SPEKE-compliant server uses Resource ID (ResourceId) to identify
-content.
+  Specify the resource ID that your SPEKE-compliant key provider uses to
+identify this content.
 
 
 =head2 SystemIds => ArrayRef[Str|Undef]
 
   Relates to SPEKE implementation. DRM system identifiers. DASH output
 groups support a max of two system ids. Other group types support one
-system id.
+system id. See https://dashif.org/identifiers/content_protection/ for
+more details.
 
 
 =head2 Url => Str
 
-  Use URL (Url) to specify the SPEKE-compliant server that will provide
-keys for content.
+  Specify the URL to the key server that your SPEKE-compliant DRM key
+provider uses to provide keys for encrypting your content.
 
 
 
