@@ -1,5 +1,6 @@
 package Paws::MediaConvert::VideoSelector;
   use Moose;
+  has AlphaBehavior => (is => 'ro', isa => 'Str', request_name => 'alphaBehavior', traits => ['NameInRequest']);
   has ColorSpace => (is => 'ro', isa => 'Str', request_name => 'colorSpace', traits => ['NameInRequest']);
   has ColorSpaceUsage => (is => 'ro', isa => 'Str', request_name => 'colorSpaceUsage', traits => ['NameInRequest']);
   has Hdr10Metadata => (is => 'ro', isa => 'Paws::MediaConvert::Hdr10Metadata', request_name => 'hdr10Metadata', traits => ['NameInRequest']);
@@ -25,14 +26,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::MediaConvert::VideoSelector object:
 
-  $service_obj->Method(Att1 => { ColorSpace => $value, ..., Rotate => $value  });
+  $service_obj->Method(Att1 => { AlphaBehavior => $value, ..., Rotate => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::MediaConvert::VideoSelector object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->ColorSpace
+  $result->Att1->AlphaBehavior
 
 =head1 DESCRIPTION
 
@@ -41,44 +42,61 @@ Selector for video.
 =head1 ATTRIBUTES
 
 
+=head2 AlphaBehavior => Str
+
+  Ignore this setting unless this input is a QuickTime animation with an
+alpha channel. Use this setting to create separate Key and Fill
+outputs. In each output, specify which part of the input MediaConvert
+uses. Leave this setting at the default value DISCARD to delete the
+alpha channel and preserve the video. Set it to REMAP_TO_LUMA to delete
+the video and map the alpha channel to the luma channel of your
+outputs.
+
+
 =head2 ColorSpace => Str
 
   If your input video has accurate color space metadata, or if you don't
-know about color space, leave this set to the default value FOLLOW. The
-service will automatically detect your input color space. If your input
-video has metadata indicating the wrong color space, or if your input
-video is missing color space metadata that should be there, specify the
-accurate color space here. If you choose HDR10, you can also correct
-inaccurate color space coefficients, using the HDR master display
-information controls. You must also set Color space usage
-(ColorSpaceUsage) to FORCE for the service to use these values.
+know about color space, leave this set to the default value Follow
+(FOLLOW). The service will automatically detect your input color space.
+If your input video has metadata indicating the wrong color space,
+specify the accurate color space here. If your input video is HDR 10
+and the SMPTE ST 2086 Mastering Display Color Volume static metadata
+isn't present in your video stream, or if that metadata is present but
+not accurate, choose Force HDR 10 (FORCE_HDR10) here and specify
+correct values in the input HDR 10 metadata (Hdr10Metadata) settings.
+For more information about MediaConvert HDR jobs, see
+https://docs.aws.amazon.com/console/mediaconvert/hdr.
 
 
 =head2 ColorSpaceUsage => Str
 
   There are two sources for color metadata, the input file and the job
-configuration (in the Color space and HDR master display informaiton
-settings). The Color space usage setting controls which takes
-precedence. FORCE: The system will use color metadata supplied by user,
-if any. If the user does not supply color metadata, the system will use
-data from the source. FALLBACK: The system will use color metadata from
-the source. If source has no color metadata, the system will use
-user-supplied color metadata values if available.
+input settings Color space (ColorSpace) and HDR master display
+information settings(Hdr10Metadata). The Color space usage setting
+determines which takes precedence. Choose Force (FORCE) to use color
+metadata from the input job settings. If you don't specify values for
+those settings, the service defaults to using metadata from your input.
+FALLBACK - Choose Fallback (FALLBACK) to use color metadata from the
+source when it is present. If there's no color metadata in your input
+file, the service defaults to using values you specify in the input
+settings.
 
 
 =head2 Hdr10Metadata => L<Paws::MediaConvert::Hdr10Metadata>
 
-  Use the "HDR master display information" (Hdr10Metadata) settings to
-correct HDR metadata or to provide missing metadata. These values vary
-depending on the input video and must be provided by a color grader.
-Range is 0 to 50,000; each increment represents 0.00002 in CIE1931
-color coordinate. Note that these settings are not color correction.
-Note that if you are creating HDR outputs inside of an HLS CMAF
-package, to comply with the Apple specification, you must use the
-following settings. Set "MP4 packaging type" (writeMp4PackagingType) to
-HVC1 (HVC1). Set "Profile" (H265Settings E<gt> codecProfile) to
-Main10/High (MAIN10_HIGH). Set "Level" (H265Settings E<gt> codecLevel)
-to 5 (LEVEL_5).
+  Use these settings to provide HDR 10 metadata that is missing or
+inaccurate in your input video. Appropriate values vary depending on
+the input video and must be provided by a color grader. The color
+grader generates these values during the HDR 10 mastering process. The
+valid range for each of these settings is 0 to 50,000. Each increment
+represents 0.00002 in CIE1931 color coordinate. Related settings - When
+you specify these values, you must also set Color space (ColorSpace) to
+HDR 10 (HDR10). To specify whether the the values you specify here take
+precedence over the values in the metadata of your input file, set
+Color space usage (ColorSpaceUsage). To specify whether color metadata
+is included in an output, set Color metadata (ColorMetadata). For more
+information about MediaConvert HDR jobs, see
+https://docs.aws.amazon.com/console/mediaconvert/hdr.
 
 
 =head2 Pid => Int
