@@ -3,6 +3,7 @@ package Paws::MediaLive::AudioOnlyHlsSettings;
   has AudioGroupId => (is => 'ro', isa => 'Str', request_name => 'audioGroupId', traits => ['NameInRequest']);
   has AudioOnlyImage => (is => 'ro', isa => 'Paws::MediaLive::InputLocation', request_name => 'audioOnlyImage', traits => ['NameInRequest']);
   has AudioTrackType => (is => 'ro', isa => 'Str', request_name => 'audioTrackType', traits => ['NameInRequest']);
+  has SegmentType => (is => 'ro', isa => 'Str', request_name => 'segmentType', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -22,7 +23,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::MediaLive::AudioOnlyHlsSettings object:
 
-  $service_obj->Method(Att1 => { AudioGroupId => $value, ..., AudioTrackType => $value  });
+  $service_obj->Method(Att1 => { AudioGroupId => $value, ..., SegmentType => $value  });
 
 =head3 Results returned from an API call
 
@@ -45,14 +46,11 @@ Audio Only Hls Settings
 
 =head2 AudioOnlyImage => L<Paws::MediaLive::InputLocation>
 
-  For use with an audio only Stream. Must be a .jpg or .png file. If
-given, this image will be used as the cover-art for the audio only
-output. Ideally, it should be formatted for an iPhone screen for two
-reasons. The iPhone does not resize the image, it crops a centered
-image on the top/bottom and left/right. Additionally, this image file
-gets saved bit-for-bit into every 10-second segment file, so will
-increase bandwidth by {image file size} * {segment count} * {user
-count.}.
+  Optional. Specifies the .jpg or .png image to use as the cover art for
+an audio-only output. We recommend a low bit-size file because the
+image increases the output audio bandwidth. The image is attached to
+the audio as an ID3 tag, frame type APIC, picture type 0x10, as per the
+"ID3 tag version 2.4.0 - Native Frames" standard.
 
 
 =head2 AudioTrackType => Str
@@ -71,6 +69,11 @@ play back by default. Represented as an EXT-X-MEDIA in the HLS manifest
 with DEFAULT=NO, AUTOSELECT=NO
 
 
+=head2 SegmentType => Str
+
+  Specifies the segment type.
+
+
 
 =head1 SEE ALSO
 
