@@ -31,7 +31,7 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::MediaLive::
 
 =head1 DESCRIPTION
 
-Placeholder documentation for AvailConfiguration
+Avail Configuration
 
 =head1 ATTRIBUTES
 
