@@ -37,13 +37,27 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           {
             ActionName             => 'My__string',
             ScheduleActionSettings => {
+              HlsId3SegmentTaggingSettings => {
+                Tag => 'My__string',
+
+              },    # OPTIONAL
               HlsTimedMetadataSettings => {
                 Id3 => 'My__string',
 
               },    # OPTIONAL
               InputSwitchSettings => {
                 InputAttachmentNameReference => 'My__string',
-
+                InputClippingSettings        => {
+                  InputTimecodeSource =>
+                    'ZEROBASED',    # values: ZEROBASED, EMBEDDED
+                  StartTimecode => { Timecode => 'My__string', },    # OPTIONAL
+                  StopTimecode  => {
+                    LastFrameClippingBehavior => 'EXCLUDE_LAST_FRAME'
+                    , # values: EXCLUDE_LAST_FRAME, INCLUDE_LAST_FRAME; OPTIONAL
+                    Timecode => 'My__string',
+                  },    # OPTIONAL
+                },    # OPTIONAL
+                UrlPath => [ 'My__string', ... ],    # OPTIONAL
               },    # OPTIONAL
               PauseStateSettings => {
                 Pipelines => [
@@ -130,6 +144,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                 FollowPoint         => 'END',          # values: END, START
                 ReferenceActionName => 'My__string',
 
+              },    # OPTIONAL
+              ImmediateModeScheduleActionStartSettings => {
+
               },    # OPTIONAL
             },
 
@@ -139,7 +156,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
       },    # OPTIONAL
       Deletes => {
-        ActionNames => [ 'My__string', ... ],
+        ActionNames => [ 'My__string', ... ],    # OPTIONAL
 
       },    # OPTIONAL
     );
