@@ -1,5 +1,6 @@
 package Paws::MediaLive::HlsOutputSettings;
   use Moose;
+  has H265PackagingType => (is => 'ro', isa => 'Str', request_name => 'h265PackagingType', traits => ['NameInRequest']);
   has HlsSettings => (is => 'ro', isa => 'Paws::MediaLive::HlsSettings', request_name => 'hlsSettings', traits => ['NameInRequest'], required => 1);
   has NameModifier => (is => 'ro', isa => 'Str', request_name => 'nameModifier', traits => ['NameInRequest']);
   has SegmentModifier => (is => 'ro', isa => 'Str', request_name => 'segmentModifier', traits => ['NameInRequest']);
@@ -22,14 +23,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::MediaLive::HlsOutputSettings object:
 
-  $service_obj->Method(Att1 => { HlsSettings => $value, ..., SegmentModifier => $value  });
+  $service_obj->Method(Att1 => { H265PackagingType => $value, ..., SegmentModifier => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::MediaLive::HlsOutputSettings object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->HlsSettings
+  $result->Att1->H265PackagingType
 
 =head1 DESCRIPTION
 
@@ -38,6 +39,13 @@ Hls Output Settings
 =head1 ATTRIBUTES
 
 
+=head2 H265PackagingType => Str
+
+  Only applicable when this output is referencing an H.265 video
+description. Specifies whether MP4 segments should be packaged as HEV1
+or HVC1.
+
+
 =head2 B<REQUIRED> HlsSettings => L<Paws::MediaLive::HlsSettings>
 
   Settings regarding the underlying stream. These settings are different
