@@ -30,7 +30,7 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::MediaLive::
 
 =head1 DESCRIPTION
 
-Placeholder documentation for Scte20PlusEmbeddedDestinationSettings
+Scte20 Plus Embedded Destination Settings
 
 =head1 ATTRIBUTES
 
