@@ -2,6 +2,7 @@ package Paws::MediaLive::VideoCodecSettings;
   use Moose;
   has FrameCaptureSettings => (is => 'ro', isa => 'Paws::MediaLive::FrameCaptureSettings', request_name => 'frameCaptureSettings', traits => ['NameInRequest']);
   has H264Settings => (is => 'ro', isa => 'Paws::MediaLive::H264Settings', request_name => 'h264Settings', traits => ['NameInRequest']);
+  has H265Settings => (is => 'ro', isa => 'Paws::MediaLive::H265Settings', request_name => 'h265Settings', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -21,7 +22,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::MediaLive::VideoCodecSettings object:
 
-  $service_obj->Method(Att1 => { FrameCaptureSettings => $value, ..., H264Settings => $value  });
+  $service_obj->Method(Att1 => { FrameCaptureSettings => $value, ..., H265Settings => $value  });
 
 =head3 Results returned from an API call
 
@@ -47,6 +48,11 @@ Video Codec Settings
   
 
 
+=head2 H265Settings => L<Paws::MediaLive::H265Settings>
+
+  
+
+
 
 =head1 SEE ALSO
 
