@@ -1,6 +1,7 @@
 
 package Paws::MediaPackage::CreateOriginEndpoint;
   use Moose;
+  has Authorization => (is => 'ro', isa => 'Paws::MediaPackage::Authorization', traits => ['NameInRequest'], request_name => 'authorization');
   has ChannelId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'channelId', required => 1);
   has CmafPackage => (is => 'ro', isa => 'Paws::MediaPackage::CmafPackageCreateOrUpdateParameters', traits => ['NameInRequest'], request_name => 'cmafPackage');
   has DashPackage => (is => 'ro', isa => 'Paws::MediaPackage::DashPackage', traits => ['NameInRequest'], request_name => 'dashPackage');
@@ -9,6 +10,7 @@ package Paws::MediaPackage::CreateOriginEndpoint;
   has Id => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'id', required => 1);
   has ManifestName => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'manifestName');
   has MssPackage => (is => 'ro', isa => 'Paws::MediaPackage::MssPackage', traits => ['NameInRequest'], request_name => 'mssPackage');
+  has Origination => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'origination');
   has StartoverWindowSeconds => (is => 'ro', isa => 'Int', traits => ['NameInRequest'], request_name => 'startoverWindowSeconds');
   has Tags => (is => 'ro', isa => 'Paws::MediaPackage::Tags', traits => ['NameInRequest'], request_name => 'tags');
   has TimeDelaySeconds => (is => 'ro', isa => 'Int', traits => ['NameInRequest'], request_name => 'timeDelaySeconds');
@@ -40,8 +42,13 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $mediapackage = Paws->service('MediaPackage');
     my $CreateOriginEndpointResponse = $mediapackage->CreateOriginEndpoint(
-      ChannelId   => 'My__string',
-      Id          => 'My__string',
+      ChannelId     => 'My__string',
+      Id            => 'My__string',
+      Authorization => {
+        CdnIdentifierSecret => 'My__string',
+        SecretsRoleArn      => 'My__string',
+
+      },    # OPTIONAL
       CmafPackage => {
         Encryption => {
           SpekeKeyProvider => {
@@ -174,6 +181,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           , # values: ORIGINAL, VIDEO_BITRATE_ASCENDING, VIDEO_BITRATE_DESCENDING; OPTIONAL
         },    # OPTIONAL
       },    # OPTIONAL
+      Origination            => 'ALLOW',                              # OPTIONAL
       StartoverWindowSeconds => 1,                                    # OPTIONAL
       Tags                   => { 'My__string' => 'My__string', },    # OPTIONAL
       TimeDelaySeconds       => 1,                                    # OPTIONAL
@@ -181,15 +189,17 @@ You shouldn't make instances of this class. Each attribute should be used as a n
     );
 
     # Results:
-    my $Arn          = $CreateOriginEndpointResponse->Arn;
-    my $ChannelId    = $CreateOriginEndpointResponse->ChannelId;
-    my $CmafPackage  = $CreateOriginEndpointResponse->CmafPackage;
-    my $DashPackage  = $CreateOriginEndpointResponse->DashPackage;
-    my $Description  = $CreateOriginEndpointResponse->Description;
-    my $HlsPackage   = $CreateOriginEndpointResponse->HlsPackage;
-    my $Id           = $CreateOriginEndpointResponse->Id;
-    my $ManifestName = $CreateOriginEndpointResponse->ManifestName;
-    my $MssPackage   = $CreateOriginEndpointResponse->MssPackage;
+    my $Arn           = $CreateOriginEndpointResponse->Arn;
+    my $Authorization = $CreateOriginEndpointResponse->Authorization;
+    my $ChannelId     = $CreateOriginEndpointResponse->ChannelId;
+    my $CmafPackage   = $CreateOriginEndpointResponse->CmafPackage;
+    my $DashPackage   = $CreateOriginEndpointResponse->DashPackage;
+    my $Description   = $CreateOriginEndpointResponse->Description;
+    my $HlsPackage    = $CreateOriginEndpointResponse->HlsPackage;
+    my $Id            = $CreateOriginEndpointResponse->Id;
+    my $ManifestName  = $CreateOriginEndpointResponse->ManifestName;
+    my $MssPackage    = $CreateOriginEndpointResponse->MssPackage;
+    my $Origination   = $CreateOriginEndpointResponse->Origination;
     my $StartoverWindowSeconds =
       $CreateOriginEndpointResponse->StartoverWindowSeconds;
     my $Tags             = $CreateOriginEndpointResponse->Tags;
@@ -205,6 +215,12 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/med
 =head1 ATTRIBUTES
 
 
+=head2 Authorization => L<Paws::MediaPackage::Authorization>
+
+
+
+
+
 =head2 B<REQUIRED> ChannelId => Str
 
 The ID of the Channel that the OriginEndpoint will be associated with.
@@ -256,6 +272,16 @@ URL (defaults to "index").
 
 
 
+=head2 Origination => Str
+
+Control whether origination of video is allowed for this
+OriginEndpoint. If set to ALLOW, the OriginEndpoint may by requested,
+pursuant to any other form of access control. If set to DENY, the
+OriginEndpoint may not be requested. This can be helpful for Live to
+VOD harvesting, or for temporarily disabling origination
+
+Valid values are: C<"ALLOW">, C<"DENY">
+
 =head2 StartoverWindowSeconds => Int
 
 Maximum duration (seconds) of content to retain for startover playback.
