@@ -1,6 +1,7 @@
 package Paws::MediaPackage::OriginEndpoint;
   use Moose;
   has Arn => (is => 'ro', isa => 'Str', request_name => 'arn', traits => ['NameInRequest']);
+  has Authorization => (is => 'ro', isa => 'Paws::MediaPackage::Authorization', request_name => 'authorization', traits => ['NameInRequest']);
   has ChannelId => (is => 'ro', isa => 'Str', request_name => 'channelId', traits => ['NameInRequest']);
   has CmafPackage => (is => 'ro', isa => 'Paws::MediaPackage::CmafPackage', request_name => 'cmafPackage', traits => ['NameInRequest']);
   has DashPackage => (is => 'ro', isa => 'Paws::MediaPackage::DashPackage', request_name => 'dashPackage', traits => ['NameInRequest']);
@@ -9,6 +10,7 @@ package Paws::MediaPackage::OriginEndpoint;
   has Id => (is => 'ro', isa => 'Str', request_name => 'id', traits => ['NameInRequest']);
   has ManifestName => (is => 'ro', isa => 'Str', request_name => 'manifestName', traits => ['NameInRequest']);
   has MssPackage => (is => 'ro', isa => 'Paws::MediaPackage::MssPackage', request_name => 'mssPackage', traits => ['NameInRequest']);
+  has Origination => (is => 'ro', isa => 'Str', request_name => 'origination', traits => ['NameInRequest']);
   has StartoverWindowSeconds => (is => 'ro', isa => 'Int', request_name => 'startoverWindowSeconds', traits => ['NameInRequest']);
   has Tags => (is => 'ro', isa => 'Paws::MediaPackage::Tags', request_name => 'tags', traits => ['NameInRequest']);
   has TimeDelaySeconds => (is => 'ro', isa => 'Int', request_name => 'timeDelaySeconds', traits => ['NameInRequest']);
@@ -54,6 +56,11 @@ An OriginEndpoint resource configuration.
   The Amazon Resource Name (ARN) assigned to the OriginEndpoint.
 
 
+=head2 Authorization => L<Paws::MediaPackage::Authorization>
+
+  
+
+
 =head2 ChannelId => Str
 
   The ID of the Channel the OriginEndpoint is associated with.
@@ -94,6 +101,15 @@ An OriginEndpoint resource configuration.
   
 
 
+=head2 Origination => Str
+
+  Control whether origination of video is allowed for this
+OriginEndpoint. If set to ALLOW, the OriginEndpoint may by requested,
+pursuant to any other form of access control. If set to DENY, the
+OriginEndpoint may not be requested. This can be helpful for Live to
+VOD harvesting, or for temporarily disabling origination
+
+
 =head2 StartoverWindowSeconds => Int
 
   Maximum duration (seconds) of content to retain for startover playback.
