@@ -1,5 +1,6 @@
 package Paws::MediaPackage::OriginEndpointCreateParameters;
   use Moose;
+  has Authorization => (is => 'ro', isa => 'Paws::MediaPackage::Authorization', request_name => 'authorization', traits => ['NameInRequest']);
   has ChannelId => (is => 'ro', isa => 'Str', request_name => 'channelId', traits => ['NameInRequest'], required => 1);
   has CmafPackage => (is => 'ro', isa => 'Paws::MediaPackage::CmafPackageCreateOrUpdateParameters', request_name => 'cmafPackage', traits => ['NameInRequest']);
   has DashPackage => (is => 'ro', isa => 'Paws::MediaPackage::DashPackage', request_name => 'dashPackage', traits => ['NameInRequest']);
@@ -8,6 +9,7 @@ package Paws::MediaPackage::OriginEndpointCreateParameters;
   has Id => (is => 'ro', isa => 'Str', request_name => 'id', traits => ['NameInRequest'], required => 1);
   has ManifestName => (is => 'ro', isa => 'Str', request_name => 'manifestName', traits => ['NameInRequest']);
   has MssPackage => (is => 'ro', isa => 'Paws::MediaPackage::MssPackage', request_name => 'mssPackage', traits => ['NameInRequest']);
+  has Origination => (is => 'ro', isa => 'Str', request_name => 'origination', traits => ['NameInRequest']);
   has StartoverWindowSeconds => (is => 'ro', isa => 'Int', request_name => 'startoverWindowSeconds', traits => ['NameInRequest']);
   has Tags => (is => 'ro', isa => 'Paws::MediaPackage::Tags', request_name => 'tags', traits => ['NameInRequest']);
   has TimeDelaySeconds => (is => 'ro', isa => 'Int', request_name => 'timeDelaySeconds', traits => ['NameInRequest']);
@@ -31,14 +33,14 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::MediaPackage::OriginEndpointCreateParameters object:
 
-  $service_obj->Method(Att1 => { ChannelId => $value, ..., Whitelist => $value  });
+  $service_obj->Method(Att1 => { Authorization => $value, ..., Whitelist => $value  });
 
 =head3 Results returned from an API call
 
 Use accessors for each attribute. If Att1 is expected to be an Paws::MediaPackage::OriginEndpointCreateParameters object:
 
   $result = $service_obj->Method(...);
-  $result->Att1->ChannelId
+  $result->Att1->Authorization
 
 =head1 DESCRIPTION
 
@@ -47,6 +49,11 @@ Configuration parameters for a new OriginEndpoint.
 =head1 ATTRIBUTES
 
 
+=head2 Authorization => L<Paws::MediaPackage::Authorization>
+
+  
+
+
 =head2 B<REQUIRED> ChannelId => Str
 
   The ID of the Channel that the OriginEndpoint will be associated with.
@@ -90,6 +97,15 @@ URL (defaults to "index").
   
 
 
+=head2 Origination => Str
+
+  Control whether origination of video is allowed for this
+OriginEndpoint. If set to ALLOW, the OriginEndpoint may by requested,
+pursuant to any other form of access control. If set to DENY, the
+OriginEndpoint may not be requested. This can be helpful for Live to
+VOD harvesting, or for temporarily disabling origination
+
+
 =head2 StartoverWindowSeconds => Int
 
   Maximum duration (seconds) of content to retain for startover playback.
