@@ -1,6 +1,7 @@
 
 package Paws::MediaPackage::UpdateOriginEndpoint;
   use Moose;
+  has Authorization => (is => 'ro', isa => 'Paws::MediaPackage::Authorization', traits => ['NameInRequest'], request_name => 'authorization');
   has CmafPackage => (is => 'ro', isa => 'Paws::MediaPackage::CmafPackageCreateOrUpdateParameters', traits => ['NameInRequest'], request_name => 'cmafPackage');
   has DashPackage => (is => 'ro', isa => 'Paws::MediaPackage::DashPackage', traits => ['NameInRequest'], request_name => 'dashPackage');
   has Description => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'description');
@@ -8,6 +9,7 @@ package Paws::MediaPackage::UpdateOriginEndpoint;
   has Id => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'id', required => 1);
   has ManifestName => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'manifestName');
   has MssPackage => (is => 'ro', isa => 'Paws::MediaPackage::MssPackage', traits => ['NameInRequest'], request_name => 'mssPackage');
+  has Origination => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'origination');
   has StartoverWindowSeconds => (is => 'ro', isa => 'Int', traits => ['NameInRequest'], request_name => 'startoverWindowSeconds');
   has TimeDelaySeconds => (is => 'ro', isa => 'Int', traits => ['NameInRequest'], request_name => 'timeDelaySeconds');
   has Whitelist => (is => 'ro', isa => 'ArrayRef[Str|Undef]', traits => ['NameInRequest'], request_name => 'whitelist');
@@ -38,7 +40,12 @@ You shouldn't make instances of this class. Each attribute should be used as a n
 
     my $mediapackage = Paws->service('MediaPackage');
     my $UpdateOriginEndpointResponse = $mediapackage->UpdateOriginEndpoint(
-      Id          => 'My__string',
+      Id            => 'My__string',
+      Authorization => {
+        CdnIdentifierSecret => 'My__string',
+        SecretsRoleArn      => 'My__string',
+
+      },    # OPTIONAL
       CmafPackage => {
         Encryption => {
           SpekeKeyProvider => {
@@ -171,21 +178,24 @@ You shouldn't make instances of this class. Each attribute should be used as a n
           , # values: ORIGINAL, VIDEO_BITRATE_ASCENDING, VIDEO_BITRATE_DESCENDING; OPTIONAL
         },    # OPTIONAL
       },    # OPTIONAL
+      Origination            => 'ALLOW',                  # OPTIONAL
       StartoverWindowSeconds => 1,                        # OPTIONAL
       TimeDelaySeconds       => 1,                        # OPTIONAL
       Whitelist              => [ 'My__string', ... ],    # OPTIONAL
     );
 
     # Results:
-    my $Arn          = $UpdateOriginEndpointResponse->Arn;
-    my $ChannelId    = $UpdateOriginEndpointResponse->ChannelId;
-    my $CmafPackage  = $UpdateOriginEndpointResponse->CmafPackage;
-    my $DashPackage  = $UpdateOriginEndpointResponse->DashPackage;
-    my $Description  = $UpdateOriginEndpointResponse->Description;
-    my $HlsPackage   = $UpdateOriginEndpointResponse->HlsPackage;
-    my $Id           = $UpdateOriginEndpointResponse->Id;
-    my $ManifestName = $UpdateOriginEndpointResponse->ManifestName;
-    my $MssPackage   = $UpdateOriginEndpointResponse->MssPackage;
+    my $Arn           = $UpdateOriginEndpointResponse->Arn;
+    my $Authorization = $UpdateOriginEndpointResponse->Authorization;
+    my $ChannelId     = $UpdateOriginEndpointResponse->ChannelId;
+    my $CmafPackage   = $UpdateOriginEndpointResponse->CmafPackage;
+    my $DashPackage   = $UpdateOriginEndpointResponse->DashPackage;
+    my $Description   = $UpdateOriginEndpointResponse->Description;
+    my $HlsPackage    = $UpdateOriginEndpointResponse->HlsPackage;
+    my $Id            = $UpdateOriginEndpointResponse->Id;
+    my $ManifestName  = $UpdateOriginEndpointResponse->ManifestName;
+    my $MssPackage    = $UpdateOriginEndpointResponse->MssPackage;
+    my $Origination   = $UpdateOriginEndpointResponse->Origination;
     my $StartoverWindowSeconds =
       $UpdateOriginEndpointResponse->StartoverWindowSeconds;
     my $Tags             = $UpdateOriginEndpointResponse->Tags;
@@ -201,6 +211,12 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/med
 =head1 ATTRIBUTES
 
 
+=head2 Authorization => L<Paws::MediaPackage::Authorization>
+
+
+
+
+
 =head2 CmafPackage => L<Paws::MediaPackage::CmafPackageCreateOrUpdateParameters>
 
 
@@ -243,6 +259,16 @@ A short string that will be appended to the end of the Endpoint URL.
 
 
 
+=head2 Origination => Str
+
+Control whether origination of video is allowed for this
+OriginEndpoint. If set to ALLOW, the OriginEndpoint may by requested,
+pursuant to any other form of access control. If set to DENY, the
+OriginEndpoint may not be requested. This can be helpful for Live to
+VOD harvesting, or for temporarily disabling origination
+
+Valid values are: C<"ALLOW">, C<"DENY">
+
 =head2 StartoverWindowSeconds => Int
 
 Maximum duration (in seconds) of content to retain for startover
