@@ -32,20 +32,7 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Neptune::DB
 
 =head1 DESCRIPTION
 
-This data type is used as a response element in the following actions:
-
-=over
-
-=item *
-
-ModifyDBInstance
-
-=item *
-
-RebootDBInstance
-
-=back
-
+Specifies membership in a designated DB security group.
 
 =head1 ATTRIBUTES
 
