@@ -124,9 +124,9 @@ attributes.
 =head2 AutoAssignElasticIps => Bool
 
 Whether to automatically assign an Elastic IP address
-(http://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html)
+(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/elastic-ip-addresses-eip.html)
 to the layer's instances. For more information, see How to Edit a Layer
-(http://docs.aws.amazon.com/opsworks/latest/userguide/workinglayers-basics-edit.html).
+(https://docs.aws.amazon.com/opsworks/latest/userguide/workinglayers-basics-edit.html).
 
 
 
@@ -135,7 +135,7 @@ to the layer's instances. For more information, see How to Edit a Layer
 For stacks that are running in a VPC, whether to automatically assign a
 public IP address to the layer's instances. For more information, see
 How to Edit a Layer
-(http://docs.aws.amazon.com/opsworks/latest/userguide/workinglayers-basics-edit.html).
+(https://docs.aws.amazon.com/opsworks/latest/userguide/workinglayers-basics-edit.html).
 
 
 
@@ -150,7 +150,7 @@ information, see CloudWatchLogsLogStream.
 
 The ARN of an IAM profile to be used for all of the layer's EC2
 instances. For more information about IAM ARNs, see Using Identifiers
-(http://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html).
+(https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html).
 
 
 
@@ -159,7 +159,7 @@ instances. For more information about IAM ARNs, see Using Identifiers
 A JSON-formatted string containing custom stack configuration and
 deployment attributes to be installed on the layer's instances. For
 more information, see Using Custom JSON
-(http://docs.aws.amazon.com/opsworks/latest/userguide/workingcookbook-json-override.html).
+(https://docs.aws.amazon.com/opsworks/latest/userguide/workingcookbook-json-override.html).
 
 
 
@@ -230,7 +230,7 @@ be in the following format: /\A[a-z0-9\-\_\.]+\Z/.
 
 The built-in layers' short names are defined by AWS OpsWorks Stacks.
 For more information, see the Layer Reference
-(http://docs.aws.amazon.com/opsworks/latest/userguide/layers.html)
+(https://docs.aws.amazon.com/opsworks/latest/userguide/layers.html)
 
 
 
