@@ -48,14 +48,14 @@ string requires one of the following:
 
 =item *
 
-Account: a string that consists of exactly 12 digits.
+Account: A string that consists of exactly 12 digits.
 
 =item *
 
-Organizational unit (OU): a string that begins with "ou-" followed by
+Organizational unit (OU): A string that begins with "ou-" followed by
 from 4 to 32 lower-case letters or digits (the ID of the root that
-contains the OU) followed by a second "-" dash and from 8 to 32
-additional lower-case letters or digits.
+contains the OU). This string is followed by a second "-" dash and from
+8 to 32 additional lower-case letters or digits.
 
 =back
 
