@@ -13,21 +13,23 @@ package Paws::Organizations::LeaveOrganization;
 
 =head1 NAME
 
-Paws::Organizations::LeaveOrganization - Arguments for method LeaveOrganization on Paws::Organizations
+Paws::Organizations::LeaveOrganization - Arguments for method LeaveOrganization on L<Paws::Organizations>
 
 =head1 DESCRIPTION
 
-This class represents the parameters used for calling the method LeaveOrganization on the 
-AWS Organizations service. Use the attributes of this class
+This class represents the parameters used for calling the method LeaveOrganization on the
+L<AWS Organizations|Paws::Organizations> service. Use the attributes of this class
 as arguments to method LeaveOrganization.
 
 You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to LeaveOrganization.
 
-As an example:
+=head1 SYNOPSIS
 
-  $service_obj->LeaveOrganization(Att1 => $value1, Att2 => $value2, ...);
+    my $organizations = Paws->service('Organizations');
+    $organizations->LeaveOrganization();
 
 Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
+For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/organizations/LeaveOrganization>
 
 =head1 ATTRIBUTES
 
@@ -39,9 +41,9 @@ This class forms part of L<Paws>, documenting arguments for method LeaveOrganiza
 
 =head1 BUGS and CONTRIBUTIONS
 
-The source code is located here: https://github.com/pplu/aws-sdk-perl
+The source code is located here: L<https://github.com/pplu/aws-sdk-perl>
 
-Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues
+Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>
 
 =cut
 
