@@ -10,7 +10,7 @@ package Paws::Pinpoint::APNSChannelResponse;
   has IsArchived => (is => 'ro', isa => 'Bool');
   has LastModifiedBy => (is => 'ro', isa => 'Str');
   has LastModifiedDate => (is => 'ro', isa => 'Str');
-  has Platform => (is => 'ro', isa => 'Str');
+  has Platform => (is => 'ro', isa => 'Str', required => 1);
   has Version => (is => 'ro', isa => 'Int');
 1;
 
@@ -42,71 +42,76 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Pinpoint::A
 
 =head1 DESCRIPTION
 
-Apple Distribution Push Notification Service channel definition.
+Provides information about the status and settings of the APNs (Apple
+Push Notification service) channel for an application.
 
 =head1 ATTRIBUTES
 
 
 =head2 ApplicationId => Str
 
-  The ID of the application that the channel applies to.
+  The unique identifier for the application that the APNs channel applies
+to.
 
 
 =head2 CreationDate => Str
 
-  The date and time when this channel was created.
+  The date and time when the APNs channel was enabled.
 
 
 =head2 DefaultAuthenticationMethod => Str
 
-  The default authentication method used for APNs.
+  The default authentication method that Amazon Pinpoint uses to
+authenticate with APNs for this channel, key or certificate.
 
 
 =head2 Enabled => Bool
 
-  If the channel is enabled for sending messages.
+  Specifies whether the APNs channel is enabled for the application.
 
 
 =head2 HasCredential => Bool
 
-  Not used. Retained for backwards compatibility.
+  (Not used) This property is retained only for backward compatibility.
 
 
 =head2 HasTokenKey => Bool
 
-  Indicates whether the channel is configured with a key for APNs token
-authentication. Provide a token key by setting the TokenKey attribute.
+  Specifies whether the APNs channel is configured to communicate with
+APNs by using APNs tokens. To provide an authentication key for APNs
+tokens, set the TokenKey property of the channel.
 
 
 =head2 Id => Str
 
-  (Deprecated) An identifier for the channel. Retained for backwards
-compatibility.
+  (Deprecated) An identifier for the APNs channel. This property is
+retained only for backward compatibility.
 
 
 =head2 IsArchived => Bool
 
-  Indicates whether or not the channel is archived.
+  Specifies whether the APNs channel is archived.
 
 
 =head2 LastModifiedBy => Str
 
-  The user who last updated this channel.
+  The user who last modified the APNs channel.
 
 
 =head2 LastModifiedDate => Str
 
-  The date and time when this channel was last modified.
+  The date and time when the APNs channel was last modified.
 
 
-=head2 Platform => Str
+=head2 B<REQUIRED> Platform => Str
 
-  The platform type. For this channel, the value is always "ADM."
+  The type of messaging or notification platform for the channel. For the
+APNs channel, this value is APNS.
 
 
 =head2 Version => Int
 
-  The channel version.
+  The current version of the APNs channel.
 
 
 
