@@ -10,7 +10,7 @@ package Paws::Pinpoint::APNSVoipChannelResponse;
   has IsArchived => (is => 'ro', isa => 'Bool');
   has LastModifiedBy => (is => 'ro', isa => 'Str');
   has LastModifiedDate => (is => 'ro', isa => 'Str');
-  has Platform => (is => 'ro', isa => 'Str');
+  has Platform => (is => 'ro', isa => 'Str', required => 1);
   has Version => (is => 'ro', isa => 'Int');
 1;
 
@@ -42,69 +42,76 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Pinpoint::A
 
 =head1 DESCRIPTION
 
-Apple VoIP Push Notification Service channel definition.
+Provides information about the status and settings of the APNs (Apple
+Push Notification service) VoIP channel for an application.
 
 =head1 ATTRIBUTES
 
 
 =head2 ApplicationId => Str
 
-  Application id
+  The unique identifier for the application that the APNs VoIP channel
+applies to.
 
 
 =head2 CreationDate => Str
 
-  When was this segment created
+  The date and time when the APNs VoIP channel was enabled.
 
 
 =head2 DefaultAuthenticationMethod => Str
 
-  The default authentication method used for APNs.
+  The default authentication method that Amazon Pinpoint uses to
+authenticate with APNs for this channel, key or certificate.
 
 
 =head2 Enabled => Bool
 
-  If the channel is enabled for sending messages.
+  Specifies whether the APNs VoIP channel is enabled for the application.
 
 
 =head2 HasCredential => Bool
 
-  Not used. Retained for backwards compatibility.
+  (Not used) This property is retained only for backward compatibility.
 
 
 =head2 HasTokenKey => Bool
 
-  If the channel is registered with a token key for authentication.
+  Specifies whether the APNs VoIP channel is configured to communicate
+with APNs by using APNs tokens. To provide an authentication key for
+APNs tokens, set the TokenKey property of the channel.
 
 
 =head2 Id => Str
 
-  Channel ID. Not used, only for backwards compatibility.
+  (Deprecated) An identifier for the APNs VoIP channel. This property is
+retained only for backward compatibility.
 
 
 =head2 IsArchived => Bool
 
-  Is this channel archived
+  Specifies whether the APNs VoIP channel is archived.
 
 
 =head2 LastModifiedBy => Str
 
-  Who made the last change
+  The user who last modified the APNs VoIP channel.
 
 
 =head2 LastModifiedDate => Str
 
-  Last date this was updated
+  The date and time when the APNs VoIP channel was last modified.
 
 
-=head2 Platform => Str
+=head2 B<REQUIRED> Platform => Str
 
-  The platform type. Will be APNS.
+  The type of messaging or notification platform for the channel. For the
+APNs VoIP channel, this value is APNS_VOIP.
 
 
 =head2 Version => Int
 
-  Version of channel
+  The current version of the APNs VoIP channel.
 
 
 
