@@ -42,85 +42,94 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Pinpoint::E
 
 =head1 DESCRIPTION
 
-Endpoint update request
+Specifies an endpoint to create or update and the settings and
+attributes to set or change for the endpoint.
 
 =head1 ATTRIBUTES
 
 
 =head2 Address => Str
 
-  The destination for messages that you send to this endpoint. The
-address varies by channel. For mobile push channels, use the token
-provided by the push notification service, such as the APNs device
-token or the FCM registration token. For the SMS channel, use a phone
-number in E.164 format, such as +12065550100. For the email channel,
-use an email address.
+  The destination address for messages or push notifications that you
+send to the endpoint. The address varies by channel. For a
+push-notification channel, use the token provided by the push
+notification service, such as an Apple Push Notification service (APNs)
+device token or a Firebase Cloud Messaging (FCM) registration token.
+For the SMS channel, use a phone number in E.164 format, such as
++12065550100. For the email channel, use an email address.
 
 
 =head2 Attributes => L<Paws::Pinpoint::MapOfListOf__string>
 
-  Custom attributes that describe the endpoint by associating a name with
-an array of values. For example, an attribute named "interests" might
-have the values ["science", "politics", "travel"]. You can use these
-attributes as selection criteria when you create a segment of users to
-engage with a messaging campaign. The following characters are not
-recommended in attribute names: # : ? \ /. The Amazon Pinpoint console
-does not display attributes that include these characters in the name.
-This limitation does not apply to attribute values.
+  One or more custom attributes that describe the endpoint by associating
+a name with an array of values. For example, the value of a custom
+attribute named Interests might be: ["science", "music", "travel"]. You
+can use these attributes as filter criteria when you create segments.
+
+When you define the name of a custom attribute, avoid using the
+following characters: number sign (#), colon (:), question mark (?),
+backslash (\), and slash (/). The Amazon Pinpoint console can't display
+attribute names that contain these characters. This limitation doesn't
+apply to attribute values.
 
 
 =head2 ChannelType => Str
 
-  The channel type. Valid values: GCM | APNS | APNS_SANDBOX | APNS_VOIP |
-APNS_VOIP_SANDBOX | ADM | SMS | EMAIL | BAIDU
+  The channel to use when sending messages or push notifications to the
+endpoint.
 
 
 =head2 Demographic => L<Paws::Pinpoint::EndpointDemographic>
 
-  The endpoint demographic attributes.
+  The demographic information for the endpoint, such as the time zone and
+platform.
 
 
 =head2 EffectiveDate => Str
 
-  The last time the endpoint was updated. Provided in ISO 8601 format.
+  The date and time, in ISO 8601 format, when the endpoint was created or
+updated.
 
 
 =head2 EndpointStatus => Str
 
-  Unused.
+  Not used.
 
 
 =head2 Id => Str
 
-  The unique Id for the Endpoint in the batch.
+  The unique identifier for the endpoint in the context of the batch.
 
 
 =head2 Location => L<Paws::Pinpoint::EndpointLocation>
 
-  The endpoint location attributes.
+  The geographic information for the endpoint.
 
 
 =head2 Metrics => L<Paws::Pinpoint::MapOf__double>
 
-  Custom metrics that your app reports to Amazon Pinpoint.
+  One or more custom metrics that your app reports to Amazon Pinpoint for
+the endpoint.
 
 
 =head2 OptOut => Str
 
-  Indicates whether a user has opted out of receiving messages with one
-of the following values: ALL - User has opted out of all messages. NONE
-- Users has not opted out and receives all messages.
+  Specifies whether the user who's associated with the endpoint has opted
+out of receiving messages and push notifications from you. Possible
+values are: ALL, the user has opted out and doesn't want to receive any
+messages or push notifications; and, NONE, the user hasn't opted out
+and wants to receive all messages and push notifications.
 
 
 =head2 RequestId => Str
 
-  The unique ID for the most recent request to update the endpoint.
+  The unique identifier for the request to create or update the endpoint.
 
 
 =head2 User => L<Paws::Pinpoint::EndpointUser>
 
-  Custom user-specific attributes that your app reports to Amazon
-Pinpoint.
+  One or more custom user attributes that your app reports to Amazon
+Pinpoint for the user who's associated with the endpoint.
 
 
 
