@@ -1,7 +1,7 @@
 package Paws::Pinpoint::ExportJobResource;
   use Moose;
-  has RoleArn => (is => 'ro', isa => 'Str');
-  has S3UrlPrefix => (is => 'ro', isa => 'Str');
+  has RoleArn => (is => 'ro', isa => 'Str', required => 1);
+  has S3UrlPrefix => (is => 'ro', isa => 'Str', required => 1);
   has SegmentId => (is => 'ro', isa => 'Str');
   has SegmentVersion => (is => 'ro', isa => 'Int');
 1;
@@ -34,35 +34,42 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Pinpoint::E
 
 =head1 DESCRIPTION
 
-Export job resource.
+Provides information about the resource settings for a job that exports
+endpoint definitions to a file. The file can be added directly to an
+Amazon Simple Storage Service (Amazon S3) bucket by using the Amazon
+Pinpoint API or downloaded directly to a computer by using the Amazon
+Pinpoint console.
 
 =head1 ATTRIBUTES
 
 
-=head2 RoleArn => Str
+=head2 B<REQUIRED> RoleArn => Str
 
-  The Amazon Resource Name (ARN) of an IAM role that grants Amazon
-Pinpoint access to the Amazon S3 location that endpoints will be
-exported to.
+  The Amazon Resource Name (ARN) of the AWS Identity and Access
+Management (IAM) role that authorized Amazon Pinpoint to access the
+Amazon S3 location where the endpoint definitions were exported to.
 
 
-=head2 S3UrlPrefix => Str
+=head2 B<REQUIRED> S3UrlPrefix => Str
 
-  A URL that points to the location within an Amazon S3 bucket that will
-receive the export. The location is typically a folder with multiple
-files. The URL should follow this format: s3://bucket-name/folder-name/
-Amazon Pinpoint will export endpoints to this location.
+  The URL of the location in an Amazon Simple Storage Service (Amazon S3)
+bucket where the endpoint definitions were exported to. This location
+is typically a folder that contains multiple files. The URL should be
+in the following format: s3://bucket-name/folder-name/.
 
 
 =head2 SegmentId => Str
 
-  The ID of the segment to export endpoints from. If not present, Amazon
-Pinpoint exports all of the endpoints that belong to the application.
+  The identifier for the segment that the endpoint definitions were
+exported from. If this value isn't present, Amazon Pinpoint exported
+definitions for all the endpoints that are associated with the
+application.
 
 
 =head2 SegmentVersion => Int
 
-  The version of the segment to export if specified.
+  The version of the segment that the endpoint definitions were exported
+from.
 
 
 
