@@ -1,7 +1,7 @@
 package Paws::Pinpoint::RecencyDimension;
   use Moose;
-  has Duration => (is => 'ro', isa => 'Str');
-  has RecencyType => (is => 'ro', isa => 'Str');
+  has Duration => (is => 'ro', isa => 'Str', required => 1);
+  has RecencyType => (is => 'ro', isa => 'Str', required => 1);
 1;
 
 ### main pod documentation begin ###
@@ -32,23 +32,24 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Pinpoint::R
 
 =head1 DESCRIPTION
 
-Define how a segment based on recency of use.
+Specifies criteria for including or excluding endpoints from a segment
+based on how recently an endpoint was active.
 
 =head1 ATTRIBUTES
 
 
-=head2 Duration => Str
+=head2 B<REQUIRED> Duration => Str
 
-  The length of time during which users have been active or inactive with
-your app. Valid values: HR_24, DAY_7, DAY_14, DAY_30
+  The duration to use when determining whether an endpoint is active or
+inactive.
 
 
-=head2 RecencyType => Str
+=head2 B<REQUIRED> RecencyType => Str
 
-  The recency dimension type: ACTIVE - Users who have used your app
-within the specified duration are included in the segment. INACTIVE -
-Users who have not used your app within the specified duration are
-included in the segment.
+  The type of recency dimension to use for the segment. Valid values are:
+ACTIVE, endpoints that were active within the specified duration are
+included in the segment; and, INACTIVE, endpoints that weren't active
+within the specified duration are included in the segment.
 
 
 
