@@ -34,46 +34,69 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Pinpoint::W
 
 =head1 DESCRIPTION
 
-Creating application setting request
+Specifies the default settings for an application.
 
 =head1 ATTRIBUTES
 
 
 =head2 CampaignHook => L<Paws::Pinpoint::CampaignHook>
 
-  Default campaign hook information.
+  The settings for the AWS Lambda function to use by default as a code
+hook for campaigns in the application. To override these settings for a
+specific campaign, use the
+
+Campaign resource to define custom Lambda function settings for the
+campaign.
 
 
 =head2 CloudWatchMetricsEnabled => Bool
 
-  The CloudWatchMetrics settings for the app.
+  Specifies whether to enable application-related alarms in Amazon
+CloudWatch.
 
 
 =head2 Limits => L<Paws::Pinpoint::CampaignLimits>
 
-  The limits that apply to each campaign in the project by default.
-Campaigns can also have their own limits, which override the settings
-at the project level.
+  The default sending limits for campaigns in the application. To
+override these limits for a specific campaign, use the
+
+Campaign resource to define custom limits for the campaign.
 
 
 =head2 QuietTime => L<Paws::Pinpoint::QuietTime>
 
-  The default quiet time for the app. Campaigns in the app don't send
-messages to endpoints during the quiet time. Note: Make sure that your
-endpoints include the Demographics.Timezone attribute if you plan to
-enable a quiet time for your app. If your endpoints don't include this
-attribute, they'll receive the messages that you send them, even if
-quiet time is enabled. When you set up an app to use quiet time,
-campaigns in that app don't send messages during the time range you
-specified, as long as all of the following are true: - The endpoint
-includes a valid Demographic.Timezone attribute. - The current time in
-the endpoint's time zone is later than or equal to the time specified
-in the QuietTime.Start attribute for the app (or campaign, if
-applicable). - The current time in the endpoint's time zone is earlier
-than or equal to the time specified in the QuietTime.End attribute for
-the app (or campaign, if applicable). Individual campaigns within the
-app can have their own quiet time settings, which override the quiet
-time settings at the app level.
+  The default quiet time for campaigns in the application. Quiet time is
+a specific time range when campaigns don't send messages to endpoints,
+if all the following conditions are met:
+
+=over
+
+=item *
+
+The EndpointDemographic.Timezone property of the endpoint is set to a
+valid value.
+
+=item *
+
+The current time in the endpoint's time zone is later than or equal to
+the time specified by the QuietTime.Start property for the application
+(or a campaign that has custom quiet time settings).
+
+=item *
+
+The current time in the endpoint's time zone is earlier than or equal
+to the time specified by the QuietTime.End property for the application
+(or a campaign that has custom quiet time settings).
+
+=back
+
+If any of the preceding conditions isn't met, the endpoint will receive
+messages from a campaign, even if quiet time is enabled.
+
+To override the default quiet time settings for a specific campaign,
+use the
+
+Campaign resource to define a custom quiet time for the campaign.
 
 
 
