@@ -38,7 +38,7 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::Polly::Lexi
 
 Contains metadata describing the lexicon such as the number of lexemes,
 language code, and so on. For more information, see Managing Lexicons
-(http://docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html).
+(https://docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html).
 
 =head1 ATTRIBUTES
 
