@@ -26,6 +26,7 @@ package Paws::RDS::DBCluster;
   has DbClusterResourceId => (is => 'ro', isa => 'Str');
   has DBSubnetGroup => (is => 'ro', isa => 'Str');
   has DeletionProtection => (is => 'ro', isa => 'Bool');
+  has DomainMemberships => (is => 'ro', isa => 'ArrayRef[Paws::RDS::DomainMembership]', request_name => 'DomainMembership', traits => ['NameInRequest']);
   has EarliestBacktrackTime => (is => 'ro', isa => 'Str');
   has EarliestRestorableTime => (is => 'ro', isa => 'Str');
   has EnabledCloudwatchLogsExports => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
@@ -118,7 +119,7 @@ session can handle these events either synchronously or asynchronously.
   For all database engines except Amazon Aurora, C<AllocatedStorage>
 specifies the allocated storage size in gibibytes (GiB). For Aurora,
 C<AllocatedStorage> always returns 1, because Aurora DB cluster storage
-size is not fixed, but instead automatically adjusts as needed.
+size isn't fixed, but instead automatically adjusts as needed.
 
 
 =head2 AssociatedRoles => ArrayRef[L<Paws::RDS::DBClusterRole>]
@@ -252,6 +253,12 @@ group.
 database can't be deleted when deletion protection is enabled.
 
 
+=head2 DomainMemberships => ArrayRef[L<Paws::RDS::DomainMembership>]
+
+  The Active Directory Domain membership records associated with the DB
+cluster.
+
+
 =head2 EarliestBacktrackTime => Str
 
   The earliest time to which a DB cluster can be backtracked.
@@ -289,7 +296,7 @@ cluster.
 =head2 EngineMode => Str
 
   The DB engine mode of the DB cluster, either C<provisioned>,
-C<serverless>, or C<parallelquery>.
+C<serverless>, C<parallelquery>, C<global>, or C<multimaster>.
 
 
 =head2 EngineVersion => Str
