@@ -44,16 +44,15 @@ Provides information about a pending maintenance action for a resource.
 =head2 Action => Str
 
   The type of pending maintenance action that is available for the
-resource. Valid actions are C<system-update>, C<db-upgrade>, and
-C<hardware-maintenance>.
+resource. Valid actions are C<system-update>, C<db-upgrade>,
+C<hardware-maintenance>, and C<ca-certificate-rotation>.
 
 
 =head2 AutoAppliedAfterDate => Str
 
   The date of the maintenance window when the action is applied. The
 maintenance action is applied to the resource during its first
-maintenance window after this date. If this date is specified, any
-C<next-maintenance> opt-in requests are ignored.
+maintenance window after this date.
 
 
 =head2 CurrentApplyDate => Str
@@ -75,8 +74,7 @@ specified as C<AutoAppliedAfterDate> or C<ForcedApplyDate>.
 
   The date when the maintenance action is automatically applied. The
 maintenance action is applied to the resource on this date regardless
-of the maintenance window for the resource. If this date is specified,
-any C<immediate> opt-in requests are ignored.
+of the maintenance window for the resource.
 
 
 =head2 OptInStatus => Str
