@@ -1,6 +1,7 @@
 package Paws::RDSData::SqlParameter;
   use Moose;
   has Name => (is => 'ro', isa => 'Str', request_name => 'name', traits => ['NameInRequest']);
+  has TypeHint => (is => 'ro', isa => 'Str', request_name => 'typeHint', traits => ['NameInRequest']);
   has Value => (is => 'ro', isa => 'Paws::RDSData::Field', request_name => 'value', traits => ['NameInRequest']);
 1;
 
@@ -42,6 +43,41 @@ A parameter used in a SQL statement.
   The name of the parameter.
 
 
+=head2 TypeHint => Str
+
+  A hint that specifies the correct object type for data type mapping.
+
+B<Values:>
+
+=over
+
+=item *
+
+C<DECIMAL> - The corresponding C<String> parameter value is sent as an
+object of C<DECIMAL> type to the database.
+
+=item *
+
+C<TIMESTAMP> - The corresponding C<String> parameter value is sent as
+an object of C<TIMESTAMP> type to the database. The accepted format is
+C<YYYY-MM-DD HH:MM:SS[.FFF]>.
+
+=item *
+
+C<TIME> - The corresponding C<String> parameter value is sent as an
+object of C<TIME> type to the database. The accepted format is
+C<HH:MM:SS[.FFF]>.
+
+=item *
+
+C<DATE> - The corresponding C<String> parameter value is sent as an
+object of C<DATE> type to the database. The accepted format is
+C<YYYY-MM-DD>.
+
+=back
+
+
+
 =head2 Value => L<Paws::RDSData::Field>
 
   The value of the parameter.
