@@ -1,6 +1,7 @@
 package Paws::RedShift::AvailabilityZone;
   use Moose;
   has Name => (is => 'ro', isa => 'Str');
+  has SupportedPlatforms => (is => 'ro', isa => 'ArrayRef[Paws::RedShift::SupportedPlatform]', request_name => 'SupportedPlatform', traits => ['NameInRequest']);
 1;
 
 ### main pod documentation begin ###
@@ -20,7 +21,7 @@ Each attribute should be used as a named argument in the calls that expect this
 
 As an example, if Att1 is expected to be a Paws::RedShift::AvailabilityZone object:
 
-  $service_obj->Method(Att1 => { Name => $value, ..., Name => $value  });
+  $service_obj->Method(Att1 => { Name => $value, ..., SupportedPlatforms => $value  });
 
 =head3 Results returned from an API call
 
@@ -41,6 +42,11 @@ Describes an availability zone.
   The name of the availability zone.
 
 
+=head2 SupportedPlatforms => ArrayRef[L<Paws::RedShift::SupportedPlatform>]
+
+  
+
+
 
 =head1 SEE ALSO
 
@@ -48,9 +54,9 @@ This class forms part of L<Paws>, describing an object used in L<Paws::RedShift>
 
 =head1 BUGS and CONTRIBUTIONS
 
-The source code is located here: https://github.com/pplu/aws-sdk-perl
+The source code is located here: L<https://github.com/pplu/aws-sdk-perl>
 
-Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues
+Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>
 
 =cut
 
