@@ -40,7 +40,7 @@ region you use for Amazon Rekognition operations.
 
 For Amazon Rekognition to process an S3 object, the user must have
 permission to access the S3 object. For more information, see
-manage-access-resource-policies.
+Resource-Based Policies in the Amazon Rekognition Developer Guide.
 
 =head1 ATTRIBUTES
 
