@@ -70,15 +70,13 @@ complete value of the filtered item. You can use up to three filters.
 
 =head2 MaxResults => Int
 
-The maximum number of deployment job results returned by
-C<ListRobotApplications> in paginated output. When this parameter is
-used, C<ListRobotApplications> only returns C<maxResults> results in a
-single page along with a C<nextToken> response element. The remaining
-results of the initial request can be seen by sending another
-C<ListRobotApplications> request with the returned C<nextToken> value.
-This value can be between 1 and 100. If this parameter is not used,
-then C<ListRobotApplications> returns up to 100 results and a
-C<nextToken> value if applicable.
+When this parameter is used, C<ListRobotApplications> only returns
+C<maxResults> results in a single page along with a C<nextToken>
+response element. The remaining results of the initial request can be
+seen by sending another C<ListRobotApplications> request with the
+returned C<nextToken> value. This value can be between 1 and 100. If
+this parameter is not used, then C<ListRobotApplications> returns up to
+100 results and a C<nextToken> value if applicable.
 
 
 
@@ -89,10 +87,6 @@ C<ListRobotApplications> request where C<maxResults> was used and the
 results exceeded the value of that parameter. Pagination continues from
 the end of the previous results that returned the C<nextToken> value.
 
-This token should be treated as an opaque identifier that is only used
-to retrieve the next items in a list and not for other programmatic
-purposes.
-
 
 
 =head2 VersionQualifier => Str
