@@ -58,7 +58,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               HealthCheckId    => 'MyHealthCheckId',    # max: 64; OPTIONAL
               MultiValueAnswer => 1,                    # OPTIONAL
               Region           => 'us-east-1'
-              , # values: us-east-1, us-east-2, us-west-1, us-west-2, ca-central-1, eu-west-1, eu-west-2, eu-west-3, eu-central-1, ap-southeast-1, ap-southeast-2, ap-northeast-1, ap-northeast-2, ap-northeast-3, eu-north-1, sa-east-1, cn-north-1, cn-northwest-1, ap-east-1, ap-south-1min: 1, max: 64; OPTIONAL
+              , # values: us-east-1, us-east-2, us-west-1, us-west-2, ca-central-1, eu-west-1, eu-west-2, eu-west-3, eu-central-1, ap-southeast-1, ap-southeast-2, ap-northeast-1, ap-northeast-2, ap-northeast-3, eu-north-1, sa-east-1, cn-north-1, cn-northwest-1, ap-east-1, me-south-1, ap-south-1min: 1, max: 64; OPTIONAL
               ResourceRecords => [
                 {
                   Value => 'MyRData',    # max: 4000
