@@ -17,21 +17,27 @@ package Paws::Route53::DeleteReusableDelegationSet;
 
 =head1 NAME
 
-Paws::Route53::DeleteReusableDelegationSet - Arguments for method DeleteReusableDelegationSet on Paws::Route53
+Paws::Route53::DeleteReusableDelegationSet - Arguments for method DeleteReusableDelegationSet on L<Paws::Route53>
 
 =head1 DESCRIPTION
 
-This class represents the parameters used for calling the method DeleteReusableDelegationSet on the 
-Amazon Route 53 service. Use the attributes of this class
+This class represents the parameters used for calling the method DeleteReusableDelegationSet on the
+L<Amazon Route 53|Paws::Route53> service. Use the attributes of this class
 as arguments to method DeleteReusableDelegationSet.
 
 You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteReusableDelegationSet.
 
-As an example:
+=head1 SYNOPSIS
 
-  $service_obj->DeleteReusableDelegationSet(Att1 => $value1, Att2 => $value2, ...);
+    my $route53 = Paws->service('Route53');
+    my $DeleteReusableDelegationSetResponse =
+      $route53->DeleteReusableDelegationSet(
+      Id => 'MyResourceId',
+
+      );
 
 Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
+For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/route53/DeleteReusableDelegationSet>
 
 =head1 ATTRIBUTES
 
@@ -49,9 +55,9 @@ This class forms part of L<Paws>, documenting arguments for method DeleteReusabl
 
 =head1 BUGS and CONTRIBUTIONS
 
-The source code is located here: https://github.com/pplu/aws-sdk-perl
+The source code is located here: L<https://github.com/pplu/aws-sdk-perl>
 
-Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues
+Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>
 
 =cut
 
