@@ -75,7 +75,8 @@ you have registered with your DNS registrar.
 
 For information about how to specify characters other than C<a-z>,
 C<0-9>, and C<-> (hyphen) and how to specify internationalized domain
-names, see CreateHostedZone.
+names, see CreateHostedZone
+(https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateHostedZone.html).
 
 
 =head2 ResourceRecordSetCount => Int
