@@ -27,15 +27,25 @@ Paws::S3::CreateMultipartUploadOutput
 
 =head2 AbortDate => Str
 
-Date when multipart upload will become eligible for abort operation by
-lifecycle.
+If the bucket has a lifecycle rule configured with an action to abort
+incomplete multipart uploads and the prefix in the lifecycle rule
+matches the object name in the request, the response includes this
+header. The header indicates when the initiated multipart upload
+becomes eligible for an abort operation. For more information, see
+Aborting Incomplete Multipart Uploads Using a Bucket Lifecycle Policy
+(https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuoverview.html#mpu-abort-incomplete-mpu-lifecycle-config).
+
+The response also includes the C<x-amz-abort-rule-id> header that
+provides the ID of the lifecycle configuration rule that defines this
+action.
 
 
 
 =head2 AbortRuleId => Str
 
-Id of the lifecycle rule that makes a multipart upload eligible for
-abort operation.
+This header is returned along with the C<x-amz-abort-date> header. It
+identifies the applicable lifecycle configuration rule that defines the
+action to abort incomplete multipart uploads.
 
 
 
@@ -43,6 +53,15 @@ abort operation.
 
 Name of the bucket to which the multipart upload was initiated.
 
+When using this API with an access point, you must direct requests to
+the access point hostname. The access point hostname takes the form
+I<AccessPointName>-I<AccountId>.s3-accesspoint.I<Region>.amazonaws.com.
+When using this operation using an access point through the AWS SDKs,
+you provide the access point ARN in place of the bucket name. For more
+information about access point ARNs, see Using Access Points
+(https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html)
+in the I<Amazon Simple Storage Service Developer Guide>.
+
 
 
 =head2 Key => Str
@@ -59,8 +78,8 @@ Valid values are: C<"requester">
 
 =head2 ServerSideEncryption => Str
 
-The Server-side encryption algorithm used when storing this object in
-S3 (e.g., AES256, aws:kms).
+The server-side encryption algorithm used when storing this object in
+Amazon S3 (for example, AES256, aws:kms).
 
 Valid values are: C<"AES256">, C<"aws:kms">
 
@@ -75,7 +94,7 @@ encryption algorithm used.
 =head2 SSECustomerKeyMD5 => Str
 
 If server-side encryption with a customer-provided encryption key was
-requested, the response will include this header to provide round trip
+requested, the response will include this header to provide round-trip
 message integrity verification of the customer-provided encryption key.
 
 
@@ -90,8 +109,9 @@ holding JSON with the encryption context key-value pairs.
 
 =head2 SSEKMSKeyId => Str
 
-If present, specifies the ID of the AWS Key Management Service (KMS)
-master encryption key that was used for the object.
+If present, specifies the ID of the AWS Key Management Service (AWS
+KMS) symmetric customer managed customer master key (CMK) that was used
+for the object.
 
 
 
