@@ -31,14 +31,27 @@ Use accessors for each attribute. If Att1 is expected to be an Paws::S3::DeleteM
 
 =head1 DESCRIPTION
 
-Specifies whether Amazon S3 should replicate delete makers.
+Specifies whether Amazon S3 replicates the delete markers. If you
+specify a C<Filter>, you must specify this element. However, in the
+latest version of replication configuration (when C<Filter> is
+specified), Amazon S3 doesn't replicate delete markers. Therefore, the
+C<DeleteMarkerReplication> element can contain only
+E<lt>StatusE<gt>DisabledE<lt>/StatusE<gt>. For an example
+configuration, see Basic Rule Configuration
+(https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-add-config.html#replication-config-min-rule-config).
+
+If you don't specify the C<Filter> element, Amazon S3 assumes that the
+replication configuration is the earlier version, V1. In the earlier
+version, Amazon S3 handled replication of delete markers differently.
+For more information, see Backward Compatibility
+(https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-add-config.html#replication-backward-compat-considerations).
 
 =head1 ATTRIBUTES
 
 
 =head2 Status => Str
 
-  The status of the delete marker replication.
+  Indicates whether to replicate delete markers.
 
 In the current implementation, Amazon S3 doesn't replicate the delete
 markers. The status must be C<Disabled>.
