@@ -59,20 +59,29 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/s3/
 
 =head2 B<REQUIRED> Bucket => Str
 
+The bucket name of the bucket containing the object.
 
+When using this API with an access point, you must direct requests to
+the access point hostname. The access point hostname takes the form
+I<AccessPointName>-I<AccountId>.s3-accesspoint.I<Region>.amazonaws.com.
+When using this operation using an access point through the AWS SDKs,
+you provide the access point ARN in place of the bucket name. For more
+information about access point ARNs, see Using Access Points
+(https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html)
+in the I<Amazon Simple Storage Service Developer Guide>.
 
 
 
 =head2 BypassGovernanceRetention => Bool
 
-Indicates whether Amazon S3 object lock should bypass governance-mode
+Indicates whether S3 Object Lock should bypass Governance-mode
 restrictions to process this operation.
 
 
 
 =head2 B<REQUIRED> Key => Str
 
-
+Key name of the object to delete.
 
 
 
@@ -80,6 +89,8 @@ restrictions to process this operation.
 
 The concatenation of the authentication device's serial number, a
 space, and the value that is displayed on your authentication device.
+Required to permanently delete a versioned object if versioning is
+configured with MFA delete enabled.
 
 
 
