@@ -39,8 +39,13 @@ is a destination for replicated objects.
 
 =head2 ReplicaKmsKeyID => Str
 
-  Specifies the AWS KMS Key ID (Key ARN or Alias ARN) for the destination
-bucket. Amazon S3 uses this key to encrypt replica objects.
+  Specifies the ID (Key ARN or Alias ARN) of the customer managed
+customer master key (CMK) stored in AWS Key Management Service (KMS)
+for the destination bucket. Amazon S3 uses this key to encrypt replica
+objects. Amazon S3 only supports symmetric customer managed CMKs. For
+more information, see Using Symmetric and Asymmetric Keys
+(https://docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html)
+in the I<AWS Key Management Service Developer Guide>.
 
 
 
