@@ -3,6 +3,8 @@ package Paws::S3::GetBucketPolicyOutput;
   use Moose;
   has Policy => (is => 'ro', isa => 'Str');
 
+  use MooseX::ClassAttribute;
+  class_has _payload => (is => 'ro', default => 'Policy');
   has _request_id => (is => 'ro', isa => 'Str');
 1;
 
