@@ -34,13 +34,18 @@ Name of the bucket to which the multipart upload was initiated.
 
 =head2 CommonPrefixes => ArrayRef[L<Paws::S3::CommonPrefix>]
 
-
+If you specify a delimiter in the request, then the result returns each
+distinct key prefix containing the delimiter in a C<CommonPrefixes>
+element. The distinct key prefixes are returned in the C<Prefix> child
+element.
 
 
 
 =head2 Delimiter => Str
 
-
+Contains the delimiter you specified in the request. If you don't
+specify a delimiter in your request, this element is absent from the
+response.
 
 
 
@@ -48,6 +53,12 @@ Name of the bucket to which the multipart upload was initiated.
 
 Encoding type used by Amazon S3 to encode object keys in the response.
 
+If you specify C<encoding-type> request parameter, Amazon S3 includes
+this element in the response, and returns encoded key name values in
+the following response elements:
+
+C<Delimiter>, C<KeyMarker>, C<Prefix>, C<NextKeyMarker>, C<Key>.
+
 Valid values are: C<"url">
 
 =head2 IsTruncated => Bool
@@ -82,7 +93,7 @@ be used for the key-marker request parameter in a subsequent request.
 =head2 NextUploadIdMarker => Str
 
 When a list is truncated, this element specifies the value that should
-be used for the upload-id-marker request parameter in a subsequent
+be used for the C<upload-id-marker> request parameter in a subsequent
 request.
 
 
@@ -103,7 +114,8 @@ Upload ID after which listing began.
 
 =head2 Uploads => ArrayRef[L<Paws::S3::MultipartUpload>]
 
-
+Container for elements related to a particular multipart upload. A
+response can contain zero or more C<Upload> elements.
 
 
 
