@@ -30,15 +30,25 @@ Paws::S3::ListPartsOutput
 
 =head2 AbortDate => Str
 
-Date when multipart upload will become eligible for abort operation by
-lifecycle.
+If the bucket has a lifecycle rule configured with an action to abort
+incomplete multipart uploads and the prefix in the lifecycle rule
+matches the object name in the request, then the response includes this
+header indicating when the initiated multipart upload will become
+eligible for abort operation. For more information, see Aborting
+Incomplete Multipart Uploads Using a Bucket Lifecycle Policy
+(https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuoverview.html#mpu-abort-incomplete-mpu-lifecycle-config).
+
+The response will also include the C<x-amz-abort-rule-id> header that
+will provide the ID of the lifecycle configuration rule that defines
+this action.
 
 
 
 =head2 AbortRuleId => Str
 
-Id of the lifecycle rule that makes a multipart upload eligible for
-abort operation.
+This header is returned along with the C<x-amz-abort-date> header. It
+identifies applicable lifecycle configuration rule that defines the
+action to abort incomplete multipart uploads.
 
 
 
@@ -50,13 +60,18 @@ Name of the bucket to which the multipart upload was initiated.
 
 =head2 Initiator => L<Paws::S3::Initiator>
 
-Identifies who initiated the multipart upload.
+Container element that identifies who initiated the multipart upload.
+If the initiator is an AWS account, this element provides the same
+information as the C<Owner> element. If the initiator is an IAM User,
+this element provides the user ARN and display name.
 
 
 
 =head2 IsTruncated => Bool
 
-Indicates whether the returned list of parts is truncated.
+Indicates whether the returned list of parts is truncated. A true value
+indicates that the list was truncated. A list can be truncated if the
+number of parts exceeds the limit returned in the MaxParts element.
 
 
 
@@ -82,19 +97,24 @@ parameter in a subsequent request.
 
 =head2 Owner => L<Paws::S3::Owner>
 
-
+Container element that identifies the object owner, after the object is
+created. If multipart upload is initiated by an IAM user, this element
+provides the parent account ID and display name.
 
 
 
 =head2 PartNumberMarker => Int
 
-Part number after which listing begins.
+When a list is truncated, this element specifies the last part in the
+list, as well as the value to use for the part-number-marker request
+parameter in a subsequent request.
 
 
 
 =head2 Parts => ArrayRef[L<Paws::S3::Part>]
 
-
+Container for elements related to a particular part. A response can
+contain zero or more C<Part> elements.
 
 
 
@@ -106,7 +126,8 @@ Valid values are: C<"requester">
 
 =head2 StorageClass => Str
 
-The class of storage used to store the object.
+Class of storage (STANDARD or REDUCED_REDUNDANCY) used to store the
+uploaded object.
 
 Valid values are: C<"STANDARD">, C<"REDUCED_REDUNDANCY">, C<"STANDARD_IA">, C<"ONEZONE_IA">, C<"INTELLIGENT_TIERING">, C<"GLACIER">, C<"DEEP_ARCHIVE">
 
