@@ -48,9 +48,9 @@ a specific period in the object's lifetime.
 
   Specifies the number of days an object is noncurrent before Amazon S3
 can perform the associated action. For information about the noncurrent
-days calculations, see How Amazon S3 Calculates When an Object Became
-Noncurrent
-(https://docs.aws.amazon.com/AmazonS3/latest/dev/s3-access-control.html)
+days calculations, see How Amazon S3 Calculates How Long an Object Has
+Been Noncurrent
+(https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations)
 in the I<Amazon Simple Storage Service Developer Guide>.
 
 
