@@ -54,7 +54,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                     Value => 'MyValue',
 
                   },
-                  ...                          # OPTIONAL
+                  ...
                 ],                             # OPTIONAL
               },    # OPTIONAL
               Prefix => 'MyPrefix',    # OPTIONAL
@@ -62,7 +62,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                 Key   => 'MyObjectKey',    # min: 1
                 Value => 'MyValue',
 
-              },    # OPTIONAL
+              },
             },    # OPTIONAL
             ID                          => 'MyID',    # OPTIONAL
             NoncurrentVersionExpiration => {
@@ -101,13 +101,13 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/s3/
 
 =head2 B<REQUIRED> Bucket => Str
 
-
+The name of the bucket for which to set the configuration.
 
 
 
 =head2 LifecycleConfiguration => L<Paws::S3::BucketLifecycleConfiguration>
 
-
+Container for lifecycle rules. You can add as many as 1,000 rules.
 
 
 
