@@ -47,7 +47,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
                 Value => 'MyValue',
 
               },
-              ...
+              ...                          # OPTIONAL
             ],                             # OPTIONAL
           },    # OPTIONAL
           Prefix => 'MyPrefix',    # OPTIONAL
@@ -55,7 +55,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
             Key   => 'MyObjectKey',    # min: 1
             Value => 'MyValue',
 
-          },
+          },    # OPTIONAL
         },    # OPTIONAL
       },
       ContentLength => 1,    # OPTIONAL
