@@ -51,7 +51,7 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/s3/
 
 =head2 B<REQUIRED> Bucket => Str
 
-
+The bucket name.
 
 
 
@@ -63,13 +63,16 @@ Size of the body in bytes.
 
 =head2 ContentMD5 => Str
 
-
+E<gt>The base64-encoded 128-bit MD5 digest of the data. You must use
+this header as a message integrity check to verify that the request
+body was not corrupted in transit. For more information, see RFC 1864
+(http://www.ietf.org/rfc/rfc1864.txt).
 
 
 
 =head2 B<REQUIRED> RequestPaymentConfiguration => L<Paws::S3::RequestPaymentConfiguration>
 
-
+Container for Payer.
 
 
 
