@@ -53,7 +53,7 @@ For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/s3/
 
 =head2 B<REQUIRED> Bucket => Str
 
-
+The bucket name.
 
 
 
@@ -65,7 +65,10 @@ Size of the body in bytes.
 
 =head2 ContentMD5 => Str
 
-
+E<gt>The base64-encoded 128-bit MD5 digest of the data. You must use
+this header as a message integrity check to verify that the request
+body was not corrupted in transit. For more information, see RFC 1864
+(http://www.ietf.org/rfc/rfc1864.txt).
 
 
 
@@ -78,7 +81,7 @@ space, and the value that is displayed on your authentication device.
 
 =head2 B<REQUIRED> VersioningConfiguration => L<Paws::S3::VersioningConfiguration>
 
-
+Container for setting the versioning state.
 
 
 
