@@ -39,7 +39,7 @@ behalf bounces.
 
 For information about receiving email through Amazon SES, see the
 Amazon SES Developer Guide
-(http://docs.aws.amazon.com/ses/latest/DeveloperGuide/receiving-email.html).
+(https://docs.aws.amazon.com/ses/latest/DeveloperGuide/receiving-email.html).
 
 =head1 ATTRIBUTES
 
