@@ -44,7 +44,7 @@ Amazon SES permission to publish emails to it. However, if you don't
 own the Amazon SNS topic, you need to attach a policy to the topic to
 give Amazon SES permissions to access it. For information about giving
 permissions, see the Amazon SES Developer Guide
-(http://docs.aws.amazon.com/ses/latest/DeveloperGuide/receiving-email-permissions.html).
+(https://docs.aws.amazon.com/ses/latest/DeveloperGuide/receiving-email-permissions.html).
 
 You can only publish emails that are 150 KB or less (including the
 header) to Amazon SNS. Larger emails will bounce. If you anticipate
@@ -52,7 +52,7 @@ emails larger than 150 KB, use the S3 action instead.
 
 For information about using a receipt rule to publish an Amazon SNS
 notification, see the Amazon SES Developer Guide
-(http://docs.aws.amazon.com/ses/latest/DeveloperGuide/receiving-email-action-sns.html).
+(https://docs.aws.amazon.com/ses/latest/DeveloperGuide/receiving-email-action-sns.html).
 
 =head1 ATTRIBUTES
 
@@ -71,7 +71,7 @@ preserves all special characters. The default value is UTF-8.
 example of an Amazon SNS topic ARN is
 C<arn:aws:sns:us-west-2:123456789012:MyTopic>. For more information
 about Amazon SNS topics, see the Amazon SNS Developer Guide
-(http://docs.aws.amazon.com/sns/latest/dg/CreateTopic.html).
+(https://docs.aws.amazon.com/sns/latest/dg/CreateTopic.html).
 
 
 
