@@ -66,7 +66,7 @@ C<StringValue>.
 
 You can also append custom labels. For more information, see Amazon SQS
 Message Attributes
-(http://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-message-attributes.html)
+(https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-message-attributes.html)
 in the I<Amazon Simple Queue Service Developer Guide>.
 
 
