@@ -44,7 +44,6 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       ApprovalRules => {
         PatchRules => [
           {
-            ApproveAfterDays => 1,    # max: 100
             PatchFilterGroup => {
               PatchFilters => [
                 {
@@ -59,7 +58,9 @@ You shouldn't make instances of this class. Each attribute should be used as a n
               ],                                 # max: 4
 
             },
-            ComplianceLevel => 'CRITICAL'
+            ApproveAfterDays => 1,                   # max: 100; OPTIONAL
+            ApproveUntilDate => 'MyPatchStringDate', # min: 1, max: 10; OPTIONAL
+            ComplianceLevel  => 'CRITICAL'
             , # values: CRITICAL, HIGH, MEDIUM, LOW, INFORMATIONAL, UNSPECIFIED; OPTIONAL
             EnableNonSecurity => 1,    # OPTIONAL
           },
@@ -95,7 +96,7 @@ You shouldn't make instances of this class. Each attribute should be used as a n
       RejectedPatchesAction => 'ALLOW_AS_DEPENDENCY',    # OPTIONAL
       Sources               => [
         {
-          Configuration => 'MyPatchSourceConfiguration',    # min: 1, max: 512
+          Configuration => 'MyPatchSourceConfiguration',    # min: 1, max: 1024
           Name          => 'MyPatchSourceName',
           Products      => [
             'MyPatchSourceProduct', ...                     # min: 1, max: 128
